@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin-test
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Tests;
 
 use PhpMyAdmin\Config;
@@ -20,7 +22,7 @@ use stdClass;
  */
 class CoreTest extends PmaTestCase
 {
-    protected $goto_whitelist = array(
+    protected $goto_whitelist = [
         'db_datadict.php',
         'db_sql.php',
         'db_export.php',
@@ -37,14 +39,14 @@ class CoreTest extends PmaTestCase
         'transformation_overview.php',
         'transformation_wrapper.php',
         'user_password.php',
-    );
+    ];
 
     /**
      * Setup for test cases
      *
      * @return void
      */
-    public function setUp()
+    protected function setUp(): void
     {
         $GLOBALS['server'] = 0;
         $GLOBALS['db'] = '';
@@ -57,17 +59,33 @@ class CoreTest extends PmaTestCase
      *
      * @return void
      */
-    function testArrayRead()
+    public function testArrayRead()
     {
-        $arr = array(
+        $arr = [
             "int" => 1,
             "str" => "str_val",
-            "arr" => array('val1', 'val2', 'val3'),
-            "sarr" => array(
-                'arr1' => array(1, 2, 3),
-                array(3, array('a', 'b', 'c'), 4)
-            )
-        );
+            "arr" => [
+                'val1',
+                'val2',
+                'val3',
+            ],
+            "sarr" => [
+                'arr1' => [
+                    1,
+                    2,
+                    3,
+                ],
+                [
+                    3,
+                    [
+                        'a',
+                        'b',
+                        'c',
+                    ],
+                    4,
+                ],
+            ],
+        ];
 
         $this->assertEquals(
             Core::arrayRead('int', $arr),
@@ -145,17 +163,33 @@ class CoreTest extends PmaTestCase
      *
      * @return void
      */
-    function testArrayWrite()
+    public function testArrayWrite()
     {
-        $arr = array(
+        $arr = [
             "int" => 1,
             "str" => "str_val",
-            "arr" => array('val1', 'val2', 'val3'),
-            "sarr" => array(
-                'arr1' => array(1, 2, 3),
-                array(3, array('a', 'b', 'c'), 4)
-            )
-        );
+            "arr" => [
+                'val1',
+                'val2',
+                'val3',
+            ],
+            "sarr" => [
+                'arr1' => [
+                    1,
+                    2,
+                    3,
+                ],
+                [
+                    3,
+                    [
+                        'a',
+                        'b',
+                        'c',
+                    ],
+                    4,
+                ],
+            ],
+        ];
 
         Core::arrayWrite('int', $arr, 5);
         $this->assertEquals($arr['int'], 5);
@@ -199,17 +233,33 @@ class CoreTest extends PmaTestCase
      *
      * @return void
      */
-    function testArrayRemove()
+    public function testArrayRemove()
     {
-        $arr = array(
+        $arr = [
             "int" => 1,
             "str" => "str_val",
-            "arr" => array('val1', 'val2', 'val3'),
-            "sarr" => array(
-                'arr1' => array(1, 2, 3),
-                array(3, array('a', 'b', 'c'), 4)
-            )
-        );
+            "arr" => [
+                'val1',
+                'val2',
+                'val3',
+            ],
+            "sarr" => [
+                'arr1' => [
+                    1,
+                    2,
+                    3,
+                ],
+                [
+                    3,
+                    [
+                        'a',
+                        'b',
+                        'c',
+                    ],
+                    4,
+                ],
+            ],
+        ];
 
         Core::arrayRemove('int', $arr);
         $this->assertArrayNotHasKey('int', $arr);
@@ -261,13 +311,14 @@ class CoreTest extends PmaTestCase
      *
      * @param string     $page      Page
      * @param array|null $whiteList White list
+     * @param boolean    $include   whether the page is going to be included
      * @param int        $expected  Expected value
      *
      * @return void
      *
      * @dataProvider providerTestGotoNowhere
      */
-    function testGotoNowhere($page, $whiteList, $include, $expected)
+    public function testGotoNowhere($page, $whiteList, $include, $expected): void
     {
         $this->assertSame($expected, Core::checkPageValidity($page, $whiteList, $include));
     }
@@ -279,20 +330,80 @@ class CoreTest extends PmaTestCase
      */
     public function providerTestGotoNowhere()
     {
-        return array(
-            array(null, [], false, false),
-            array(null, [], true, false),
-            array('export.php', [], false, true),
-            array('export.php', [], true, true),
-            array('export.php', $this->goto_whitelist, false, true),
-            array('export.php', $this->goto_whitelist, true, true),
-            array('shell.php', $this->goto_whitelist, false, false),
-            array('shell.php', $this->goto_whitelist, true, false),
-            array('index.php?sql.php&test=true', $this->goto_whitelist, false, true),
-            array('index.php?sql.php&test=true', $this->goto_whitelist, true, false),
-            array('index.php%3Fsql.php%26test%3Dtrue', $this->goto_whitelist, false, true),
-            array('index.php%3Fsql.php%26test%3Dtrue', $this->goto_whitelist, true, false),
-        );
+        return [
+            [
+                null,
+                [],
+                false,
+                false,
+            ],
+            [
+                null,
+                [],
+                true,
+                false,
+            ],
+            [
+                'export.php',
+                [],
+                false,
+                true,
+            ],
+            [
+                'export.php',
+                [],
+                true,
+                true,
+            ],
+            [
+                'export.php',
+                $this->goto_whitelist,
+                false,
+                true,
+            ],
+            [
+                'export.php',
+                $this->goto_whitelist,
+                true,
+                true,
+            ],
+            [
+                'shell.php',
+                $this->goto_whitelist,
+                false,
+                false,
+            ],
+            [
+                'shell.php',
+                $this->goto_whitelist,
+                true,
+                false,
+            ],
+            [
+                'index.php?sql.php&test=true',
+                $this->goto_whitelist,
+                false,
+                true,
+            ],
+            [
+                'index.php?sql.php&test=true',
+                $this->goto_whitelist,
+                true,
+                false,
+            ],
+            [
+                'index.php%3Fsql.php%26test%3Dtrue',
+                $this->goto_whitelist,
+                false,
+                true,
+            ],
+            [
+                'index.php%3Fsql.php%26test%3Dtrue',
+                $this->goto_whitelist,
+                true,
+                false,
+            ],
+        ];
     }
 
     /**
@@ -307,7 +418,7 @@ class CoreTest extends PmaTestCase
      *
      * @dataProvider providerTestPathInfo
      */
-    public function testPathInfo($php_self, $request, $path_info, $expected)
+    public function testPathInfo($php_self, $request, $path_info, $expected): void
     {
         $_SERVER['PHP_SELF'] = $php_self;
         $_SERVER['REQUEST_URI'] = $request;
@@ -326,56 +437,56 @@ class CoreTest extends PmaTestCase
      */
     public function providerTestPathInfo()
     {
-        return array(
-            array(
+        return [
+            [
                 '/phpmyadmin/index.php/; cookieinj=value/',
                 '/phpmyadmin/index.php/;%20cookieinj=value///',
                 '/; cookieinj=value/',
-                '/phpmyadmin/index.php'
-            ),
-            array(
+                '/phpmyadmin/index.php',
+            ],
+            [
                 '',
                 '/phpmyadmin/index.php/;%20cookieinj=value///',
                 '/; cookieinj=value/',
-                '/phpmyadmin/index.php'
-            ),
-            array(
+                '/phpmyadmin/index.php',
+            ],
+            [
                 '',
                 '//example.com/../phpmyadmin/index.php',
                 '',
-                '/phpmyadmin/index.php'
-            ),
-            array(
+                '/phpmyadmin/index.php',
+            ],
+            [
                 '',
                 '//example.com/../../.././phpmyadmin/index.php',
                 '',
-                '/phpmyadmin/index.php'
-            ),
-            array(
+                '/phpmyadmin/index.php',
+            ],
+            [
                 '',
                 '/page.php/malicouspathinfo?malicouspathinfo',
                 'malicouspathinfo',
-                '/page.php'
-            ),
-            array(
+                '/page.php',
+            ],
+            [
                 '/phpmyadmin/./index.php',
                 '/phpmyadmin/./index.php',
                 '',
-                '/phpmyadmin/index.php'
-            ),
-            array(
+                '/phpmyadmin/index.php',
+            ],
+            [
                 '/phpmyadmin/index.php',
                 '/phpmyadmin/index.php',
                 '',
-                '/phpmyadmin/index.php'
-            ),
-            array(
+                '/phpmyadmin/index.php',
+            ],
+            [
                 '',
                 '/phpmyadmin/index.php',
                 '',
-                '/phpmyadmin/index.php'
-            ),
-        );
+                '/phpmyadmin/index.php',
+            ],
+        ];
     }
 
     /**
@@ -397,7 +508,10 @@ class CoreTest extends PmaTestCase
     public function testFatalErrorMessageWithArgs()
     {
         $message = "Fatal error #%d in file %s.";
-        $params = array(1, 'error_file.php');
+        $params = [
+            1,
+            'error_file.php',
+        ];
 
         $this->expectOutputRegex("/Fatal error #1 in file error_file.php./");
         Core::fatalError($message, $params);
@@ -417,9 +531,11 @@ class CoreTest extends PmaTestCase
      *
      * @return void
      *
+     * @group 32bit-incompatible
+     *
      * @dataProvider providerTestGetRealSize
      */
-    public function testGetRealSize($size, $expected)
+    public function testGetRealSize($size, $expected): void
     {
         $this->assertEquals($expected, Core::getRealSize($size));
     }
@@ -431,14 +547,40 @@ class CoreTest extends PmaTestCase
      */
     public function providerTestGetRealSize()
     {
-        return array(
-            array('0', 0),
-            array('1kb', 1024),
-            array('1024k', 1024 * 1024),
-            array('8m', 8 * 1024 * 1024),
-            array('12gb', 12 * 1024 * 1024 * 1024),
-            array('1024', 1024),
-        );
+        return [
+            [
+                '0',
+                0,
+            ],
+            [
+                '1kb',
+                1024,
+            ],
+            [
+                '1024k',
+                1024 * 1024,
+            ],
+            [
+                '8m',
+                8 * 1024 * 1024,
+            ],
+            [
+                '12gb',
+                12 * 1024 * 1024 * 1024,
+            ],
+            [
+                '1024',
+                1024,
+            ],
+            [
+                '8000m',
+                8 * 1000 * 1024 * 1024,
+            ],
+            [
+                '8G',
+                8 * 1024 * 1024 * 1024,
+            ],
+        ];
     }
 
     /**
@@ -466,7 +608,7 @@ class CoreTest extends PmaTestCase
      *
      * @dataProvider providerTestLinkURL
      */
-    public function testLinkURL($link, $url)
+    public function testLinkURL($link, $url): void
     {
         $this->assertEquals(Core::linkURL($link), $url);
     }
@@ -478,14 +620,24 @@ class CoreTest extends PmaTestCase
      */
     public function providerTestLinkURL()
     {
-        return array(
-            array('https://wiki.phpmyadmin.net',
-             './url.php?url=https%3A%2F%2Fwiki.phpmyadmin.net'),
-            array('https://wiki.phpmyadmin.net',
-             './url.php?url=https%3A%2F%2Fwiki.phpmyadmin.net'),
-            array('wiki.phpmyadmin.net', 'wiki.phpmyadmin.net'),
-            array('index.php?db=phpmyadmin', 'index.php?db=phpmyadmin')
-        );
+        return [
+            [
+                'https://wiki.phpmyadmin.net',
+                './url.php?url=https%3A%2F%2Fwiki.phpmyadmin.net',
+            ],
+            [
+                'https://wiki.phpmyadmin.net',
+                './url.php?url=https%3A%2F%2Fwiki.phpmyadmin.net',
+            ],
+            [
+                'wiki.phpmyadmin.net',
+                'wiki.phpmyadmin.net',
+            ],
+            [
+                'index.php?db=phpmyadmin',
+                'index.php?db=phpmyadmin',
+            ],
+        ];
     }
 
     /**
@@ -556,18 +708,17 @@ class CoreTest extends PmaTestCase
         $testUri_html = htmlspecialchars($testUri);
         $testUri_js = Sanitize::escapeJsString($testUri);
 
-        $header = "<html>\n<head>\n    <title>- - -</title>
-    <meta http-equiv=\"expires\" content=\"0\" />"
-            . "\n    <meta http-equiv=\"Pragma\" content=\"no-cache\" />"
-            . "\n    <meta http-equiv=\"Cache-Control\" content=\"no-cache\" />"
-            . "\n    <meta http-equiv=\"Refresh\" content=\"0;url=" . $testUri_html . "\" />"
-            . "\n    <script type=\"text/javascript\">\n        //<![CDATA[
-        setTimeout(function() { window.location = decodeURI('" . $testUri_js . "'); }, 2000);
-        //]]>\n    </script>\n</head>
-<body>\n<script type=\"text/javascript\">\n    //<![CDATA[
-    document.write('<p><a href=\"" . $testUri_html . "\">" . __('Go') . "</a></p>');
-    //]]>\n</script>\n</body>\n</html>
-";
+        $header = "<html>\n<head>\n    <title>- - -</title>"
+            . "\n    <meta http-equiv=\"expires\" content=\"0\">"
+            . "\n    <meta http-equiv=\"Pragma\" content=\"no-cache\">"
+            . "\n    <meta http-equiv=\"Cache-Control\" content=\"no-cache\">"
+            . "\n    <meta http-equiv=\"Refresh\" content=\"0;url=" . $testUri_html . "\">"
+            . "\n    <script type=\"text/javascript\">\n        //<![CDATA["
+            . "\n        setTimeout(function() { window.location = decodeURI('" . $testUri_js . "'); }, 2000);"
+            . "\n        //]]>\n    </script>\n</head>"
+            . "\n<body>\n<script type=\"text/javascript\">\n    //<![CDATA["
+            . "\n    document.write('<p><a href=\"" . $testUri_html . "\">" . __('Go') . "</a></p>');"
+            . "\n    //]]>\n</script>\n</body>\n</html>\n";
 
         $this->expectOutputString($header);
 
@@ -637,7 +788,7 @@ class CoreTest extends PmaTestCase
      *
      * @dataProvider provideTestIsAllowedDomain
      */
-    function testIsAllowedDomain($url, $expected)
+    public function testIsAllowedDomain($url, $expected): void
     {
         $_SERVER['SERVER_NAME'] = 'server.local';
         $this->assertEquals(
@@ -651,18 +802,42 @@ class CoreTest extends PmaTestCase
      *
      * @return array
      */
-    function provideTestIsAllowedDomain()
+    public function provideTestIsAllowedDomain()
     {
-        return array(
-            array('https://www.phpmyadmin.net/', true),
-            array('http://duckduckgo.com\\@github.com', false),
-            array('https://github.com/', true),
-            array('https://github.com:123/', false),
-            array('https://user:pass@github.com:123/', false),
-            array('https://user:pass@github.com/', false),
-            array('https://server.local/', true),
-            array('./relative/', false),
-        );
+        return [
+            [
+                'https://www.phpmyadmin.net/',
+                true,
+            ],
+            [
+                'http://duckduckgo.com\\@github.com',
+                false,
+            ],
+            [
+                'https://github.com/',
+                true,
+            ],
+            [
+                'https://github.com:123/',
+                false,
+            ],
+            [
+                'https://user:pass@github.com:123/',
+                false,
+            ],
+            [
+                'https://user:pass@github.com/',
+                false,
+            ],
+            [
+                'https://server.local/',
+                true,
+            ],
+            [
+                './relative/',
+                false,
+            ],
+        ];
     }
 
     /**
@@ -676,7 +851,7 @@ class CoreTest extends PmaTestCase
      *
      * @dataProvider providerTestNoVarType
      */
-    public function testNoVarType($var, $type, $compare)
+    public function testNoVarType($var, $type, $compare): void
     {
         $this->assertTrue(Core::isValid($var, $type, $compare));
     }
@@ -688,19 +863,72 @@ class CoreTest extends PmaTestCase
      */
     public static function providerTestNoVarType()
     {
-        return array(
-            array(0, false, 0),
-            array(0, false, 1),
-            array(1, false, null),
-            array(1.1, false, null),
-            array('', false, null),
-            array(' ', false, null),
-            array('0', false, null),
-            array('string', false, null),
-            array(array(), false, null),
-            array(array(1, 2, 3), false, null),
-            array(true, false, null),
-            array(false, false, null));
+        return [
+            [
+                0,
+                false,
+                0,
+            ],
+            [
+                0,
+                false,
+                1,
+            ],
+            [
+                1,
+                false,
+                null,
+            ],
+            [
+                1.1,
+                false,
+                null,
+            ],
+            [
+                '',
+                false,
+                null,
+            ],
+            [
+                ' ',
+                false,
+                null,
+            ],
+            [
+                '0',
+                false,
+                null,
+            ],
+            [
+                'string',
+                false,
+                null,
+            ],
+            [
+                [],
+                false,
+                null,
+            ],
+            [
+                [
+                    1,
+                    2,
+                    3,
+                ],
+                false,
+                null,
+            ],
+            [
+                true,
+                false,
+                null,
+            ],
+            [
+                false,
+                false,
+                null,
+            ],
+        ];
     }
 
     /**
@@ -841,7 +1069,7 @@ class CoreTest extends PmaTestCase
      */
     public function testNotScalarArray()
     {
-        $var = array('test');
+        $var = ['test'];
         $this->assertFalse(Core::isValid($var, 'scalar'));
     }
 
@@ -908,7 +1136,7 @@ class CoreTest extends PmaTestCase
     public function testValueInArray()
     {
         $var = 'a';
-        $this->assertTrue(Core::isValid($var, array('a', 'b',)));
+        $this->assertTrue(Core::isValid($var, ['a', 'b']));
     }
 
     /**
@@ -919,7 +1147,7 @@ class CoreTest extends PmaTestCase
     public function testValueNotInArray()
     {
         $var = 'c';
-        $this->assertFalse(Core::isValid($var, array('a', 'b',)));
+        $this->assertFalse(Core::isValid($var, ['a', 'b']));
     }
 
     /**
@@ -953,7 +1181,7 @@ class CoreTest extends PmaTestCase
      *
      * @dataProvider provideTestSimilarType
      */
-    public function testSimilarType($var, $compare)
+    public function testSimilarType($var, $compare): void
     {
         $this->assertTrue(Core::isValid($var, 'similar', $compare));
         $this->assertTrue(Core::isValid($var, 'equal', $compare));
@@ -968,14 +1196,51 @@ class CoreTest extends PmaTestCase
      */
     public function provideTestSimilarType()
     {
-        return array(
-            array(1, 1),
-            array(1.5, 1.5),
-            array(true, true),
-            array('string', "string"),
-            array(array(1, 2, 3.4), array(1, 2, 3.4)),
-            array(array(1, '2', '3.4', 5, 'text'), array('1', '2', 3.4,'5'))
-        );
+        return [
+            [
+                1,
+                1,
+            ],
+            [
+                1.5,
+                1.5,
+            ],
+            [
+                true,
+                true,
+            ],
+            [
+                'string',
+                "string",
+            ],
+            [
+                [
+                    1,
+                    2,
+                    3.4,
+                ],
+                [
+                    1,
+                    2,
+                    3.4,
+                ],
+            ],
+            [
+                [
+                    1,
+                    '2',
+                    '3.4',
+                    5,
+                    'text',
+                ],
+                [
+                    '1',
+                    '2',
+                    3.4,
+                    '5',
+                ],
+            ],
+        ];
     }
 
     /**
@@ -999,7 +1264,7 @@ class CoreTest extends PmaTestCase
      *
      * @dataProvider provideTestSafeUnserialize
      */
-    function testSafeUnserialize($data, $expected)
+    public function testSafeUnserialize($data, $expected): void
     {
         $this->assertEquals(
             $expected,
@@ -1012,20 +1277,54 @@ class CoreTest extends PmaTestCase
      *
      * @return array
      */
-    function provideTestSafeUnserialize()
+    public function provideTestSafeUnserialize()
     {
-        return array(
-            array('s:6:"foobar";', 'foobar'),
-            array('foobar', null),
-            array('b:0;', false),
-            array('O:1:"a":1:{s:5:"value";s:3:"100";}', null),
-            array('O:8:"stdClass":1:{s:5:"field";O:8:"stdClass":0:{}}', null),
-            array('a:2:{i:0;s:90:"1234567890;a345678901234567890123456789012345678901234567890123456789012345678901234567890";i:1;O:8:"stdClass":0:{}}', null),
-            array(serialize(array(1, 2, 3)), array(1, 2, 3)),
-            array(serialize('string""'), 'string""'),
-            array(serialize(array('foo' => 'bar')), array('foo' => 'bar')),
-            array(serialize(array('1', new stdClass(), '2')), null),
-        );
+        return [
+            [
+                's:6:"foobar";',
+                'foobar',
+            ],
+            [
+                'foobar',
+                null,
+            ],
+            [
+                'b:0;',
+                false,
+            ],
+            [
+                'O:1:"a":1:{s:5:"value";s:3:"100";}',
+                null,
+            ],
+            [
+                'O:8:"stdClass":1:{s:5:"field";O:8:"stdClass":0:{}}',
+                null,
+            ],
+            [
+                'a:2:{i:0;s:90:"1234567890;a345678901234567890123456789012345678901234567890123456789012345678901234567890";i:1;O:8:"stdClass":0:{}}',
+                null,
+            ],
+            [
+                serialize([1, 2, 3]),
+                [
+                    1,
+                    2,
+                    3,
+                ],
+            ],
+            [
+                serialize('string""'),
+                'string""',
+            ],
+            [
+                serialize(['foo' => 'bar']),
+                ['foo' => 'bar'],
+            ],
+            [
+                serialize(['1', new stdClass(), '2']),
+                null,
+            ],
+        ];
     }
 
     /**
@@ -1038,7 +1337,7 @@ class CoreTest extends PmaTestCase
      *
      * @dataProvider provideTestSanitizeMySQLHost
      */
-    function testSanitizeMySQLHost($host, $expected)
+    public function testSanitizeMySQLHost($host, $expected): void
     {
         $this->assertEquals(
             $expected,
@@ -1051,14 +1350,26 @@ class CoreTest extends PmaTestCase
      *
      * @return array
      */
-    function provideTestSanitizeMySQLHost()
+    public function provideTestSanitizeMySQLHost()
     {
-        return array(
-            array('p:foo.bar', 'foo.bar'),
-            array('p:p:foo.bar', 'foo.bar'),
-            array('bar.baz', 'bar.baz'),
-            array('P:example.com', 'example.com'),
-        );
+        return [
+            [
+                'p:foo.bar',
+                'foo.bar',
+            ],
+            [
+                'p:p:foo.bar',
+                'foo.bar',
+            ],
+            [
+                'bar.baz',
+                'bar.baz',
+            ],
+            [
+                'P:example.com',
+                'example.com',
+            ],
+        ];
     }
 
     /**
@@ -1087,7 +1398,7 @@ class CoreTest extends PmaTestCase
      *
      * @return void
      */
-    function testMissingExtensionFatal()
+    public function testMissingExtensionFatal()
     {
         $ext = 'php_ext';
         $warn = 'The <a href="' . Core::getPHPDocLink('book.' . $ext . '.php')
@@ -1104,7 +1415,7 @@ class CoreTest extends PmaTestCase
      *
      * @return void
      */
-    function testMissingExtensionFatalWithExtra()
+    public function testMissingExtensionFatalWithExtra()
     {
         $ext = 'php_ext';
         $extra = 'Appended Extra String';
