@@ -4,16 +4,21 @@
  *
  * @package PhpMyAdmin-test
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Tests\Database;
 
 use PhpMyAdmin\Database\Qbe;
+use PhpMyAdmin\DatabaseInterface;
+use PhpMyAdmin\Relation;
+use PhpMyAdmin\Template;
 use PhpMyAdmin\Tests\PmaTestCase;
 use ReflectionClass;
 
 /**
  * Tests for PhpMyAdmin\Database\Qbe class
  *
- *  @package PhpMyAdmin-test
+ * @package PhpMyAdmin-test
  */
 class QbeTest extends PmaTestCase
 {
@@ -29,13 +34,13 @@ class QbeTest extends PmaTestCase
      * @access protected
      * @return void
      */
-    protected function setUp()
+    protected function setUp(): void
     {
-        $this->object = new Qbe('pma_test');
+        $this->object = new Qbe(new Relation($GLOBALS['dbi']), new Template(), $GLOBALS['dbi'], 'pma_test');
         $GLOBALS['server'] = 0;
         $GLOBALS['db'] = 'pma_test';
         //mock DBI
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -53,9 +58,10 @@ class QbeTest extends PmaTestCase
 
         $dbi->expects($this->any())
             ->method('getTableIndexes')
-            ->will($this->returnValue(array()));
+            ->will($this->returnValue([]));
 
         $GLOBALS['dbi'] = $dbi;
+        $this->object->dbi = $dbi;
     }
 
     /**
@@ -65,7 +71,7 @@ class QbeTest extends PmaTestCase
      * @access protected
      * @return void
      */
-    protected function tearDown()
+    protected function tearDown(): void
     {
         parent::tearDown();
         unset($this->object);
@@ -77,7 +83,7 @@ class QbeTest extends PmaTestCase
      * @param string $name   method name
      * @param array  $params parameters for the invocation
      *
-     * @return the output from the protected method.
+     * @return mixed the output from the protected method.
      */
     private function _callProtectedFunction($name, $params)
     {
@@ -94,25 +100,28 @@ class QbeTest extends PmaTestCase
      */
     public function testGetSortSelectCell()
     {
-        $this->assertContains(
+        $this->assertStringContainsString(
             'style="width:12ex" name="criteriaSort[1]"',
             $this->_callProtectedFunction(
                 '_getSortSelectCell',
-                array(1)
+                [1]
             )
         );
-        $this->assertNotContains(
+        $this->assertStringNotContainsString(
             'selected="selected"',
             $this->_callProtectedFunction(
                 '_getSortSelectCell',
-                array(1)
+                [1]
             )
         );
-        $this->assertContains(
+        $this->assertStringContainsString(
             'value="ASC" selected="selected">',
             $this->_callProtectedFunction(
                 '_getSortSelectCell',
-                array(1, 'ASC')
+                [
+                    1,
+                    'ASC',
+                ]
             )
         );
     }
@@ -124,32 +133,32 @@ class QbeTest extends PmaTestCase
      */
     public function testGetSortRow()
     {
-        $this->assertContains(
+        $this->assertStringContainsString(
             '<th>Sort:</th>',
             $this->_callProtectedFunction(
                 '_getSortRow',
-                array()
+                []
             )
         );
-        $this->assertContains(
+        $this->assertStringContainsString(
             'name="criteriaSort[0]"',
             $this->_callProtectedFunction(
                 '_getSortRow',
-                array()
+                []
             )
         );
-        $this->assertContains(
+        $this->assertStringContainsString(
             'name="criteriaSort[1]"',
             $this->_callProtectedFunction(
                 '_getSortRow',
-                array()
+                []
             )
         );
-        $this->assertContains(
+        $this->assertStringContainsString(
             'name="criteriaSort[2]"',
             $this->_callProtectedFunction(
                 '_getSortRow',
-                array()
+                []
             )
         );
     }
@@ -163,13 +172,13 @@ class QbeTest extends PmaTestCase
     {
         $this->assertEquals(
             '<tr class="noclick"><th>Show:</th><td class="center"><input type'
-            . '="checkbox" name="criteriaShow[0]" /></td><td class="center">'
-            . '<input type="checkbox" name="criteriaShow[1]" /></td><td '
-            . 'class="center"><input type="checkbox" name="criteriaShow[2]" />'
+            . '="checkbox" name="criteriaShow[0]"></td><td class="center">'
+            . '<input type="checkbox" name="criteriaShow[1]"></td><td '
+            . 'class="center"><input type="checkbox" name="criteriaShow[2]">'
             . '</td></tr>',
             $this->_callProtectedFunction(
                 '_getShowRow',
-                array()
+                []
             )
         );
     }
@@ -183,18 +192,18 @@ class QbeTest extends PmaTestCase
     {
         $this->assertEquals(
             '<tr class="noclick"><th>Criteria:</th><td class="center">'
-            . '<input type="hidden" name="prev_criteria[0]" value="" />'
+            . '<input type="hidden" name="prev_criteria[0]" value="">'
             . '<input type="text" name="criteria[0]" value="" class="textfield" '
-            . 'style="width: 12ex" size="20" /></td><td class="center">'
-            . '<input type="hidden" name="prev_criteria[1]" value="" />'
+            . 'style="width: 12ex" size="20"></td><td class="center">'
+            . '<input type="hidden" name="prev_criteria[1]" value="">'
             . '<input type="text" name="criteria[1]" value="" class="textfield" '
-            . 'style="width: 12ex" size="20" /></td><td class="center">'
-            . '<input type="hidden" name="prev_criteria[2]" value="" />'
+            . 'style="width: 12ex" size="20"></td><td class="center">'
+            . '<input type="hidden" name="prev_criteria[2]" value="">'
             . '<input type="text" name="criteria[2]" value="" class="textfield" '
-            . 'style="width: 12ex" size="20" /></td></tr>',
+            . 'style="width: 12ex" size="20"></td></tr>',
             $this->_callProtectedFunction(
                 '_getCriteriaInputboxRow',
-                array()
+                []
             )
         );
     }
@@ -206,25 +215,25 @@ class QbeTest extends PmaTestCase
      */
     public function testGetFootersOptions()
     {
-        $this->assertContains(
+        $this->assertStringContainsString(
             'Add/Delete criteria rows',
             $this->_callProtectedFunction(
                 '_getFootersOptions',
-                array('row')
+                ['row']
             )
         );
-        $this->assertContains(
+        $this->assertStringContainsString(
             'name="criteriaRowAdd"',
             $this->_callProtectedFunction(
                 '_getFootersOptions',
-                array('row')
+                ['row']
             )
         );
-        $this->assertContains(
+        $this->assertStringContainsString(
             '<option value="0" selected="selected">0</option>',
             $this->_callProtectedFunction(
                 '_getFootersOptions',
-                array('row')
+                ['row']
             )
         );
     }
@@ -236,25 +245,25 @@ class QbeTest extends PmaTestCase
      */
     public function testGetTableFooters()
     {
-        $this->assertContains(
+        $this->assertStringContainsString(
             'name="criteriaRowAdd"',
             $this->_callProtectedFunction(
                 '_getTableFooters',
-                array()
+                []
             )
         );
-        $this->assertContains(
+        $this->assertStringContainsString(
             'name="criteriaColumnAdd"',
             $this->_callProtectedFunction(
                 '_getTableFooters',
-                array()
+                []
             )
         );
-        $this->assertContains(
-            '<input type="submit" name="modify" value="Update Query" />',
+        $this->assertStringContainsString(
+            '<input class="btn btn-secondary" type="submit" name="modify" value="Update Query">',
             $this->_callProtectedFunction(
                 '_getTableFooters',
-                array()
+                []
             )
         );
     }
@@ -268,14 +277,14 @@ class QbeTest extends PmaTestCase
     {
         $this->assertEquals(
             '<td class="center"><strong>Or:</strong><input type="radio" '
-            . 'name="criteriaAndOrColumn[1]" value="or" />&nbsp;&nbsp;<strong>And:'
+            . 'name="criteriaAndOrColumn[1]" value="or">&nbsp;&nbsp;<strong>And:'
             . '</strong><input type="radio" name="criteriaAndOrColumn[1]" value='
-            . '"and" /><br />Ins<input type="checkbox" name="criteriaColumnInsert'
-            . '[1]" />&nbsp;&nbsp;Del<input type="checkbox" '
-            . 'name="criteriaColumnDelete[1]" /></td>',
+            . '"and"><br>Ins<input type="checkbox" name="criteriaColumnInsert'
+            . '[1]">&nbsp;&nbsp;Del<input type="checkbox" '
+            . 'name="criteriaColumnDelete[1]"></td>',
             $this->_callProtectedFunction(
                 '_getAndOrColCell',
-                array(1)
+                [1]
             )
         );
     }
@@ -290,22 +299,22 @@ class QbeTest extends PmaTestCase
         $this->assertEquals(
             '<tr class="noclick"><th>Modify:</th><td class="center"><strong>'
             . 'Or:</strong><input type="radio" name="criteriaAndOrColumn[0]" value'
-            . '="or" />&nbsp;&nbsp;<strong>And:</strong><input type="radio" name='
-            . '"criteriaAndOrColumn[0]" value="and" checked="checked" /><br />Ins'
-            . '<input type="checkbox" name="criteriaColumnInsert[0]" />&nbsp;&nbsp;'
-            . 'Del<input type="checkbox" name="criteriaColumnDelete[0]" /></td><td '
+            . '="or">&nbsp;&nbsp;<strong>And:</strong><input type="radio" name='
+            . '"criteriaAndOrColumn[0]" value="and" checked="checked"><br>Ins'
+            . '<input type="checkbox" name="criteriaColumnInsert[0]">&nbsp;&nbsp;'
+            . 'Del<input type="checkbox" name="criteriaColumnDelete[0]"></td><td '
             . 'class="center"><strong>Or:</strong><input type="radio" name="'
-            . 'criteriaAndOrColumn[1]" value="or" />&nbsp;&nbsp;<strong>And:'
+            . 'criteriaAndOrColumn[1]" value="or">&nbsp;&nbsp;<strong>And:'
             . '</strong><input type="radio" name="criteriaAndOrColumn[1]" value='
-            . '"and" checked="checked" /><br />Ins<input type="checkbox" name='
-            . '"criteriaColumnInsert[1]" />&nbsp;&nbsp;Del<input type="checkbox" '
-            . 'name="criteriaColumnDelete[1]" /></td><td class="center"><br />Ins'
-            . '<input type="checkbox" name="criteriaColumnInsert[2]" />&nbsp;&nbsp;'
-            . 'Del<input type="checkbox" name="criteriaColumnDelete[2]" /></td>'
+            . '"and" checked="checked"><br>Ins<input type="checkbox" name='
+            . '"criteriaColumnInsert[1]">&nbsp;&nbsp;Del<input type="checkbox" '
+            . 'name="criteriaColumnDelete[1]"></td><td class="center"><br>Ins'
+            . '<input type="checkbox" name="criteriaColumnInsert[2]">&nbsp;&nbsp;'
+            . 'Del<input type="checkbox" name="criteriaColumnDelete[2]"></td>'
             . '</tr>',
             $this->_callProtectedFunction(
                 '_getModifyColumnsRow',
-                array()
+                []
             )
         );
     }
@@ -320,16 +329,22 @@ class QbeTest extends PmaTestCase
         $this->assertEquals(
             '<td class="value nowrap"><!-- Row controls --><table class="nospac'
             . 'ing nopadding"><tr><td class="value nowrap"><small>Ins:</small>'
-            . '<input type="checkbox" name="criteriaRowInsert[3]" /></td><td '
+            . '<input type="checkbox" name="criteriaRowInsert[3]"></td><td '
             . 'class="value"><strong>And:</strong></td><td><input type="radio" '
-            . 'name="criteriaAndOrRow[3]" value="and" /></td></tr><tr><td class="'
+            . 'name="criteriaAndOrRow[3]" value="and"></td></tr><tr><td class="'
             . 'value nowrap"><small>Del:</small><input type="checkbox" '
-            . 'name="criteriaRowDelete[3]" /></td><td class="value"><strong>'
+            . 'name="criteriaRowDelete[3]"></td><td class="value"><strong>'
             . 'Or:</strong></td><td><input type="radio" name="criteriaAndOrRow[3]" '
-            . 'value="or" checked="checked" /></td></tr></table></td>',
+            . 'value="or" checked="checked"></td></tr></table></td>',
             $this->_callProtectedFunction(
                 '_getInsDelAndOrCell',
-                array(3, array('and' => '', 'or' => ' checked="checked"'))
+                [
+                    3,
+                    [
+                        'and' => '',
+                        'or' => ' checked="checked"',
+                    ],
+                ]
             )
         );
     }
@@ -343,14 +358,14 @@ class QbeTest extends PmaTestCase
     {
         $this->assertEquals(
             '<td class="center"><input type="text" name="Or2[0]" value="" class='
-            . '"textfield" style="width: 12ex" size="20" /></td><td class="center">'
+            . '"textfield" style="width: 12ex" size="20"></td><td class="center">'
             . '<input type="text" name="Or2[1]" value="" class="textfield" '
-            . 'style="width: 12ex" size="20" /></td><td class="center"><input '
+            . 'style="width: 12ex" size="20"></td><td class="center"><input '
             . 'type="text" name="Or2[2]" value="" class="textfield" style="width: '
-            . '12ex" size="20" /></td>',
+            . '12ex" size="20"></td>',
             $this->_callProtectedFunction(
                 '_getInputboxRow',
-                array(2)
+                [2]
             )
         );
     }
@@ -366,21 +381,24 @@ class QbeTest extends PmaTestCase
             '<tr class="noclick"><td class="value nowrap"><!-- Row controls'
             . ' --><table class="nospacing nopadding"><tr><td class="value '
             . 'nowrap"><small>Ins:</small><input type="checkbox" name="'
-            . 'criteriaRowInsert[0]" /></td><td class="value"><strong>And:'
+            . 'criteriaRowInsert[0]"></td><td class="value"><strong>And:'
             . '</strong></td><td><input type="radio" name="criteriaAndOrRow[0]" '
-            . 'value="and" /></td></tr><tr><td class="value nowrap"><small>Del:'
-            . '</small><input type="checkbox" name="criteriaRowDelete[0]" /></td>'
+            . 'value="and"></td></tr><tr><td class="value nowrap"><small>Del:'
+            . '</small><input type="checkbox" name="criteriaRowDelete[0]"></td>'
             . '<td class="value"><strong>Or:</strong></td><td><input type='
-            . '"radio" name="criteriaAndOrRow[0]" value="or" checked="checked" />'
+            . '"radio" name="criteriaAndOrRow[0]" value="or" checked="checked">'
             . '</td></tr></table></td><td class="center"><input type="text" '
             . 'name="Or0[0]" value="" class="textfield" style="width: 12ex" '
-            . 'size="20" /></td><td class="center"><input type="text" name="Or0[1]" '
-            . 'value="" class="textfield" style="width: 12ex" size="20" /></td><td '
+            . 'size="20"></td><td class="center"><input type="text" name="Or0[1]" '
+            . 'value="" class="textfield" style="width: 12ex" size="20"></td><td '
             . 'class="center"><input type="text" name="Or0[2]" value="" class='
-            . '"textfield" style="width: 12ex" size="20" /></td></tr>',
+            . '"textfield" style="width: 12ex" size="20"></td></tr>',
             $this->_callProtectedFunction(
                 '_getInsDelAndOrCriteriaRows',
-                array(2,3)
+                [
+                    2,
+                    3,
+                ]
             )
         );
     }
@@ -396,7 +414,7 @@ class QbeTest extends PmaTestCase
             '',
             $this->_callProtectedFunction(
                 '_getSelectClause',
-                array()
+                []
             )
         );
     }
@@ -412,7 +430,7 @@ class QbeTest extends PmaTestCase
             '',
             $this->_callProtectedFunction(
                 '_getWhereClause',
-                array()
+                []
             )
         );
     }
@@ -428,7 +446,7 @@ class QbeTest extends PmaTestCase
             '',
             $this->_callProtectedFunction(
                 '_getOrderByClause',
-                array()
+                []
             )
         );
     }
@@ -441,17 +459,24 @@ class QbeTest extends PmaTestCase
     public function testGetIndexes()
     {
         $this->assertEquals(
-            array(
-                'unique' => array(),
-                'index' => array()
-            ),
+            [
+                'unique' => [],
+                'index' => [],
+            ],
             $this->_callProtectedFunction(
                 '_getIndexes',
-                array(
-                    array('`table1`','table2'),
-                    array('column1', 'column2', 'column3'),
-                    array('column2')
-                )
+                [
+                    [
+                        '`table1`',
+                        'table2',
+                    ],
+                    [
+                        'column1',
+                        'column2',
+                        'column3',
+                    ],
+                    ['column2'],
+                ]
             )
         );
     }
@@ -464,16 +489,23 @@ class QbeTest extends PmaTestCase
     public function testGetLeftJoinColumnCandidates()
     {
         $this->assertEquals(
-            array(
-                0 => 'column2'
-            ),
+            [
+                0 => 'column2',
+            ],
             $this->_callProtectedFunction(
                 '_getLeftJoinColumnCandidates',
-                array(
-                    array('`table1`','table2'),
-                    array('column1', 'column2', 'column3'),
-                    array('column2')
-                )
+                [
+                    [
+                        '`table1`',
+                        'table2',
+                    ],
+                    [
+                        'column1',
+                        'column2',
+                        'column3',
+                    ],
+                    ['column2'],
+                ]
             )
         );
     }
@@ -489,12 +521,19 @@ class QbeTest extends PmaTestCase
             0,
             $this->_callProtectedFunction(
                 '_getMasterTable',
-                array(
-                    array('table1','table2'),
-                    array('column1', 'column2', 'column3'),
-                    array('column2'),
-                    array('qbe_test')
-                )
+                [
+                    [
+                        'table1',
+                        'table2',
+                    ],
+                    [
+                        'column1',
+                        'column2',
+                        'column3',
+                    ],
+                    ['column2'],
+                    ['qbe_test'],
+                ]
             )
         );
     }
@@ -506,20 +545,20 @@ class QbeTest extends PmaTestCase
      */
     public function testGetWhereClauseTablesAndColumns()
     {
-        $_POST['criteriaColumn'] = array(
+        $_POST['criteriaColumn'] = [
             'table1.id',
             'table1.value',
             'table1.name',
-            'table1.deleted'
-        );
+            'table1.deleted',
+        ];
         $this->assertEquals(
-            array(
-                'where_clause_tables' => array(),
-                'where_clause_columns' => array()
-            ),
+            [
+                'where_clause_tables' => [],
+                'where_clause_columns' => [],
+            ],
             $this->_callProtectedFunction(
                 '_getWhereClauseTablesAndColumns',
-                array()
+                []
             )
         );
     }
@@ -531,17 +570,17 @@ class QbeTest extends PmaTestCase
      */
     public function testGetFromClause()
     {
-        $_POST['criteriaColumn'] = array(
+        $_POST['criteriaColumn'] = [
             'table1.id',
             'table1.value',
             'table1.name',
-            'table1.deleted'
-        );
+            'table1.deleted',
+        ];
         $this->assertEquals(
             '`table1`',
             $this->_callProtectedFunction(
                 '_getFromClause',
-                array(array('`table1`.`id`'))
+                [['`table1`.`id`']]
             )
         );
     }
@@ -553,18 +592,17 @@ class QbeTest extends PmaTestCase
      */
     public function testGetSQLQuery()
     {
-        $_POST['criteriaColumn'] = array(
+        $_POST['criteriaColumn'] = [
             'table1.id',
             'table1.value',
             'table1.name',
-            'table1.deleted'
-        );
+            'table1.deleted',
+        ];
         $this->assertEquals(
-            'FROM `table1`
-',
+            'FROM `table1`' . "\n",
             $this->_callProtectedFunction(
                 '_getSQLQuery',
-                array(array('`table1`.`id`'))
+                [['`table1`.`id`']]
             )
         );
     }
