@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin-test
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Tests\Gis;
 
 use PhpMyAdmin\Gis\GisMultiPolygon;
@@ -31,7 +33,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
      * @access protected
      * @return void
      */
-    protected function setUp()
+    protected function setUp(): void
     {
         $this->object = GisMultiPolygon::singleton();
     }
@@ -43,7 +45,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
      * @access protected
      * @return void
      */
-    protected function tearDown()
+    protected function tearDown(): void
     {
         unset($this->object);
     }
@@ -55,51 +57,90 @@ class GisMultiPolygonTest extends GisGeomTestCase
      */
     private function _getData()
     {
-        return array(
-            'MULTIPOLYGON' => array(
+        return [
+            'MULTIPOLYGON' => [
                 'no_of_polygons' => 2,
-                0 => array(
+                0 => [
                     'no_of_lines' => 2,
-                    0 => array(
+                    0 => [
                         'no_of_points' => 5,
-                        0 => array('x' => 35, 'y' => 10),
-                        1 => array('x' => 10, 'y' => 20),
-                        2 => array('x' => 15, 'y' => 40),
-                        3 => array('x' => 45, 'y' => 45),
-                        4 => array('x' => 35, 'y' => 10),
-                    ),
-                    1 => array(
+                        0 => [
+                            'x' => 35,
+                            'y' => 10,
+                        ],
+                        1 => [
+                            'x' => 10,
+                            'y' => 20,
+                        ],
+                        2 => [
+                            'x' => 15,
+                            'y' => 40,
+                        ],
+                        3 => [
+                            'x' => 45,
+                            'y' => 45,
+                        ],
+                        4 => [
+                            'x' => 35,
+                            'y' => 10,
+                        ],
+                    ],
+                    1 => [
                         'no_of_points' => 4,
-                        0 => array('x' => 20, 'y' => 30),
-                        1 => array('x' => 35, 'y' => 32),
-                        2 => array('x' => 30, 'y' => 20),
-                        3 => array('x' => 20, 'y' => 30),
-                    )
-                ),
-                1 => array(
+                        0 => [
+                            'x' => 20,
+                            'y' => 30,
+                        ],
+                        1 => [
+                            'x' => 35,
+                            'y' => 32,
+                        ],
+                        2 => [
+                            'x' => 30,
+                            'y' => 20,
+                        ],
+                        3 => [
+                            'x' => 20,
+                            'y' => 30,
+                        ],
+                    ],
+                ],
+                1 => [
                     'no_of_lines' => 1,
-                    0 => array(
+                    0 => [
                         'no_of_points' => 4,
-                        0 => array('x' => 123, 'y' => 0),
-                        1 => array('x' => 23, 'y' => 30),
-                        2 => array('x' => 17, 'y' => 63),
-                        3 => array('x' => 123, 'y' => 0),
-                    )
-                )
-            )
-        );
+                        0 => [
+                            'x' => 123,
+                            'y' => 0,
+                        ],
+                        1 => [
+                            'x' => 23,
+                            'y' => 30,
+                        ],
+                        2 => [
+                            'x' => 17,
+                            'y' => 63,
+                        ],
+                        3 => [
+                            'x' => 123,
+                            'y' => 0,
+                        ],
+                    ],
+                ],
+            ],
+        ];
     }
 
     /**
      * data provider for testGenerateWkt
      *
-     * @return data for testGenerateWkt
+     * @return array data for testGenerateWkt
      */
     public function providerForTestGenerateWkt()
     {
-        $temp = array(
-            0 => $this->_getData()
-        );
+        $temp = [
+            0 => $this->_getData(),
+        ];
 
         $temp1 = $temp;
         $temp1[0]['MULTIPOLYGON']['no_of_polygons'] = 0;
@@ -110,45 +151,45 @@ class GisMultiPolygonTest extends GisGeomTestCase
         $temp3 = $temp;
         $temp3[0]['MULTIPOLYGON'][1][0]['no_of_points'] = 3;
 
-        return array(
-            array(
+        return [
+            [
                 $temp,
                 0,
                 null,
                 'MULTIPOLYGON(((35 10,10 20,15 40,45 45,35 10)'
-                    . ',(20 30,35 32,30 20,20 30)),((123 0,23 30,17 63,123 0)))'
-            ),
+                    . ',(20 30,35 32,30 20,20 30)),((123 0,23 30,17 63,123 0)))',
+            ],
             // at lease one polygon should be there
-            array(
+            [
                 $temp1,
                 0,
                 null,
                 'MULTIPOLYGON(((35 10,10 20,15 40,45 45,35 10)'
-                    . ',(20 30,35 32,30 20,20 30)))'
-            ),
+                    . ',(20 30,35 32,30 20,20 30)))',
+            ],
             // a polygon should have at least one ring
-            array(
+            [
                 $temp2,
                 0,
                 null,
                 'MULTIPOLYGON(((35 10,10 20,15 40,45 45,35 10)'
-                    . ',(20 30,35 32,30 20,20 30)),((123 0,23 30,17 63,123 0)))'
-            ),
+                    . ',(20 30,35 32,30 20,20 30)),((123 0,23 30,17 63,123 0)))',
+            ],
             // a ring should have at least four points
-            array(
+            [
                 $temp3,
                 0,
                 '0',
                 'MULTIPOLYGON(((35 10,10 20,15 40,45 45,35 10)'
-                    . ',(20 30,35 32,30 20,20 30)),((123 0,23 30,17 63,123 0)))'
-            ),
-        );
+                    . ',(20 30,35 32,30 20,20 30)),((123 0,23 30,17 63,123 0)))',
+            ],
+        ];
     }
 
     /**
      * data provider for testGenerateParams
      *
-     * @return data for testGenerateParams
+     * @return array data for testGenerateParams
      */
     public function providerForTestGenerateParams()
     {
@@ -157,25 +198,25 @@ class GisMultiPolygonTest extends GisGeomTestCase
         $temp1 = $this->_getData();
         $temp1['gis_type'] = 'MULTIPOLYGON';
 
-        return array(
-            array(
+        return [
+            [
                 "'MULTIPOLYGON(((35 10,10 20,15 40,45 45,35 10),"
                 . "(20 30,35 32,30 20,20 30)),((123 0,23 30,17 63,123 0)))',124",
                 null,
-                array(
+                [
                     'srid' => '124',
-                    0 => $temp
-                )
-            ),
-            array(
+                    0 => $temp,
+                ],
+            ],
+            [
                 'MULTIPOLYGON(((35 10,10 20,15 40,45 45,35 10)'
                     . ',(20 30,35 32,30 20,20 30)),((123 0,23 30,17 63,123 0)))',
                 2,
-                array(
-                    2 => $temp1
-                )
-            )
-        );
+                [
+                    2 => $temp1,
+                ],
+            ],
+        ];
     }
 
     /**
@@ -187,7 +228,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
      * @dataProvider providerForTestGetShape
      * @return void
      */
-    public function testGetShape($row_data, $shape)
+    public function testGetShape($row_data, $shape): void
     {
         $this->assertEquals($this->object->getShape($row_data), $shape);
     }
@@ -195,96 +236,143 @@ class GisMultiPolygonTest extends GisGeomTestCase
     /**
      * data provider for testGetShape
      *
-     * @return data for testGetShape
+     * @return array data for testGetShape
      */
     public function providerForTestGetShape()
     {
-        return array(
-            array(
-                array(
-                    'parts' => array(
-                        0 => array(
-                            'points' => array(
-                                0 => array('x' => 10, 'y' => 10),
-                                1 => array('x' => 10, 'y' => 40),
-                                2 => array('x' => 50, 'y' => 40),
-                                3 => array('x' => 50, 'y' => 10),
-                                4 => array('x' => 10, 'y' => 10),
-                            ),
-                        ),
-                        1 => array(
-                            'points' => array(
-                                0 => array('x' => 60, 'y' => 40),
-                                1 => array('x' => 75, 'y' => 65),
-                                2 => array('x' => 90, 'y' => 40),
-                                3 => array('x' => 60, 'y' => 40),
-                            ),
-                        ),
-                        2 => array(
-                            'points' => array(
-                                0 => array('x' => 20, 'y' => 20),
-                                1 => array('x' => 40, 'y' => 20),
-                                2 => array('x' => 25, 'y' => 30),
-                                3 => array('x' => 20, 'y' => 20),
-                            ),
-                        ),
-                    ),
-                ),
+        return [
+            [
+                [
+                    'parts' => [
+                        0 => [
+                            'points' => [
+                                0 => [
+                                    'x' => 10,
+                                    'y' => 10,
+                                ],
+                                1 => [
+                                    'x' => 10,
+                                    'y' => 40,
+                                ],
+                                2 => [
+                                    'x' => 50,
+                                    'y' => 40,
+                                ],
+                                3 => [
+                                    'x' => 50,
+                                    'y' => 10,
+                                ],
+                                4 => [
+                                    'x' => 10,
+                                    'y' => 10,
+                                ],
+                            ],
+                        ],
+                        1 => [
+                            'points' => [
+                                0 => [
+                                    'x' => 60,
+                                    'y' => 40,
+                                ],
+                                1 => [
+                                    'x' => 75,
+                                    'y' => 65,
+                                ],
+                                2 => [
+                                    'x' => 90,
+                                    'y' => 40,
+                                ],
+                                3 => [
+                                    'x' => 60,
+                                    'y' => 40,
+                                ],
+                            ],
+                        ],
+                        2 => [
+                            'points' => [
+                                0 => [
+                                    'x' => 20,
+                                    'y' => 20,
+                                ],
+                                1 => [
+                                    'x' => 40,
+                                    'y' => 20,
+                                ],
+                                2 => [
+                                    'x' => 25,
+                                    'y' => 30,
+                                ],
+                                3 => [
+                                    'x' => 20,
+                                    'y' => 20,
+                                ],
+                            ],
+                        ],
+                    ],
+                ],
                 'MULTIPOLYGON(((10 10,10 40,50 40,50 10,10 10),(20 20,40 20,25 30'
-                    . ',20 20)),((60 40,75 65,90 40,60 40)))'
-            )
-        );
+                    . ',20 20)),((60 40,75 65,90 40,60 40)))',
+            ],
+        ];
     }
 
     /**
      * data provider for testScaleRow
      *
-     * @return data for testScaleRow
+     * @return array data for testScaleRow
      */
     public function providerForTestScaleRow()
     {
-        return array(
-            array(
+        return [
+            [
                 'MULTIPOLYGON(((136 40,147 83,16 75,136 40)),'
                     . '((105 0,56 20,78 73,105 0)))',
-                array(
+                [
                     'minX' => 16,
                     'maxX' => 147,
                     'minY' => 0,
-                    'maxY' => 83
-                )
-            ),
-            array(
+                    'maxY' => 83,
+                ],
+            ],
+            [
                 'MULTIPOLYGON(((35 10,10 20,15 40,45 45,35 10),(20 30,35 32,30 20'
                     . ',20 30)),((105 0,56 20,78 73,105 0)))',
-                array(
+                [
                     'minX' => 10,
                     'maxX' => 105,
                     'minY' => 0,
-                    'maxY' => 73
-                )
-            )
-        );
+                    'maxY' => 73,
+                ],
+            ],
+        ];
     }
 
 
     /**
      * test case for prepareRowAsPng() method
      *
-     * @param string $spatial    GIS MULTIPOLYGON object
-     * @param string $label      label for the GIS MULTIPOLYGON object
-     * @param string $fill_color color for the GIS MULTIPOLYGON object
-     * @param array  $scale_data array containing data related to scaling
-     * @param object $image      image object
+     * @param string   $spatial    GIS MULTIPOLYGON object
+     * @param string   $label      label for the GIS MULTIPOLYGON object
+     * @param string   $fill_color color for the GIS MULTIPOLYGON object
+     * @param array    $scale_data array containing data related to scaling
+     * @param resource $image      image object
      *
      * @return void
      * @dataProvider providerForPrepareRowAsPng
      */
     public function testPrepareRowAsPng(
-        $spatial, $label, $fill_color, $scale_data, $image
+        $spatial,
+        $label,
+        $fill_color,
+        $scale_data,
+        $image
     ) {
         $return = $this->object->prepareRowAsPng(
-            $spatial, $label, $fill_color, $scale_data, $image
+            $spatial,
+            $label,
+            $fill_color,
+            $scale_data,
+            $image
         );
         $this->assertImage($return);
     }
@@ -299,22 +387,22 @@ class GisMultiPolygonTest extends GisGeomTestCase
         if (! function_exists('imagecreatetruecolor')) {
             $this->markTestSkipped('GD extension missing!');
         }
-        return array(
-            array(
+        return [
+            [
                 'MULTIPOLYGON(((136 40,147 83,16 75,136 40)),'
                     . '((105 0,56 20,78 73,105 0)))',
                 'image',
                 '#B02EE0',
-                array(
+                [
                     'x' => 12,
                     'y' => 69,
                     'scale' => 2,
-                    'height' => 150
-                ),
-                imagecreatetruecolor('120', '150'),
-            )
+                    'height' => 150,
+                ],
+                imagecreatetruecolor(120, 150),
+            ],
 
-        );
+        ];
     }
 
     /**
@@ -324,16 +412,24 @@ class GisMultiPolygonTest extends GisGeomTestCase
      * @param string $label      label for the GIS MULTIPOLYGON object
      * @param string $fill_color color for the GIS MULTIPOLYGON object
      * @param array  $scale_data array containing data related to scaling
-     * @param object $pdf        TCPDF instance
+     * @param TCPDF  $pdf        TCPDF instance
      *
      * @return void
      * @dataProvider providerForPrepareRowAsPdf
      */
     public function testPrepareRowAsPdf(
-        $spatial, $label, $fill_color, $scale_data, $pdf
+        $spatial,
+        $label,
+        $fill_color,
+        $scale_data,
+        $pdf
     ) {
         $return = $this->object->prepareRowAsPdf(
-            $spatial, $label, $fill_color, $scale_data, $pdf
+            $spatial,
+            $label,
+            $fill_color,
+            $scale_data,
+            $pdf
         );
         $this->assertInstanceOf('TCPDF', $return);
     }
@@ -345,21 +441,21 @@ class GisMultiPolygonTest extends GisGeomTestCase
      */
     public function providerForPrepareRowAsPdf()
     {
-        return array(
-            array(
+        return [
+            [
                 'MULTIPOLYGON(((136 40,147 83,16 75,136 40)),'
                     . '((105 0,56 20,78 73,105 0)))',
                 'pdf',
                 '#B02EE0',
-                array(
+                [
                     'x' => 12,
                     'y' => 69,
                     'scale' => 2,
-                    'height' => 150
-                ),
+                    'height' => 150,
+                ],
                 new TCPDF(),
-            )
-        );
+            ],
+        ];
     }
 
     /**
@@ -375,10 +471,17 @@ class GisMultiPolygonTest extends GisGeomTestCase
      * @dataProvider providerForPrepareRowAsSvg
      */
     public function testPrepareRowAsSvg(
-        $spatial, $label, $fill_color, $scale_data, $output
+        $spatial,
+        $label,
+        $fill_color,
+        $scale_data,
+        $output
     ) {
         $string = $this->object->prepareRowAsSvg(
-            $spatial, $label, $fill_color, $scale_data
+            $spatial,
+            $label,
+            $fill_color,
+            $scale_data
         );
         $this->assertEquals(1, preg_match($output, $string));
     }
@@ -390,27 +493,27 @@ class GisMultiPolygonTest extends GisGeomTestCase
      */
     public function providerForPrepareRowAsSvg()
     {
-        return array(
-            array(
+        return [
+            [
                 'MULTIPOLYGON(((136 40,147 83,16 75,136 40)),'
                     . '((105 0,56 20,78 73,105 0)))',
                 'svg',
                 '#B02EE0',
-                array(
+                [
                     'x' => 12,
                     'y' => 69,
                     'scale' => 2,
-                    'height' => 150
-                ),
+                    'height' => 150,
+                ],
                 '/^(<path d=" M 248, 208 L 270, 122 L 8, 138 Z " name="svg" class="'
                 . 'multipolygon vector" stroke="black" stroke-width="0.5" fill="'
                 . '#B02EE0" fill-rule="evenodd" fill-opacity="0.8" id="svg)(\d+)'
                 . '("\/><path d=" M 186, 288 L 88, 248 L 132, 142 Z " name="svg" '
                 . 'class="multipolygon vector" stroke="black" stroke-width="0.5" '
                 . 'fill="#B02EE0" fill-rule="evenodd" fill-opacity="0.8" id="svg)'
-                . '(\d+)("\/>)$/'
-            )
-        );
+                . '(\d+)("\/>)$/',
+            ],
+        ];
     }
 
     /**
@@ -427,12 +530,21 @@ class GisMultiPolygonTest extends GisGeomTestCase
      * @dataProvider providerForPrepareRowAsOl
      */
     public function testPrepareRowAsOl(
-        $spatial, $srid, $label, $fill_color, $scale_data, $output
+        $spatial,
+        $srid,
+        $label,
+        $fill_color,
+        $scale_data,
+        $output
     ) {
         $this->assertEquals(
             $output,
             $this->object->prepareRowAsOl(
-                $spatial, $srid, $label, $fill_color, $scale_data
+                $spatial,
+                $srid,
+                $label,
+                $fill_color,
+                $scale_data
             )
         );
     }
@@ -444,19 +556,19 @@ class GisMultiPolygonTest extends GisGeomTestCase
      */
     public function providerForPrepareRowAsOl()
     {
-        return array(
-            array(
+        return [
+            [
                 'MULTIPOLYGON(((136 40,147 83,16 75,136 40)),'
                     . '((105 0,56 20,78 73,105 0)))',
                 4326,
                 'Ol',
                 '#B02EE0',
-                array(
+                [
                     'minX' => '0',
                     'minY' => '0',
                     'maxX' => '1',
                     'maxY' => '1',
-                ),
+                ],
                 'bound = new OpenLayers.Bounds(); bound.extend(new OpenLayers.'
                 . 'LonLat(0, 0).transform(new OpenLayers.Projection("EPSG:4326"), '
                 . 'map.getProjectionObject())); bound.extend(new OpenLayers.LonLat'
@@ -482,8 +594,8 @@ class GisMultiPolygonTest extends GisGeomTestCase
                 . '()), (new OpenLayers.Geometry.Point(105,0)).transform(new Open'
                 . 'Layers.Projection("EPSG:4326"), map.getProjectionObject()))))))'
                 . '), null, {"strokeColor":"#000000","strokeWidth":0.5,"fillColor":'
-                . '"#B02EE0","fillOpacity":0.8,"label":"Ol","fontSize":10}));'
-            )
-        );
+                . '"#B02EE0","fillOpacity":0.8,"label":"Ol","fontSize":10}));',
+            ],
+        ];
     }
 }
