@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin-test
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Tests\Gis;
 
 use PhpMyAdmin\Gis\GisPolygon;
@@ -31,7 +33,7 @@ class GisPolygonTest extends GisGeomTestCase
      * @access protected
      * @return void
      */
-    protected function setUp()
+    protected function setUp(): void
     {
         $this->object = GisPolygon::singleton();
     }
@@ -43,7 +45,7 @@ class GisPolygonTest extends GisGeomTestCase
      * @access protected
      * @return void
      */
-    protected function tearDown()
+    protected function tearDown(): void
     {
         unset($this->object);
     }
@@ -55,38 +57,65 @@ class GisPolygonTest extends GisGeomTestCase
      */
     private function _getData()
     {
-        return array(
-            'POLYGON' => array(
+        return [
+            'POLYGON' => [
                 'no_of_lines' => 2,
-                0 => array(
+                0 => [
                     'no_of_points' => 5,
-                    0 => array('x' => 35, 'y' => 10),
-                    1 => array('x' => 10, 'y' => 20),
-                    2 => array('x' => 15, 'y' => 40),
-                    3 => array('x' => 45, 'y' => 45),
-                    4 => array('x' => 35, 'y' => 10),
-                ),
-                1 => array(
+                    0 => [
+                        'x' => 35,
+                        'y' => 10,
+                    ],
+                    1 => [
+                        'x' => 10,
+                        'y' => 20,
+                    ],
+                    2 => [
+                        'x' => 15,
+                        'y' => 40,
+                    ],
+                    3 => [
+                        'x' => 45,
+                        'y' => 45,
+                    ],
+                    4 => [
+                        'x' => 35,
+                        'y' => 10,
+                    ],
+                ],
+                1 => [
                     'no_of_points' => 4,
-                    0 => array('x' => 20, 'y' => 30),
-                    1 => array('x' => 35, 'y' => 32),
-                    2 => array('x' => 30, 'y' => 20),
-                    3 => array('x' => 20, 'y' => 30),
-                )
-            )
-        );
+                    0 => [
+                        'x' => 20,
+                        'y' => 30,
+                    ],
+                    1 => [
+                        'x' => 35,
+                        'y' => 32,
+                    ],
+                    2 => [
+                        'x' => 30,
+                        'y' => 20,
+                    ],
+                    3 => [
+                        'x' => 20,
+                        'y' => 30,
+                    ],
+                ],
+            ],
+        ];
     }
 
     /**
      * data provider for testGenerateWkt
      *
-     * @return data for testGenerateWkt
+     * @return array data for testGenerateWkt
      */
     public function providerForTestGenerateWkt()
     {
-        $temp = array(
-            0 => $this->_getData()
-        );
+        $temp = [
+            0 => $this->_getData(),
+        ];
 
         $temp1 = $temp;
         unset($temp1[0]['POLYGON'][1][3]['y']);
@@ -97,55 +126,55 @@ class GisPolygonTest extends GisGeomTestCase
         $temp3 = $temp;
         $temp3[0]['POLYGON'][1]['no_of_points'] = 3;
 
-        return array(
-            array(
+        return [
+            [
                 $temp,
                 0,
                 null,
-                'POLYGON((35 10,10 20,15 40,45 45,35 10),(20 30,35 32,30 20,20 30))'
-            ),
+                'POLYGON((35 10,10 20,15 40,45 45,35 10),(20 30,35 32,30 20,20 30))',
+            ],
             // values at undefined index
-            array(
+            [
                 $temp,
                 1,
                 null,
-                'POLYGON(( , , , ))'
-            ),
+                'POLYGON(( , , , ))',
+            ],
             // if a coordinate is missing, default is empty string
-            array(
+            [
                 $temp1,
                 0,
                 null,
-                'POLYGON((35 10,10 20,15 40,45 45,35 10),(20 30,35 32,30 20,20 ))'
-            ),
+                'POLYGON((35 10,10 20,15 40,45 45,35 10),(20 30,35 32,30 20,20 ))',
+            ],
             // missing coordinates are replaced with provided values (3rd parameter)
-            array(
+            [
                 $temp1,
                 0,
                 '0',
-                'POLYGON((35 10,10 20,15 40,45 45,35 10),(20 30,35 32,30 20,20 0))'
-            ),
+                'POLYGON((35 10,10 20,15 40,45 45,35 10),(20 30,35 32,30 20,20 0))',
+            ],
             // should have at least one ring
-            array(
+            [
                 $temp2,
                 0,
                 '0',
-                'POLYGON((35 10,10 20,15 40,45 45,35 10))'
-            ),
+                'POLYGON((35 10,10 20,15 40,45 45,35 10))',
+            ],
             // a ring should have at least four points
-            array(
+            [
                 $temp3,
                 0,
                 '0',
-                'POLYGON((35 10,10 20,15 40,45 45,35 10),(20 30,35 32,30 20,20 30))'
-            ),
-        );
+                'POLYGON((35 10,10 20,15 40,45 45,35 10),(20 30,35 32,30 20,20 30))',
+            ],
+        ];
     }
 
     /**
      * data provider for testGenerateParams
      *
-     * @return data for testGenerateParams
+     * @return array data for testGenerateParams
      */
     public function providerForTestGenerateParams()
     {
@@ -154,24 +183,24 @@ class GisPolygonTest extends GisGeomTestCase
         $temp1 = $temp;
         $temp1['gis_type'] = 'POLYGON';
 
-        return array(
-            array(
+        return [
+            [
                 "'POLYGON((35 10,10 20,15 40,45 45,35 10),"
                     . "(20 30,35 32,30 20,20 30))',124",
                 null,
-                array(
+                [
                     'srid' => '124',
-                    0 => $temp
-                )
-            ),
-            array(
+                    0 => $temp,
+                ],
+            ],
+            [
                 'POLYGON((35 10,10 20,15 40,45 45,35 10),(20 30,35 32,30 20,20 30))',
                 2,
-                array(
-                    2 => $temp1
-                )
-            )
-        );
+                [
+                    2 => $temp1,
+                ],
+            ],
+        ];
     }
 
     /**
@@ -183,7 +212,7 @@ class GisPolygonTest extends GisGeomTestCase
      * @dataProvider providerForTestArea
      * @return void
      */
-    public function testArea($ring, $area)
+    public function testArea($ring, $area): void
     {
         $this->assertEquals($this->object->area($ring), $area);
     }
@@ -191,39 +220,69 @@ class GisPolygonTest extends GisGeomTestCase
     /**
      * data provider for testArea
      *
-     * @return data for testArea
+     * @return array data for testArea
      */
     public function providerForTestArea()
     {
-        return array(
-            array(
-                array(
-                    0 => array('x' => 35, 'y' => 10),
-                    1 => array('x' => 10, 'y' => 10),
-                    2 => array('x' => 15, 'y' => 40)
-                ),
-                -375.00
-            ),
+        return [
+            [
+                [
+                    0 => [
+                        'x' => 35,
+                        'y' => 10,
+                    ],
+                    1 => [
+                        'x' => 10,
+                        'y' => 10,
+                    ],
+                    2 => [
+                        'x' => 15,
+                        'y' => 40,
+                    ],
+                ],
+                -375.00,
+            ],
             // first point of the ring repeated as the last point
-            array(
-                array(
-                    0 => array('x' => 35, 'y' => 10),
-                    1 => array('x' => 10, 'y' => 10),
-                    2 => array('x' => 15, 'y' => 40),
-                    3 => array('x' => 35, 'y' => 10)
-                ),
-                -375.00
-            ),
+            [
+                [
+                    0 => [
+                        'x' => 35,
+                        'y' => 10,
+                    ],
+                    1 => [
+                        'x' => 10,
+                        'y' => 10,
+                    ],
+                    2 => [
+                        'x' => 15,
+                        'y' => 40,
+                    ],
+                    3 => [
+                        'x' => 35,
+                        'y' => 10,
+                    ],
+                ],
+                -375.00,
+            ],
             // anticlockwise gives positive area
-            array(
-                array(
-                    0 => array('x' => 15, 'y' => 40),
-                    1 => array('x' => 10, 'y' => 10),
-                    2 => array('x' => 35, 'y' => 10)
-                ),
-                375.00
-            )
-        );
+            [
+                [
+                    0 => [
+                        'x' => 15,
+                        'y' => 40,
+                    ],
+                    1 => [
+                        'x' => 10,
+                        'y' => 10,
+                    ],
+                    2 => [
+                        'x' => 35,
+                        'y' => 10,
+                    ],
+                ],
+                375.00,
+            ],
+        ];
     }
 
     /**
@@ -236,7 +295,7 @@ class GisPolygonTest extends GisGeomTestCase
      * @dataProvider providerForTestIsPointInsidePolygon
      * @return void
      */
-    public function testIsPointInsidePolygon($point, $polygon, $isInside)
+    public function testIsPointInsidePolygon($point, $polygon, $isInside): void
     {
         $this->assertEquals(
             $this->object->isPointInsidePolygon($point, $polygon),
@@ -247,43 +306,67 @@ class GisPolygonTest extends GisGeomTestCase
     /**
      * data provider for testIsPointInsidePolygon
      *
-     * @return data for testIsPointInsidePolygon
+     * @return array data for testIsPointInsidePolygon
      */
     public function providerForTestIsPointInsidePolygon()
     {
-        $ring = array(
-            0 => array('x' => 35, 'y' => 10),
-            1 => array('x' => 10, 'y' => 10),
-            2 => array('x' => 15, 'y' => 40),
-            3 => array('x' => 35, 'y' => 10)
-        );
+        $ring = [
+            0 => [
+                'x' => 35,
+                'y' => 10,
+            ],
+            1 => [
+                'x' => 10,
+                'y' => 10,
+            ],
+            2 => [
+                'x' => 15,
+                'y' => 40,
+            ],
+            3 => [
+                'x' => 35,
+                'y' => 10,
+            ],
+        ];
 
-        return array(
+        return [
             // point inside the ring
-            array(
-                array('x' => 20, 'y' => 15),
+            [
+                [
+                    'x' => 20,
+                    'y' => 15,
+                ],
                 $ring,
-                true
-            ),
+                true,
+            ],
             // point on an edge of the ring
-            array(
-                array('x' => 20, 'y' => 10),
+            [
+                [
+                    'x' => 20,
+                    'y' => 10,
+                ],
                 $ring,
-                false
-            ),
+                false,
+            ],
             // point on a vertex of the ring
-            array(
-                array('x' => 10, 'y' => 10),
+            [
+                [
+                    'x' => 10,
+                    'y' => 10,
+                ],
                 $ring,
-                false
-            ),
+                false,
+            ],
             // point outside the ring
-            array(
-                array('x' => 5, 'y' => 10),
+            [
+                [
+                    'x' => 5,
+                    'y' => 10,
+                ],
                 $ring,
-                false
-            ),
-        );
+                false,
+            ],
+        ];
     }
 
     /**
@@ -294,7 +377,7 @@ class GisPolygonTest extends GisGeomTestCase
      * @dataProvider providerForTestGetPointOnSurface
      * @return void
      */
-    public function testGetPointOnSurface($ring)
+    public function testGetPointOnSurface($ring): void
     {
         $this->assertEquals(
             $this->object->isPointInsidePolygon(
@@ -308,7 +391,7 @@ class GisPolygonTest extends GisGeomTestCase
     /**
      * data provider for testGetPointOnSurface
      *
-     * @return data for testGetPointOnSurface
+     * @return array data for testGetPointOnSurface
      */
     public function providerForTestGetPointOnSurface()
     {
@@ -316,63 +399,71 @@ class GisPolygonTest extends GisGeomTestCase
         unset($temp['POLYGON'][0]['no_of_points']);
         unset($temp['POLYGON'][1]['no_of_points']);
 
-        return array(
-            array(
-                $temp['POLYGON'][0]
-            ),
-            array(
-                $temp['POLYGON'][1]
-            )
-        );
+        return [
+            [
+                $temp['POLYGON'][0],
+            ],
+            [
+                $temp['POLYGON'][1],
+            ],
+        ];
     }
 
     /**
      * data provider for testScaleRow
      *
-     * @return data for testScaleRow
+     * @return array data for testScaleRow
      */
     public function providerForTestScaleRow()
     {
-        return array(
-            array(
+        return [
+            [
                 'POLYGON((123 0,23 30,17 63,123 0))',
-                array(
+                [
                     'minX' => 17,
                     'maxX' => 123,
                     'minY' => 0,
                     'maxY' => 63,
-                )
-            ),
-            array(
+                ],
+            ],
+            [
                 'POLYGON((35 10,10 20,15 40,45 45,35 10),'
                     . '(20 30,35 32,30 20,20 30)))',
-                array(
+                [
                     'minX' => 10,
                     'maxX' => 45,
                     'minY' => 10,
-                    'maxY' => 45
-                )
-            ),
-        );
+                    'maxY' => 45,
+                ],
+            ],
+        ];
     }
 
     /**
      * test case for prepareRowAsPng()
      *
-     * @param string $spatial    GIS POLYGON object
-     * @param string $label      label for the GIS POLYGON object
-     * @param string $fill_color color for the GIS POLYGON object
-     * @param array  $scale_data array containing data related to scaling
-     * @param object $image      image object
+     * @param string   $spatial    GIS POLYGON object
+     * @param string   $label      label for the GIS POLYGON object
+     * @param string   $fill_color color for the GIS POLYGON object
+     * @param array    $scale_data array containing data related to scaling
+     * @param resource $image      image object
      *
      * @return void
      * @dataProvider providerForPrepareRowAsPng
      */
     public function testPrepareRowAsPng(
-        $spatial, $label, $fill_color, $scale_data, $image
+        $spatial,
+        $label,
+        $fill_color,
+        $scale_data,
+        $image
     ) {
         $return = $this->object->prepareRowAsPng(
-            $spatial, $label, $fill_color, $scale_data, $image
+            $spatial,
+            $label,
+            $fill_color,
+            $scale_data,
+            $image
         );
         $this->assertImage($return);
     }
@@ -387,20 +478,20 @@ class GisPolygonTest extends GisGeomTestCase
         if (! function_exists('imagecreatetruecolor')) {
             $this->markTestSkipped('GD extension missing!');
         }
-        return array(
-            array(
+        return [
+            [
                 'POLYGON((123 0,23 30,17 63,123 0))',
                 'image',
                 '#B02EE0',
-                array(
+                [
                     'x' => 12,
                     'y' => 69,
                     'scale' => 2,
-                    'height' => 150
-                ),
-                imagecreatetruecolor('120', '150')
-            )
-        );
+                    'height' => 150,
+                ],
+                imagecreatetruecolor(120, 150),
+            ],
+        ];
     }
 
     /**
@@ -410,16 +501,24 @@ class GisPolygonTest extends GisGeomTestCase
      * @param string $label      label for the GIS POLYGON object
      * @param string $fill_color color for the GIS POLYGON object
      * @param array  $scale_data array containing data related to scaling
-     * @param object $pdf        TCPDF instance
+     * @param TCPDF  $pdf        TCPDF instance
      *
      * @return void
      * @dataProvider providerForPrepareRowAsPdf
      */
     public function testPrepareRowAsPdf(
-        $spatial, $label, $fill_color, $scale_data, $pdf
+        $spatial,
+        $label,
+        $fill_color,
+        $scale_data,
+        $pdf
     ) {
         $return = $this->object->prepareRowAsPdf(
-            $spatial, $label, $fill_color, $scale_data, $pdf
+            $spatial,
+            $label,
+            $fill_color,
+            $scale_data,
+            $pdf
         );
         $this->assertInstanceOf('TCPDF', $return);
     }
@@ -431,20 +530,20 @@ class GisPolygonTest extends GisGeomTestCase
      */
     public function providerForPrepareRowAsPdf()
     {
-        return array(
-            array(
+        return [
+            [
                 'POLYGON((123 0,23 30,17 63,123 0))',
                 'pdf',
                 '#B02EE0',
-                array(
+                [
                     'x' => 12,
                     'y' => 69,
                     'scale' => 2,
-                    'height' => 150
-                ),
+                    'height' => 150,
+                ],
                 new TCPDF(),
-            )
-        );
+            ],
+        ];
     }
 
     /**
@@ -460,10 +559,17 @@ class GisPolygonTest extends GisGeomTestCase
      * @dataProvider providerForPrepareRowAsSvg
      */
     public function testPrepareRowAsSvg(
-        $spatial, $label, $fill_color, $scale_data, $output
+        $spatial,
+        $label,
+        $fill_color,
+        $scale_data,
+        $output
     ) {
         $string = $this->object->prepareRowAsSvg(
-            $spatial, $label, $fill_color, $scale_data
+            $spatial,
+            $label,
+            $fill_color,
+            $scale_data
         );
         $this->assertEquals(1, preg_match($output, $string));
     }
@@ -475,23 +581,23 @@ class GisPolygonTest extends GisGeomTestCase
      */
     public function providerForPrepareRowAsSvg()
     {
-        return array(
-            array(
+        return [
+            [
                 'POLYGON((123 0,23 30,17 63,123 0))',
                 'svg',
                 '#B02EE0',
-                array(
+                [
                     'x' => 12,
                     'y' => 69,
                     'scale' => 2,
-                    'height' => 150
-                ),
+                    'height' => 150,
+                ],
                 '/^(<path d=" M 222, 288 L 22, 228 L 10, 162 Z " name="svg" '
                 . 'id="svg)(\d+)(" class="polygon vector" stroke="black" '
                 . 'stroke-width="0.5" fill="#B02EE0" fill-rule="evenodd" '
-                . 'fill-opacity="0.8"\/>)$/'
-            )
-        );
+                . 'fill-opacity="0.8"\/>)$/',
+            ],
+        ];
     }
 
     /**
@@ -508,12 +614,21 @@ class GisPolygonTest extends GisGeomTestCase
      * @dataProvider providerForPrepareRowAsOl
      */
     public function testPrepareRowAsOl(
-        $spatial, $srid, $label, $fill_color, $scale_data, $output
+        $spatial,
+        $srid,
+        $label,
+        $fill_color,
+        $scale_data,
+        $output
     ) {
         $this->assertEquals(
             $output,
             $this->object->prepareRowAsOl(
-                $spatial, $srid, $label, $fill_color, $scale_data
+                $spatial,
+                $srid,
+                $label,
+                $fill_color,
+                $scale_data
             )
         );
     }
@@ -525,18 +640,18 @@ class GisPolygonTest extends GisGeomTestCase
      */
     public function providerForPrepareRowAsOl()
     {
-        return array(
-            array(
+        return [
+            [
                 'POLYGON((123 0,23 30,17 63,123 0))',
                 4326,
                 'Ol',
                 '#B02EE0',
-                array(
+                [
                     'minX' => '0',
                     'minY' => '0',
                     'maxX' => '1',
                     'maxY' => '1',
-                ),
+                ],
                 'bound = new OpenLayers.Bounds(); bound.extend(new OpenLayers.Lon'
                 . 'Lat(0, 0).transform(new OpenLayers.Projection("EPSG:4326"), '
                 . 'map.getProjectionObject())); bound.extend(new OpenLayers.'
@@ -553,9 +668,9 @@ class GisPolygonTest extends GisGeomTestCase
                 . 'Geometry.Point(123,0)).transform(new OpenLayers.Projection'
                 . '("EPSG:4326"), map.getProjectionObject()))))), null, {"stroke'
                 . 'Color":"#000000","strokeWidth":0.5,"fillColor":"#B02EE0",'
-                . '"fillOpacity":0.8,"label":"Ol","fontSize":10}));'
-            )
-        );
+                . '"fillOpacity":0.8,"label":"Ol","fontSize":10}));',
+            ],
+        ];
     }
 
     /**
@@ -566,7 +681,7 @@ class GisPolygonTest extends GisGeomTestCase
      * @return void
      * @dataProvider providerForIsOuterRing
      */
-    public function testIsOuterRing($ring)
+    public function testIsOuterRing($ring): void
     {
         $this->assertTrue($this->object->isOuterRing($ring));
     }
@@ -578,15 +693,27 @@ class GisPolygonTest extends GisGeomTestCase
      */
     public function providerForIsOuterRing()
     {
-        return array(
-            array(
-                array(
-                    array('x' => 0, 'y' => 0),
-                    array('x' => 0, 'y' => 1),
-                    array('x' => 1, 'y' => 1),
-                    array('x' => 1, 'y' => 0)
-                ),
-            )
-        );
+        return [
+            [
+                [
+                    [
+                        'x' => 0,
+                        'y' => 0,
+                    ],
+                    [
+                        'x' => 0,
+                        'y' => 1,
+                    ],
+                    [
+                        'x' => 1,
+                        'y' => 1,
+                    ],
+                    [
+                        'x' => 1,
+                        'y' => 0,
+                    ],
+                ],
+            ],
+        ];
     }
 }
