@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin-test
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Tests;
 
 use PhpMyAdmin\Core;
@@ -23,9 +25,9 @@ class MenuTest extends PmaTestCase
      *
      * @return void
      */
-    function setUp()
+    protected function setUp(): void
     {
-        if (!defined('PMA_IS_WINDOWS')) {
+        if (! defined('PMA_IS_WINDOWS')) {
             define('PMA_IS_WINDOWS', false);
         }
         $GLOBALS['cfg']['Server']['DisableIS'] = false;
@@ -43,10 +45,10 @@ class MenuTest extends PmaTestCase
      *
      * @return void
      */
-    function testServer()
+    public function testServer()
     {
-        $menu = new Menu('server', '', '');
-        $this->assertContains(
+        $menu = new Menu('', '');
+        $this->assertStringContainsString(
             'floating_menubar',
             $menu->getDisplay()
         );
@@ -57,10 +59,10 @@ class MenuTest extends PmaTestCase
      *
      * @return void
      */
-    function testDatabase()
+    public function testDatabase()
     {
-        $menu = new Menu('server', 'pma_test', '');
-        $this->assertContains(
+        $menu = new Menu('pma_test', '');
+        $this->assertStringContainsString(
             'floating_menubar',
             $menu->getDisplay()
         );
@@ -71,10 +73,10 @@ class MenuTest extends PmaTestCase
      *
      * @return void
      */
-    function testTable()
+    public function testTable()
     {
-        $menu = new Menu('server', 'pma_test', 'table1');
-        $this->assertContains(
+        $menu = new Menu('pma_test', 'table1');
+        $this->assertStringContainsString(
             'floating_menubar',
             $menu->getDisplay()
         );
@@ -85,9 +87,9 @@ class MenuTest extends PmaTestCase
      *
      * @return void
      */
-    function testTableDisplay()
+    public function testTableDisplay()
     {
-        $menu = new Menu('server', 'pma_test', '');
+        $menu = new Menu('pma_test', '');
         $this->expectOutputString(
             $menu->getDisplay()
         );
@@ -100,11 +102,11 @@ class MenuTest extends PmaTestCase
      *
      * @return void
      */
-    function testSetTable()
+    public function testSetTable()
     {
-        $menu = new Menu('server', 'pma_test', '');
+        $menu = new Menu('pma_test', '');
         $menu->setTable('table1');
-        $this->assertContains(
+        $this->assertStringContainsString(
             'table1',
             $menu->getDisplay()
         );
