@@ -5,11 +5,13 @@
  *
  * @package PhpMyAdmin-test
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Tests;
 
 use PhpMyAdmin\Message;
-use PhpMyAdmin\Theme;
 use PhpMyAdmin\Tests\PmaTestCase;
+use PhpMyAdmin\Theme;
 
 /**
  * Test for Message class
@@ -19,7 +21,7 @@ use PhpMyAdmin\Tests\PmaTestCase;
 class MessageTest extends PmaTestCase
 {
     /**
-     * @var    PhpMyAdmin\Message
+     * @var Message
      * @access protected
      */
     protected $object;
@@ -31,9 +33,9 @@ class MessageTest extends PmaTestCase
      * @access protected
      * @return void
      */
-    protected function setUp()
+    protected function setUp(): void
     {
-        $this->object = new Message;
+        $this->object = new Message();
     }
 
     /**
@@ -43,7 +45,7 @@ class MessageTest extends PmaTestCase
      * @access protected
      * @return void
      */
-    protected function tearDown()
+    protected function tearDown(): void
     {
     }
 
@@ -55,7 +57,7 @@ class MessageTest extends PmaTestCase
     public function testToString()
     {
         $this->object->setMessage('test<&>', true);
-        $this->assertEquals('test&lt;&amp;&gt;', (string)$this->object);
+        $this->assertEquals('test&lt;&amp;&gt;', (string) $this->object);
     }
 
     /**
@@ -208,17 +210,24 @@ class MessageTest extends PmaTestCase
     {
         $this->object->addParam(Message::notice('test'));
         $this->assertEquals(
-            array(Message::notice('test')),
+            [Message::notice('test')],
             $this->object->getParams()
         );
         $this->object->addParam('test');
         $this->assertEquals(
-            array(Message::notice('test'), 'test'),
+            [
+                Message::notice('test'),
+                'test',
+            ],
             $this->object->getParams()
         );
         $this->object->addParam('test');
         $this->assertEquals(
-            array(Message::notice('test'), 'test', Message::notice('test')),
+            [
+                Message::notice('test'),
+                'test',
+                Message::notice('test'),
+            ],
             $this->object->getParams()
         );
     }
@@ -249,16 +258,19 @@ class MessageTest extends PmaTestCase
     {
         $this->object->addText('test', '*');
         $this->assertEquals(
-            array('*', Message::notice('test')),
+            [
+                '*',
+                Message::notice('test'),
+            ],
             $this->object->getAddedMessages()
         );
         $this->object->addText('test', '');
         $this->assertEquals(
-            array(
+            [
                 '*',
                 Message::notice('test'),
-                Message::notice('test')
-            ),
+                Message::notice('test'),
+            ],
             $this->object->getAddedMessages()
         );
     }
@@ -272,16 +284,16 @@ class MessageTest extends PmaTestCase
     {
         $this->object->addText('test<>', '');
         $this->assertEquals(
-            array(Message::notice('test&lt;&gt;')),
+            [Message::notice('test&lt;&gt;')],
             $this->object->getAddedMessages()
         );
         $this->object->addHtml('<b>test</b>');
         $this->assertEquals(
-            array(
+            [
                 Message::notice('test&lt;&gt;'),
                 ' ',
-                Message::rawNotice('<b>test</b>')
-            ),
+                Message::rawNotice('<b>test</b>'),
+            ],
             $this->object->getAddedMessages()
         );
         $this->object->addMessage(Message::notice('test<>'));
@@ -298,18 +310,18 @@ class MessageTest extends PmaTestCase
      */
     public function testAddMessages()
     {
-        $messages = array();
+        $messages = [];
         $messages[] = new Message("Test1");
         $messages[] = new Message("PMA_Test2", Message::ERROR);
         $messages[] = new Message("Test3");
         $this->object->addMessages($messages, '');
 
         $this->assertEquals(
-            array(
+            [
                 Message::notice('Test1'),
                 Message::error("PMA_Test2"),
-                Message::notice('Test3')
-            ),
+                Message::notice('Test3'),
+            ],
             $this->object->getAddedMessages()
         );
     }
@@ -321,15 +333,19 @@ class MessageTest extends PmaTestCase
      */
     public function testAddMessagesString()
     {
-        $messages = array('test1', 'test<b>', 'test2');
+        $messages = [
+            'test1',
+            'test<b>',
+            'test2',
+        ];
         $this->object->addMessagesString($messages, '');
 
         $this->assertEquals(
-            array(
+            [
                 Message::notice('test1'),
                 Message::notice('test&lt;b&gt;'),
-                Message::notice('test2')
-            ),
+                Message::notice('test2'),
+            ],
             $this->object->getAddedMessages()
         );
 
@@ -365,8 +381,11 @@ class MessageTest extends PmaTestCase
             Message::sanitize($this->object)
         );
         $this->assertEquals(
-            array('test&amp;string&lt;&gt;', 'test&amp;string&lt;&gt;'),
-            Message::sanitize(array($this->object, $this->object))
+            [
+                'test&amp;string&lt;&gt;',
+                'test&amp;string&lt;&gt;',
+            ],
+            Message::sanitize([$this->object, $this->object])
         );
     }
 
@@ -377,39 +396,51 @@ class MessageTest extends PmaTestCase
      */
     public function decodeBBDataProvider()
     {
-        return array(
-            array(
+        return [
+            [
                 '[em]test[/em][em]aa[em/][em]test[/em]',
-                '<em>test</em><em>aa[em/]<em>test</em>'
-            ),
-            array(
+                '<em>test</em><em>aa[em/]<em>test</em>',
+            ],
+            [
                 '[strong]test[/strong][strong]test[/strong]',
-                '<strong>test</strong><strong>test</strong>'
-            ),
-            array(
+                '<strong>test</strong><strong>test</strong>',
+            ],
+            [
                 '[code]test[/code][code]test[/code]',
-                '<code>test</code><code>test</code>'
-            ),
-            array(
+                '<code>test</code><code>test</code>',
+            ],
+            [
                 '[kbd]test[/kbd][br][sup]test[/sup]',
-                '<kbd>test</kbd><br /><sup>test</sup>'
-            ),
-            array(
+                '<kbd>test</kbd><br><sup>test</sup>',
+            ],
+            [
                 '[a@https://example.com/@Documentation]link[/a]',
                 '<a href="./url.php?url=https%3A%2F%2Fexample.com%2F"'
-                . ' target="Documentation">link</a>'
-            ),
-            array(
+                . ' target="Documentation">link</a>',
+            ],
+            [
                 '[a@./non-existing@Documentation]link[/a]',
-                '[a@./non-existing@Documentation]link</a>'
-            ),
-            array(
+                '[a@./non-existing@Documentation]link</a>',
+            ],
+            [
                 '[doc@foo]link[/doc]',
                 '<a href="./url.php?url=https%3A%2F%2Fdocs.phpmyadmin.net%2Fen%2F'
                 . 'latest%2Fsetup.html%23foo" '
-                . 'target="documentation">link</a>'
-            ),
-        );
+                . 'target="documentation">link</a>',
+            ],
+            [
+                '[doc@page@anchor]link[/doc]',
+                '<a href="./url.php?url=https%3A%2F%2Fdocs.phpmyadmin.net%2Fen%2F'
+                . 'latest%2Fpage.html%23anchor" '
+                . 'target="documentation">link</a>',
+            ],
+            [
+                '[doc@faqmysql]link[/doc]',
+                '<a href="./url.php?url=https%3A%2F%2Fdocs.phpmyadmin.net%2Fen%2F'
+                . 'latest%2Ffaq.html%23faqmysql" '
+                . 'target="documentation">link</a>',
+            ],
+        ];
     }
 
     /**
@@ -422,7 +453,7 @@ class MessageTest extends PmaTestCase
      *
      * @dataProvider decodeBBDataProvider
      */
-    public function testDecodeBB($actual, $expected)
+    public function testDecodeBB($actual, $expected): void
     {
         unset($GLOBALS['server']);
         $this->assertEquals($expected, Message::decodeBB($actual));
@@ -445,13 +476,12 @@ class MessageTest extends PmaTestCase
         );
         $this->assertEquals(
             'test string',
-            Message::format('test string', array())
+            Message::format('test string', [])
         );
         $this->assertEquals(
             'test string',
-            Message::format('%s string', array('test'))
+            Message::format('%s string', ['test'])
         );
-
     }
 
     /**
@@ -541,7 +571,7 @@ class MessageTest extends PmaTestCase
         $this->object->setMessage('Test Message');
 
         $this->expectOutputString(
-            '<div class="notice"><img src="themes/dot.gif" title="" alt="" class="icon ic_s_notice" /> '
+            '<div class="notice"><img src="themes/dot.gif" title="" alt="" class="icon ic_s_notice"> '
             . 'Test Message</div>'
         );
         $this->object->display();
@@ -558,7 +588,7 @@ class MessageTest extends PmaTestCase
     {
         $this->object->setMessage('Test Message');
         $this->assertEquals(
-            '<div class="notice"><img src="themes/dot.gif" title="" alt="" class="icon ic_s_notice" /> '
+            '<div class="notice"><img src="themes/dot.gif" title="" alt="" class="icon ic_s_notice"> '
             . 'Test Message</div>',
             $this->object->getDisplay()
         );
@@ -583,23 +613,23 @@ class MessageTest extends PmaTestCase
      */
     public function providerAffectedRows()
     {
-        return array(
-            array(
+        return [
+            [
                 1,
                 '<div class="notice"><img src="themes/dot.gif" title="" alt="" '
-                . 'class="icon ic_s_notice" />  1 row affected.</div>'
-            ),
-            array(
+                . 'class="icon ic_s_notice">  1 row affected.</div>',
+            ],
+            [
                 2,
                 '<div class="notice"><img src="themes/dot.gif" title="" alt="" '
-                . 'class="icon ic_s_notice" />  2 rows affected.</div>'
-            ),
-            array(
+                . 'class="icon ic_s_notice">  2 rows affected.</div>',
+            ],
+            [
                 10000,
                 '<div class="notice"><img src="themes/dot.gif" title="" alt="" '
-                . 'class="icon ic_s_notice" />  10000 rows affected.</div>'
-            )
-        );
+                . 'class="icon ic_s_notice">  10000 rows affected.</div>',
+            ],
+        ];
     }
 
     /**
@@ -612,11 +642,11 @@ class MessageTest extends PmaTestCase
      *
      * @dataProvider providerAffectedRows
      */
-    public function testAffectedRows($rows, $output)
+    public function testAffectedRows($rows, $output): void
     {
         $this->object = new Message();
         $msg = $this->object->getMessageForAffectedRows($rows);
-        echo $this->object->addMessage($msg);
+        $this->object->addMessage($msg);
         $this->expectOutputString($output);
         $this->object->display();
     }
@@ -628,23 +658,23 @@ class MessageTest extends PmaTestCase
      */
     public function providerInsertedRows()
     {
-        return array(
-            array(
+        return [
+            [
                 1,
                 '<div class="notice"><img src="themes/dot.gif" title="" alt="" '
-                . 'class="icon ic_s_notice" />  1 row inserted.</div>'
-            ),
-            array(
+                . 'class="icon ic_s_notice">  1 row inserted.</div>',
+            ],
+            [
                 2,
                 '<div class="notice"><img src="themes/dot.gif" title="" alt="" '
-                . 'class="icon ic_s_notice" />  2 rows inserted.</div>'
-            ),
-            array(
+                . 'class="icon ic_s_notice">  2 rows inserted.</div>',
+            ],
+            [
                 100000,
                 '<div class="notice"><img src="themes/dot.gif" title="" alt="" '
-                . 'class="icon ic_s_notice" />  100000 rows inserted.</div>'
-            )
-        );
+                . 'class="icon ic_s_notice">  100000 rows inserted.</div>',
+            ],
+        ];
     }
 
     /**
@@ -657,11 +687,11 @@ class MessageTest extends PmaTestCase
      *
      * @dataProvider providerInsertedRows
      */
-    public function testInsertedRows($rows, $output)
+    public function testInsertedRows($rows, $output): void
     {
         $this->object = new Message();
         $msg = $this->object->getMessageForInsertedRows($rows);
-        echo $this->object->addMessage($msg);
+        $this->object->addMessage($msg);
         $this->expectOutputString($output);
         $this->object->display();
     }
@@ -673,23 +703,23 @@ class MessageTest extends PmaTestCase
      */
     public function providerDeletedRows()
     {
-        return array(
-            array(
+        return [
+            [
                 1,
                 '<div class="notice"><img src="themes/dot.gif" title="" alt="" '
-                . 'class="icon ic_s_notice" />  1 row deleted.</div>'
-            ),
-            array(
+                . 'class="icon ic_s_notice">  1 row deleted.</div>',
+            ],
+            [
                 2,
                 '<div class="notice"><img src="themes/dot.gif" title="" alt="" '
-                . 'class="icon ic_s_notice" />  2 rows deleted.</div>'
-            ),
-            array(
+                . 'class="icon ic_s_notice">  2 rows deleted.</div>',
+            ],
+            [
                 500000,
                 '<div class="notice"><img src="themes/dot.gif" title="" alt="" '
-                . 'class="icon ic_s_notice" />  500000 rows deleted.</div>'
-            )
-        );
+                . 'class="icon ic_s_notice">  500000 rows deleted.</div>',
+            ],
+        ];
     }
 
     /**
@@ -702,11 +732,11 @@ class MessageTest extends PmaTestCase
      *
      * @dataProvider providerDeletedRows
      */
-    public function testDeletedRows($rows, $output)
+    public function testDeletedRows($rows, $output): void
     {
         $this->object = new Message();
         $msg = $this->object->getMessageForDeletedRows($rows);
-        echo $this->object->addMessage($msg);
+        $this->object->addMessage($msg);
         $this->expectOutputString($output);
         $this->object->display();
     }
