@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin-test
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Tests\Navigation\Nodes;
 
 use PhpMyAdmin\Navigation\NodeFactory;
@@ -25,7 +27,7 @@ class NodeTest extends PmaTestCase
      *
      * @return void
      */
-    public function setUp()
+    protected function setUp(): void
     {
         $GLOBALS['server'] = 0;
         $GLOBALS['cfg']['Server']['DisableIS'] = false;
@@ -46,7 +48,7 @@ class NodeTest extends PmaTestCase
             $child
         );
         $this->assertEquals(
-            $parent->getChild($child->real_name, true),
+            $parent->getChild($child->realName, true),
             $child
         );
     }
@@ -98,8 +100,10 @@ class NodeTest extends PmaTestCase
     public function testNodeHasChildren()
     {
         $parent = NodeFactory::getInstance();
-        $empty_container = NodeFactory::getInstance(
-            'Node', 'empty', Node::CONTAINER
+        $emptyContainer = NodeFactory::getInstance(
+            'Node',
+            'empty',
+            Node::CONTAINER
         );
         $child = NodeFactory::getInstance();
         // test with no children
@@ -112,7 +116,7 @@ class NodeTest extends PmaTestCase
             false
         );
         // test with an empty container
-        $parent->addChild($empty_container);
+        $parent->addChild($emptyContainer);
         $this->assertEquals(
             $parent->hasChildren(true),
             true
@@ -153,7 +157,9 @@ class NodeTest extends PmaTestCase
         $this->assertEquals($parent->numChildren(), 1);
         // add a container, this one doesn't count wither
         $container = NodeFactory::getInstance(
-            'Node', 'default', Node::CONTAINER
+            'Node',
+            'default',
+            Node::CONTAINER
         );
         $parent->addChild($container);
         $this->assertEquals($parent->numChildren(), 1);
@@ -173,16 +179,19 @@ class NodeTest extends PmaTestCase
     public function testParents()
     {
         $parent = NodeFactory::getInstance();
-        $this->assertEquals($parent->parents(), array()); // exclude self
-        $this->assertEquals($parent->parents(true), array($parent)); // include self
+        $this->assertEquals($parent->parents(), []); // exclude self
+        $this->assertEquals($parent->parents(true), [$parent]); // include self
 
         $child = NodeFactory::getInstance();
         $parent->addChild($child);
 
-        $this->assertEquals($child->parents(), array($parent)); // exclude self
+        $this->assertEquals($child->parents(), [$parent]); // exclude self
         $this->assertEquals(
             $child->parents(true),
-            array($child, $parent)
+            [
+                $child,
+                $parent,
+            ]
         ); // include self
     }
 
@@ -237,7 +246,9 @@ class NodeTest extends PmaTestCase
         $firstChild = NodeFactory::getInstance();
         $parent->addChild($firstChild);
         $secondChild = NodeFactory::getInstance(
-            'Node', 'default', Node::CONTAINER
+            'Node',
+            'default',
+            Node::CONTAINER
         );
         $parent->addChild($secondChild);
         // Empty Node::CONTAINER type node should not be considered in hasSiblings()
@@ -281,14 +292,16 @@ class NodeTest extends PmaTestCase
     public function testGetWhereClause()
     {
         $method = new ReflectionMethod(
-            'PhpMyAdmin\Navigation\Nodes\Node', '_getWhereClause'
+            'PhpMyAdmin\Navigation\Nodes\Node',
+            'getWhereClause'
         );
         $method->setAccessible(true);
 
         // Vanilla case
         $node = NodeFactory::getInstance();
         $this->assertEquals(
-            "WHERE TRUE ", $method->invoke($node, 'SCHEMA_NAME')
+            "WHERE TRUE ",
+            $method->invoke($node, 'SCHEMA_NAME')
         );
 
         // When a schema names is passed as search clause
@@ -298,7 +311,7 @@ class NodeTest extends PmaTestCase
         );
 
         if (! isset($GLOBALS['cfg']['Server'])) {
-            $GLOBALS['cfg']['Server'] = array();
+            $GLOBALS['cfg']['Server'] = [];
         }
 
         // When hide_db regular expression is present
@@ -318,7 +331,10 @@ class NodeTest extends PmaTestCase
         unset($GLOBALS['cfg']['Server']['only_db']);
 
         // When only_db directive is present and it's an array of dbs
-        $GLOBALS['cfg']['Server']['only_db'] = array('onlyDbOne', 'onlyDbTwo');
+        $GLOBALS['cfg']['Server']['only_db'] = [
+            'onlyDbOne',
+            'onlyDbTwo',
+        ];
         $this->assertEquals(
             "WHERE TRUE AND ( `SCHEMA_NAME` LIKE 'onlyDbOne' "
             . "OR `SCHEMA_NAME` LIKE 'onlyDbTwo' ) ",
@@ -444,12 +460,12 @@ class NodeTest extends PmaTestCase
         $dbi->expects($this->exactly(3))
             ->method('fetchArray')
             ->willReturnOnConsecutiveCalls(
-                array(
-                    '0' => 'db'
-                ),
-                array(
-                    '0' => 'aa_db'
-                ),
+                [
+                    '0' => 'db',
+                ],
+                [
+                    '0' => 'aa_db',
+                ],
                 false
             );
 
