@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin-test
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Tests\Navigation\Nodes;
 
 use PhpMyAdmin\Navigation\NodeFactory;
@@ -23,7 +25,7 @@ class NodeViewTest extends PmaTestCase
      *
      * @return void
      */
-    public function setUp()
+    protected function setUp(): void
     {
         $GLOBALS['server'] = 0;
     }
@@ -40,11 +42,11 @@ class NodeViewTest extends PmaTestCase
             'text',
             $parent->links
         );
-        $this->assertContains(
+        $this->assertStringContainsString(
             'sql.php',
             $parent->links['text']
         );
-        $this->assertContains('b_props', $parent->icon);
-        $this->assertContains('view', $parent->classes);
+        $this->assertStringContainsString('b_props', $parent->icon);
+        $this->assertStringContainsString('view', $parent->classes);
     }
 }
