@@ -5,10 +5,13 @@
  *
  * @package PhpMyAdmin-test
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Tests\Plugins\Export;
 
 use PhpMyAdmin\DatabaseInterface;
 use PhpMyAdmin\Plugins\Export\ExportHtmlword;
+use PhpMyAdmin\Relation;
 use PhpMyAdmin\Tests\PmaTestCase;
 use ReflectionMethod;
 use ReflectionProperty;
@@ -28,7 +31,7 @@ class ExportHtmlwordTest extends PmaTestCase
      *
      * @return void
      */
-    function setUp()
+    protected function setUp(): void
     {
         $GLOBALS['server'] = 0;
         $this->object = new ExportHtmlword();
@@ -44,7 +47,7 @@ class ExportHtmlwordTest extends PmaTestCase
      *
      * @return void
      */
-    public function tearDown()
+    protected function tearDown(): void
     {
         unset($this->object);
     }
@@ -138,11 +141,11 @@ class ExportHtmlwordTest extends PmaTestCase
         );
 
         $this->assertEquals(
-            array(
+            [
                 'structure' => __('structure'),
                 'data' => __('data'),
-                'structure_and_data' => __('structure and data')
-            ),
+                'structure_and_data' => __('structure and data'),
+            ],
             $property->getValues()
         );
 
@@ -226,7 +229,7 @@ class ExportHtmlwordTest extends PmaTestCase
             <html>
             <head>
                 <meta http-equiv="Content-type" content="text/html;charset='
-            . 'utf-8' . '" />
+            . 'utf-8" />
             </head>
             <body>';
 
@@ -252,7 +255,7 @@ class ExportHtmlwordTest extends PmaTestCase
             <html>
             <head>
                 <meta http-equiv="Content-type" content="text/html;charset='
-            . 'ISO-8859-1' . '" />
+            . 'ISO-8859-1" />
             </head>
             <body>';
 
@@ -354,7 +357,7 @@ class ExportHtmlwordTest extends PmaTestCase
         $dbi->expects($this->at(7))
             ->method('fetchRow')
             ->with(true)
-            ->will($this->returnValue(array(null, '0', 'test', false)));
+            ->will($this->returnValue([null, '0', 'test', false]));
 
         $dbi->expects($this->at(8))
             ->method('fetchRow')
@@ -374,7 +377,11 @@ class ExportHtmlwordTest extends PmaTestCase
         ob_start();
         $this->assertTrue(
             $this->object->exportData(
-                'testDB', 'testTable', "\n", 'example.com', 'test'
+                'testDB',
+                'testTable',
+                "\n",
+                'example.com',
+                'test'
             )
         );
         $result = htmlspecialchars_decode(ob_get_clean());
@@ -402,21 +409,21 @@ class ExportHtmlwordTest extends PmaTestCase
     public function testGetTableDefStandIn()
     {
         $this->object = $this->getMockBuilder('PhpMyAdmin\Plugins\Export\ExportHtmlword')
-            ->setMethods(array('formatOneColumnDefinition'))
+            ->setMethods(['formatOneColumnDefinition'])
             ->getMock();
 
         // case 1
 
-        $keys = array(
-            array(
+        $keys = [
+            [
                 'Non_unique' => 0,
-                'Column_name' => 'name1'
-            ),
-            array(
+                'Column_name' => 'name1',
+            ],
+            [
                 'Non_unique' => 1,
-                'Column_name' => 'name2'
-            )
-        );
+                'Column_name' => 'name2',
+            ],
+        ];
 
         $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
             ->disableOriginalConstructor()
@@ -430,13 +437,13 @@ class ExportHtmlwordTest extends PmaTestCase
         $dbi->expects($this->once())
             ->method('getColumns')
             ->with('database', 'view')
-            ->will($this->returnValue(array(array('Field' => 'column'))));
+            ->will($this->returnValue([['Field' => 'column']]));
 
         $GLOBALS['dbi'] = $dbi;
 
         $this->object->expects($this->once())
             ->method('formatOneColumnDefinition')
-            ->with(array('Field' => 'column'), array('name1'), 'column')
+            ->with(['Field' => 'column'], ['name1'], 'column')
             ->will($this->returnValue(1));
 
         $this->assertEquals(
@@ -458,19 +465,19 @@ class ExportHtmlwordTest extends PmaTestCase
     public function testGetTableDef()
     {
         $this->object = $this->getMockBuilder('PhpMyAdmin\Plugins\Export\ExportHtmlword')
-            ->setMethods(array('formatOneColumnDefinition'))
+            ->setMethods(['formatOneColumnDefinition'])
             ->getMock();
 
-        $keys = array(
-            array(
+        $keys = [
+            [
                 'Non_unique' => 0,
-                'Column_name' => 'name1'
-            ),
-            array(
+                'Column_name' => 'name1',
+            ],
+            [
                 'Non_unique' => 1,
-                'Column_name' => 'name2'
-            )
-        );
+                'Column_name' => 'name2',
+            ],
+        ];
 
         // case 1
 
@@ -481,14 +488,14 @@ class ExportHtmlwordTest extends PmaTestCase
         $dbi->expects($this->exactly(2))
             ->method('fetchResult')
             ->willReturnOnConsecutiveCalls(
-                array(),
-                array(
-                    'fieldname' => array(
+                [],
+                [
+                    'fieldname' => [
                         'values' => 'test-',
                         'transformation' => 'testfoo',
-                        'mimetype' => 'test<'
-                    )
-                )
+                        'mimetype' => 'test<',
+                    ],
+                ]
             );
 
         $dbi->expects($this->once())
@@ -496,13 +503,13 @@ class ExportHtmlwordTest extends PmaTestCase
             ->with('database', '')
             ->will($this->returnValue($keys));
 
-        $columns = array(
-            'Field' => 'fieldname'
-        );
+        $columns = [
+            'Field' => 'fieldname',
+        ];
         $dbi->expects($this->once())
             ->method('getColumns')
             ->with('database', '')
-            ->will($this->returnValue(array($columns)));
+            ->will($this->returnValue([$columns]));
 
         $dbi->expects($this->any())
             ->method('query')
@@ -516,31 +523,32 @@ class ExportHtmlwordTest extends PmaTestCase
             ->method('fetchAssoc')
             ->will(
                 $this->returnValue(
-                    array(
-                        'comment' => array('fieldname' => 'testComment')
-                    )
+                    [
+                        'comment' => ['fieldname' => 'testComment'],
+                    ]
                 )
             );
         $dbi->expects($this->any())->method('escapeString')
             ->will($this->returnArgument(0));
 
         $GLOBALS['dbi'] = $dbi;
+        $this->object->relation = new Relation($dbi);
 
         $this->object->expects($this->exactly(3))
             ->method('formatOneColumnDefinition')
-            ->with($columns, array('name1'))
+            ->with($columns, ['name1'])
             ->will($this->returnValue(1));
 
         $GLOBALS['cfgRelation']['relation'] = true;
-        $_SESSION['relation'][0] = array(
+        $_SESSION['relation'][0] = [
             'PMA_VERSION' => PMA_VERSION,
             'relwork' => true,
             'commwork' => true,
             'mimework' => true,
             'db' => 'database',
             'relation' => 'rel',
-            'column_info' => 'col'
-        );
+            'column_info' => 'col',
+        ];
 
         $result = $this->object->getTableDef(
             'database',
@@ -557,7 +565,7 @@ class ExportHtmlwordTest extends PmaTestCase
             '<td class="print"><strong>Null</strong></td>' .
             '<td class="print"><strong>Default</strong></td>' .
             '<td class="print"><strong>Comments</strong></td>' .
-            '<td class="print"><strong>MIME</strong></td></tr>' .
+            '<td class="print"><strong>Media (MIME) type</strong></td></tr>' .
             '1<td class="print"></td><td class="print">Test&lt;</td></tr></table>',
             $result
         );
@@ -571,19 +579,19 @@ class ExportHtmlwordTest extends PmaTestCase
         $dbi->expects($this->exactly(2))
             ->method('fetchResult')
             ->willReturnOnConsecutiveCalls(
-                array(
-                    'fieldname' => array(
+                [
+                    'fieldname' => [
                         'foreign_table' => 'ftable',
-                        'foreign_field' => 'ffield'
-                    )
-                ),
-                array(
-                    'field' => array(
+                        'foreign_field' => 'ffield',
+                    ],
+                ],
+                [
+                    'field' => [
                         'values' => 'test-',
                         'transformation' => 'testfoo',
-                        'mimetype' => 'test<'
-                    )
-                )
+                        'mimetype' => 'test<',
+                    ],
+                ]
             );
 
         $dbi->expects($this->once())
@@ -591,14 +599,14 @@ class ExportHtmlwordTest extends PmaTestCase
             ->with('database', '')
             ->will($this->returnValue($keys));
 
-        $columns = array(
-            'Field' => 'fieldname'
-        );
+        $columns = [
+            'Field' => 'fieldname',
+        ];
 
         $dbi->expects($this->once())
             ->method('getColumns')
             ->with('database', '')
-            ->will($this->returnValue(array($columns)));
+            ->will($this->returnValue([$columns]));
 
         $dbi->expects($this->any())
             ->method('query')
@@ -612,26 +620,27 @@ class ExportHtmlwordTest extends PmaTestCase
             ->method('fetchAssoc')
             ->will(
                 $this->returnValue(
-                    array(
-                        'comment' => array('field' => 'testComment')
-                    )
+                    [
+                        'comment' => ['field' => 'testComment'],
+                    ]
                 )
             );
         $dbi->expects($this->any())->method('escapeString')
             ->will($this->returnArgument(0));
 
         $GLOBALS['dbi'] = $dbi;
+        $this->object->relation = new Relation($dbi);
 
         $GLOBALS['cfgRelation']['relation'] = true;
-        $_SESSION['relation'][0] = array(
+        $_SESSION['relation'][0] = [
             'PMA_VERSION' => PMA_VERSION,
             'relwork' => true,
             'commwork' => true,
             'mimework' => true,
             'db' => 'database',
             'relation' => 'rel',
-            'column_info' => 'col'
-        );
+            'column_info' => 'col',
+        ];
 
         $result = $this->object->getTableDef(
             'database',
@@ -641,12 +650,12 @@ class ExportHtmlwordTest extends PmaTestCase
             true
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '<td class="print">ftable (ffield)</td>',
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '<td class="print"></td><td class="print"></td>',
             $result
         );
@@ -662,14 +671,14 @@ class ExportHtmlwordTest extends PmaTestCase
             ->with('database', '')
             ->will($this->returnValue($keys));
 
-        $columns = array(
-            'Field' => 'fieldname'
-        );
+        $columns = [
+            'Field' => 'fieldname',
+        ];
 
         $dbi->expects($this->once())
             ->method('getColumns')
             ->with('database', '')
-            ->will($this->returnValue(array($columns)));
+            ->will($this->returnValue([$columns]));
 
         $dbi->expects($this->any())
             ->method('query')
@@ -683,9 +692,9 @@ class ExportHtmlwordTest extends PmaTestCase
             ->method('fetchAssoc')
             ->will(
                 $this->returnValue(
-                    array(
-                        'comment' => array('field' => 'testComment')
-                    )
+                    [
+                        'comment' => ['field' => 'testComment'],
+                    ]
                 )
             );
         $dbi->expects($this->any())->method('escapeString')
@@ -694,15 +703,15 @@ class ExportHtmlwordTest extends PmaTestCase
         $GLOBALS['dbi'] = $dbi;
 
         $GLOBALS['cfgRelation']['relation'] = true;
-        $_SESSION['relation'][0] = array(
+        $_SESSION['relation'][0] = [
             'PMA_VERSION' => PMA_VERSION,
             'relwork' => false,
             'commwork' => false,
             'mimework' => false,
             'db' => 'database',
             'relation' => 'rel',
-            'column_info' => 'col'
-        );
+            'column_info' => 'col',
+        ];
 
         $result = $this->object->getTableDef(
             'database',
@@ -733,14 +742,14 @@ class ExportHtmlwordTest extends PmaTestCase
             ->disableOriginalConstructor()
             ->getMock();
 
-        $triggers = array(
-            array(
+        $triggers = [
+            [
                 'name' => 'tna"me',
                 'action_timing' => 'ac>t',
                 'event_manipulation' => 'manip&',
-                'definition' => 'def'
-            )
-        );
+                'definition' => 'def',
+            ],
+        ];
 
         $dbi->expects($this->once())
             ->method('getTriggers')
@@ -753,7 +762,7 @@ class ExportHtmlwordTest extends PmaTestCase
         $method->setAccessible(true);
         $result = $method->invoke($this->object, 'database', 'table');
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '<td class="print">tna&quot;me</td>' .
             '<td class="print">ac&gt;t</td>' .
             '<td class="print">manip&amp;</td>' .
@@ -780,7 +789,7 @@ class ExportHtmlwordTest extends PmaTestCase
             ->will($this->returnValue(1));
 
         $this->object = $this->getMockBuilder('PhpMyAdmin\Plugins\Export\ExportHtmlword')
-            ->setMethods(array('getTableDef', 'getTriggers', 'getTableDefStandIn'))
+            ->setMethods(['getTableDef', 'getTriggers', 'getTableDefStandIn'])
             ->getMock();
 
         $this->object->expects($this->at(0))
@@ -795,7 +804,7 @@ class ExportHtmlwordTest extends PmaTestCase
 
         $this->object->expects($this->at(2))
             ->method('getTableDef')
-            ->with('db', 'tbl', false, false, false, true, array())
+            ->with('db', 'tbl', false, false, false, true, [])
             ->will($this->returnValue('dumpText3'));
 
         $this->object->expects($this->once())
@@ -808,7 +817,12 @@ class ExportHtmlwordTest extends PmaTestCase
         ob_start();
         $this->assertTrue(
             $this->object->exportStructure(
-                'db', 'tbl', "\n", "example.com", "create_table", "test"
+                'db',
+                'tbl',
+                "\n",
+                "example.com",
+                "create_table",
+                "test"
             )
         );
         $result = ob_get_clean();
@@ -821,7 +835,12 @@ class ExportHtmlwordTest extends PmaTestCase
         ob_start();
         $this->assertTrue(
             $this->object->exportStructure(
-                'db', 'tbl', "\n", "example.com", "triggers", "test"
+                'db',
+                'tbl',
+                "\n",
+                "example.com",
+                "triggers",
+                "test"
             )
         );
         $result = ob_get_clean();
@@ -834,7 +853,12 @@ class ExportHtmlwordTest extends PmaTestCase
         ob_start();
         $this->assertTrue(
             $this->object->exportStructure(
-                'db', 'tbl', "\n", "example.com", "create_view", "test"
+                'db',
+                'tbl',
+                "\n",
+                "example.com",
+                "create_view",
+                "test"
             )
         );
         $result = ob_get_clean();
@@ -847,7 +871,12 @@ class ExportHtmlwordTest extends PmaTestCase
         ob_start();
         $this->assertTrue(
             $this->object->exportStructure(
-                'db', 'tbl', "\n", "example.com", "stand_in", "test"
+                'db',
+                'tbl',
+                "\n",
+                "example.com",
+                "stand_in",
+                "test"
             )
         );
         $result = ob_get_clean();
@@ -866,20 +895,21 @@ class ExportHtmlwordTest extends PmaTestCase
     public function testFormatOneColumnDefinition()
     {
         $method = new ReflectionMethod(
-            'PhpMyAdmin\Plugins\Export\ExportHtmlword', 'formatOneColumnDefinition'
+            'PhpMyAdmin\Plugins\Export\ExportHtmlword',
+            'formatOneColumnDefinition'
         );
         $method->setAccessible(true);
 
-        $cols = array(
+        $cols = [
             'Null' => 'Yes',
             'Field' => 'field',
             'Key' => 'PRI',
-            'Type' => 'set(abc)enum123'
-        );
+            'Type' => 'set(abc)enum123',
+        ];
 
-        $unique_keys = array(
-            'field'
-        );
+        $unique_keys = [
+            'field',
+        ];
 
         $this->assertEquals(
             '<tr class="print-category"><td class="print"><em>' .
@@ -888,17 +918,17 @@ class ExportHtmlwordTest extends PmaTestCase
             $method->invoke($this->object, $cols, $unique_keys)
         );
 
-        $cols = array(
+        $cols = [
             'Null' => 'NO',
             'Field' => 'fields',
             'Key' => 'COMP',
             'Type' => '',
-            'Default' => 'def'
-        );
+            'Default' => 'def',
+        ];
 
-        $unique_keys = array(
-            'field'
-        );
+        $unique_keys = [
+            'field',
+        ];
 
         $this->assertEquals(
             '<tr class="print-category"><td class="print">fields</td>' .
