@@ -5,9 +5,12 @@
  *
  * @package PhpMyAdmin-test
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Tests\Plugins\Export;
 
 use PhpMyAdmin\Plugins\Export\ExportLatex;
+use PhpMyAdmin\Relation;
 use PhpMyAdmin\Tests\PmaTestCase;
 use ReflectionMethod;
 use ReflectionProperty;
@@ -27,7 +30,7 @@ class ExportLatexTest extends PmaTestCase
      *
      * @return void
      */
-    function setUp()
+    protected function setUp(): void
     {
         $GLOBALS['server'] = 0;
         $GLOBALS['output_kanji_conversion'] = false;
@@ -35,7 +38,7 @@ class ExportLatexTest extends PmaTestCase
         $GLOBALS['buffer_needed'] = false;
         $GLOBALS['asfile'] = true;
         $GLOBALS['save_on_server'] = false;
-        $GLOBALS['plugin_param'] = array();
+        $GLOBALS['plugin_param'] = [];
         $GLOBALS['plugin_param']['export_type'] = 'table';
         $GLOBALS['plugin_param']['single_table'] = false;
         $GLOBALS['cfgRelation']['relation'] = true;
@@ -49,7 +52,7 @@ class ExportLatexTest extends PmaTestCase
      *
      * @return void
      */
-    public function tearDown()
+    protected function tearDown(): void
     {
         unset($this->object);
     }
@@ -175,11 +178,11 @@ class ExportLatexTest extends PmaTestCase
         );
 
         $this->assertEquals(
-            array(
+            [
                 'structure' => __('structure'),
                 'data' => __('data'),
-                'structure_and_data' => __('structure and data')
-            ),
+                'structure_and_data' => __('structure and data'),
+            ],
             $property->getValues()
         );
 
@@ -321,7 +324,7 @@ class ExportLatexTest extends PmaTestCase
         );
 
         $this->assertEquals(
-            'Display MIME types',
+            'Display media (MIME) types',
             $property->getText()
         );
 
@@ -482,7 +485,7 @@ class ExportLatexTest extends PmaTestCase
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "\n% Host: localhost:80",
             $result
         );
@@ -574,12 +577,12 @@ class ExportLatexTest extends PmaTestCase
         $dbi->expects($this->at(3))
             ->method('fetchAssoc')
             ->with(null)
-            ->will($this->returnValue(array('f1' => 'foo$%')));
+            ->will($this->returnValue(['f1' => 'foo$%']));
 
         $dbi->expects($this->at(4))
             ->method('fetchAssoc')
             ->with(null)
-            ->will($this->returnValue(array('f1' => null)));
+            ->will($this->returnValue(['f1' => null]));
 
         $dbi->expects($this->at(5))
             ->method('fetchAssoc')
@@ -630,12 +633,12 @@ class ExportLatexTest extends PmaTestCase
         $dbi->expects($this->at(3))
             ->method('fetchAssoc')
             ->with(null)
-            ->will($this->returnValue(array('f1' => 'foo$%')));
+            ->will($this->returnValue(['f1' => 'foo$%']));
 
         $dbi->expects($this->at(4))
             ->method('fetchAssoc')
             ->with(null)
-            ->will($this->returnValue(array('f1' => null)));
+            ->will($this->returnValue(['f1' => null]));
 
         $dbi->expects($this->at(5))
             ->method('fetchAssoc')
@@ -650,7 +653,7 @@ class ExportLatexTest extends PmaTestCase
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '{datalabel} \\\\\\\\ \hlinefoo',
             $result
         );
@@ -667,16 +670,16 @@ class ExportLatexTest extends PmaTestCase
         //     ->setMethods(array('formatOneColumnDefinition'))
         //     ->getMock();
 
-        $keys = array(
-            array(
+        $keys = [
+            [
                 'Non_unique' => 0,
-                'Column_name' => 'name1'
-            ),
-            array(
+                'Column_name' => 'name1',
+            ],
+            [
                 'Non_unique' => 1,
-                'Column_name' => 'name2'
-            )
-        );
+                'Column_name' => 'name2',
+            ],
+        ];
 
         // case 1
 
@@ -692,31 +695,31 @@ class ExportLatexTest extends PmaTestCase
         $dbi->expects($this->exactly(2))
             ->method('fetchResult')
             ->willReturnOnConsecutiveCalls(
-                array(),
-                array(
-                    'name1' => array(
+                [],
+                [
+                    'name1' => [
                         'values' => 'test-',
                         'transformation' => 'testfoo',
-                        'mimetype' => 'testmimetype_'
-                    )
-                )
+                        'mimetype' => 'testmimetype_',
+                    ],
+                ]
             );
 
-        $columns = array(
-            array(
+        $columns = [
+            [
                 'Null' => 'Yes',
                 'Field' => 'name1',
                 'Key' => 'PRI',
-                'Type' => 'set(abc)enum123'
-            ),
-            array(
+                'Type' => 'set(abc)enum123',
+            ],
+            [
                 'Null' => 'NO',
                 'Field' => 'fields',
                 'Key' => 'COMP',
                 'Type' => '',
-                'Default' => 'def'
-            )
-        );
+                'Default' => 'def',
+            ],
+        ];
         $dbi->expects($this->once())
             ->method('getColumns')
             ->with('database', '')
@@ -734,27 +737,28 @@ class ExportLatexTest extends PmaTestCase
             ->method('fetchAssoc')
             ->will(
                 $this->returnValue(
-                    array(
-                        'comment' => array('name1' => 'testComment')
-                    )
+                    [
+                        'comment' => ['name1' => 'testComment'],
+                    ]
                 )
             );
 
         $GLOBALS['dbi'] = $dbi;
+        $this->object->relation = new Relation($dbi);
         if (isset($GLOBALS['latex_caption'])) {
             unset($GLOBALS['latex_caption']);
         }
 
         $GLOBALS['cfgRelation']['relation'] = true;
-        $_SESSION['relation'][0] = array(
+        $_SESSION['relation'][0] = [
             'PMA_VERSION' => PMA_VERSION,
             'relwork' => true,
             'commwork' => true,
             'mimework' => true,
             'db' => 'database',
             'relation' => 'rel',
-            'column_info' => 'col'
-        );
+            'column_info' => 'col',
+        ];
 
         ob_start();
         $this->assertTrue(
@@ -784,7 +788,7 @@ class ExportLatexTest extends PmaTestCase
             ' \\multicolumn{1}{|c|}{\\textbf{Comments}} & \\multicolumn{1}' .
             '{|c|}{\\textbf{MIME}} \\\\ \\hline \\hline' . "\n" .
             '\\endfirsthead' . "\n" . ' \\hline \\multicolumn{1}{|c|}' .
-            '{\\textbf{Column}} & \\multicolumn{1}' . '{|c|}{\\textbf{Type}}' .
+            '{\\textbf{Column}} & \\multicolumn{1}{|c|}{\\textbf{Type}}' .
             ' & \\multicolumn{1}{|c|}{\\textbf{Null}} & \\multicolumn' .
             '{1}{|c|}{\\textbf{Default}} & \\multicolumn{1}{|c|}{\\textbf' .
             '{Comments}} & \\multicolumn{1}{|c|}{\\textbf{MIME}} \\\\ ' .
@@ -805,20 +809,20 @@ class ExportLatexTest extends PmaTestCase
         $dbi->expects($this->exactly(2))
             ->method('fetchResult')
             ->willReturnOnConsecutiveCalls(
-                array(
-                    'name1' => array(
+                [
+                    'name1' => [
                         'foreign_table' => 'ftable',
-                        'foreign_field' => 'ffield'
-                    ),
-                    'foreign_keys_data' => array()
-                ),
-                array(
-                    'field' => array(
+                        'foreign_field' => 'ffield',
+                    ],
+                    'foreign_keys_data' => [],
+                ],
+                [
+                    'field' => [
                         'values' => 'test-',
                         'transformation' => 'testfoo',
-                        'mimetype' => 'test<'
-                    )
-                )
+                        'mimetype' => 'test<',
+                    ],
+                ]
             );
 
         $dbi->expects($this->once())
@@ -843,24 +847,25 @@ class ExportLatexTest extends PmaTestCase
             ->method('fetchAssoc')
             ->will(
                 $this->returnValue(
-                    array(
-                        'comment' => array('field' => 'testComment')
-                    )
+                    [
+                        'comment' => ['field' => 'testComment'],
+                    ]
                 )
             );
 
         $GLOBALS['dbi'] = $dbi;
+        $this->object->relation = new Relation($dbi);
 
         $GLOBALS['cfgRelation']['relation'] = true;
-        $_SESSION['relation'][0] = array(
+        $_SESSION['relation'][0] = [
             'PMA_VERSION' => PMA_VERSION,
             'relwork' => true,
             'commwork' => true,
             'mimework' => true,
             'db' => 'database',
             'relation' => 'rel',
-            'column_info' => 'col'
-        );
+            'column_info' => 'col',
+        ];
 
         ob_start();
         $this->assertTrue(
@@ -878,7 +883,7 @@ class ExportLatexTest extends PmaTestCase
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '\\textbf{\\textit{name1}} & set(abc) & Yes & NULL & ' .
             'ftable (ffield) &  &  \\\\ \\hline',
             $result
@@ -912,9 +917,9 @@ class ExportLatexTest extends PmaTestCase
             ->method('fetchAssoc')
             ->will(
                 $this->returnValue(
-                    array(
-                        'comment' => array('field' => 'testComment')
-                    )
+                    [
+                        'comment' => ['field' => 'testComment'],
+                    ]
                 )
             );
 
@@ -928,15 +933,15 @@ class ExportLatexTest extends PmaTestCase
         $GLOBALS['cfg']['Server']['host'] = 'localhost';
         $GLOBALS['cfg']['Server']['verbose'] = 'verb';
 
-        $_SESSION['relation'][0] = array(
+        $_SESSION['relation'][0] = [
             'PMA_VERSION' => PMA_VERSION,
             'relwork' => false,
             'commwork' => false,
             'mimework' => false,
             'db' => 'database',
             'relation' => 'rel',
-            'column_info' => 'col'
-        );
+            'column_info' => 'col',
+        ];
 
         ob_start();
         $this->assertTrue(
@@ -951,12 +956,12 @@ class ExportLatexTest extends PmaTestCase
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '\\caption{latexstructure} \\label{latexlabel}',
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'caption{latexcontinued}',
             $result
         );
