@@ -5,10 +5,13 @@
  *
  * @package PhpMyAdmin-test
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Tests\Plugins\Export;
 
 use PhpMyAdmin\DatabaseInterface;
 use PhpMyAdmin\Plugins\Export\ExportOdt;
+use PhpMyAdmin\Relation;
 use PhpMyAdmin\Tests\PmaTestCase;
 use ReflectionMethod;
 use ReflectionProperty;
@@ -29,7 +32,7 @@ class ExportOdtTest extends PmaTestCase
      *
      * @return void
      */
-    function setUp()
+    protected function setUp(): void
     {
         $GLOBALS['server'] = 0;
         $GLOBALS['output_kanji_conversion'] = false;
@@ -37,7 +40,7 @@ class ExportOdtTest extends PmaTestCase
         $GLOBALS['buffer_needed'] = false;
         $GLOBALS['asfile'] = true;
         $GLOBALS['save_on_server'] = false;
-        $GLOBALS['plugin_param'] = array();
+        $GLOBALS['plugin_param'] = [];
         $GLOBALS['plugin_param']['export_type'] = 'table';
         $GLOBALS['plugin_param']['single_table'] = false;
         $GLOBALS['cfgRelation']['relation'] = true;
@@ -49,7 +52,7 @@ class ExportOdtTest extends PmaTestCase
      *
      * @return void
      */
-    public function tearDown()
+    protected function tearDown(): void
     {
         unset($this->object);
     }
@@ -148,11 +151,11 @@ class ExportOdtTest extends PmaTestCase
         );
 
         $this->assertEquals(
-            array(
+            [
                 'structure' => __('structure'),
                 'data' => __('data'),
-                'structure_and_data' => __('structure and data')
-            ),
+                'structure_and_data' => __('structure and data'),
+            ],
             $property->getValues()
         );
 
@@ -227,7 +230,7 @@ class ExportOdtTest extends PmaTestCase
         );
 
         $this->assertEquals(
-            'Display MIME types',
+            'Display media (MIME) types',
             $property->getText()
         );
 
@@ -316,11 +319,11 @@ class ExportOdtTest extends PmaTestCase
             $this->object->exportHeader()
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "<office:document-content",
             $GLOBALS['odt_buffer']
         );
-        $this->assertContains(
+        $this->assertStringContainsString(
             "office:version",
             $GLOBALS['odt_buffer']
         );
@@ -342,12 +345,12 @@ class ExportOdtTest extends PmaTestCase
             $this->object->exportFooter()
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "header",
             $GLOBALS['odt_buffer']
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "</office:text></office:body></office:document-content>",
             $GLOBALS['odt_buffer']
         );
@@ -366,12 +369,12 @@ class ExportOdtTest extends PmaTestCase
             $this->object->exportDBHeader('d&b')
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "header",
             $GLOBALS['odt_buffer']
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "Database d&amp;b</text:h>",
             $GLOBALS['odt_buffer']
         );
@@ -412,23 +415,23 @@ class ExportOdtTest extends PmaTestCase
             ->disableOriginalConstructor()
             ->getMock();
 
-        $flags = array();
-        $a = new stdClass;
+        $flags = [];
+        $a = new stdClass();
         $a->type = '';
         $flags[] = $a;
 
-        $a = new stdClass;
+        $a = new stdClass();
         $a->type = '';
         $a->blob = true;
         $flags[] = $a;
 
-        $a = new stdClass;
+        $a = new stdClass();
         $a->numeric = true;
         $a->type = 'real';
         $a->blob = false;
         $flags[] = $a;
 
-        $a = new stdClass;
+        $a = new stdClass();
         $a->type = "timestamp";
         $a->blob = false;
         $a->numeric = false;
@@ -462,9 +465,12 @@ class ExportOdtTest extends PmaTestCase
             ->with(true)
             ->will(
                 $this->returnValue(
-                    array(
-                        null, 'a<b', 'a>b', 'a&b'
-                    )
+                    [
+                        null,
+                        'a<b',
+                        'a>b',
+                        'a&b',
+                    ]
                 )
             );
 
@@ -479,7 +485,11 @@ class ExportOdtTest extends PmaTestCase
 
         $this->assertTrue(
             $this->object->exportData(
-                'db', 'ta<ble', "\n", "example.com", "SELECT"
+                'db',
+                'ta<ble',
+                "\n",
+                "example.com",
+                "SELECT"
             )
         );
 
@@ -510,7 +520,7 @@ class ExportOdtTest extends PmaTestCase
             ->disableOriginalConstructor()
             ->getMock();
 
-        $flags = array();
+        $flags = [];
 
         $dbi->expects($this->once())
             ->method('getFieldsMeta')
@@ -555,7 +565,11 @@ class ExportOdtTest extends PmaTestCase
 
         $this->assertTrue(
             $this->object->exportData(
-                'db', 'table', "\n", "example.com", "SELECT"
+                'db',
+                'table',
+                "\n",
+                "example.com",
+                "SELECT"
             )
         );
 
@@ -575,7 +589,7 @@ class ExportOdtTest extends PmaTestCase
             ->disableOriginalConstructor()
             ->getMock();
 
-        $flags = array();
+        $flags = [];
 
         $dbi->expects($this->once())
             ->method('getFieldsMeta')
@@ -610,7 +624,11 @@ class ExportOdtTest extends PmaTestCase
 
         $this->assertTrue(
             $this->object->exportData(
-                'db', 'table', "\n", "example.com", "SELECT"
+                'db',
+                'table',
+                "\n",
+                "example.com",
+                "SELECT"
             )
         );
 
@@ -638,13 +656,13 @@ class ExportOdtTest extends PmaTestCase
         $dbi->expects($this->once())
             ->method('getColumns')
             ->with('db', 'v&w')
-            ->will($this->returnValue(array(1, 2)));
+            ->will($this->returnValue([1, 2]));
 
         $GLOBALS['dbi'] = $dbi;
 
         $this->object = $this->getMockBuilder('PhpMyAdmin\Plugins\Export\ExportOdt')
             ->disableOriginalConstructor()
-            ->setMethods(array('formatOneColumnDefinition'))
+            ->setMethods(['formatOneColumnDefinition'])
             ->getMock();
 
         $this->object->expects($this->at(0))
@@ -657,16 +675,17 @@ class ExportOdtTest extends PmaTestCase
             ->with(2)
             ->will($this->returnValue('c2'));
 
-        $this->assertTrue(
-            $this->object->getTableDefStandIn('db', 'v&w', '#')
+        $this->assertSame(
+            $this->object->getTableDefStandIn('db', 'v&w', '#'),
+            ''
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '<table:table table:name="v&amp;w_data">',
             $GLOBALS['odt_buffer']
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '</table:table-row>c1</table:table-row>c2</table:table-row>' .
             '</table:table>',
             $GLOBALS['odt_buffer']
@@ -681,7 +700,7 @@ class ExportOdtTest extends PmaTestCase
     public function testGetTableDef()
     {
         $this->object = $this->getMockBuilder('PhpMyAdmin\Plugins\Export\ExportOdt')
-            ->setMethods(array('formatOneColumnDefinition'))
+            ->setMethods(['formatOneColumnDefinition'])
             ->getMock();
 
         // case 1
@@ -693,23 +712,23 @@ class ExportOdtTest extends PmaTestCase
         $dbi->expects($this->exactly(2))
             ->method('fetchResult')
             ->willReturnOnConsecutiveCalls(
-                array(),
-                array(
-                    'fieldname' => array(
+                [],
+                [
+                    'fieldname' => [
                         'values' => 'test-',
                         'transformation' => 'testfoo',
-                        'mimetype' => 'test<'
-                    )
-                )
+                        'mimetype' => 'test<',
+                    ],
+                ]
             );
 
-        $columns = array(
-            'Field' => 'fieldname'
-        );
+        $columns = [
+            'Field' => 'fieldname',
+        ];
         $dbi->expects($this->once())
             ->method('getColumns')
             ->with('database', '')
-            ->will($this->returnValue(array($columns)));
+            ->will($this->returnValue([$columns]));
 
         $dbi->expects($this->any())
             ->method('query')
@@ -723,29 +742,30 @@ class ExportOdtTest extends PmaTestCase
             ->method('fetchAssoc')
             ->will(
                 $this->returnValue(
-                    array(
-                        'comment' => array('fieldname' => 'testComment')
-                    )
+                    [
+                        'comment' => ['fieldname' => 'testComment'],
+                    ]
                 )
             );
 
         $GLOBALS['dbi'] = $dbi;
+        $this->object->relation = new Relation($dbi);
 
         $this->object->expects($this->exactly(2))
             ->method('formatOneColumnDefinition')
-            ->with(array('Field' => 'fieldname'))
+            ->with(['Field' => 'fieldname'])
             ->will($this->returnValue(1));
 
         $GLOBALS['cfgRelation']['relation'] = true;
-        $_SESSION['relation'][0] = array(
+        $_SESSION['relation'][0] = [
             'PMA_VERSION' => PMA_VERSION,
             'relwork' => true,
             'commwork' => true,
             'mimework' => true,
             'db' => 'database',
             'relation' => 'rel',
-            'column_info' => 'col'
-        );
+            'column_info' => 'col',
+        ];
         $this->assertTrue(
             $this->object->getTableDef(
                 'database',
@@ -758,25 +778,25 @@ class ExportOdtTest extends PmaTestCase
             )
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '<table:table table:name="_structure"><table:table-column ' .
             'table:number-columns-repeated="6"/>',
             $GLOBALS['odt_buffer']
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '<table:table-cell office:value-type="string"><text:p>Comments' .
             '</text:p></table:table-cell>',
             $GLOBALS['odt_buffer']
         );
 
-        $this->assertContains(
-            '<table:table-cell office:value-type="string"><text:p>MIME type' .
+        $this->assertStringContainsString(
+            '<table:table-cell office:value-type="string"><text:p>Media (MIME) type' .
             '</text:p></table:table-cell>',
             $GLOBALS['odt_buffer']
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '</table:table-row>1<table:table-cell office:value-type="string">' .
             '<text:p></text:p></table:table-cell><table:table-cell office:value-' .
             'type="string"><text:p>Test&lt;</text:p></table:table-cell>' .
@@ -793,29 +813,29 @@ class ExportOdtTest extends PmaTestCase
         $dbi->expects($this->exactly(2))
             ->method('fetchResult')
             ->willReturnOnConsecutiveCalls(
-                array(
-                    'fieldname' => array(
+                [
+                    'fieldname' => [
                         'foreign_table' => 'ftable',
-                        'foreign_field' => 'ffield'
-                    )
-                ),
-                array(
-                    'field' => array(
+                        'foreign_field' => 'ffield',
+                    ],
+                ],
+                [
+                    'field' => [
                         'values' => 'test-',
                         'transformation' => 'testfoo',
-                        'mimetype' => 'test<'
-                    )
-                )
+                        'mimetype' => 'test<',
+                    ],
+                ]
             );
 
-        $columns = array(
-            'Field' => 'fieldname'
-        );
+        $columns = [
+            'Field' => 'fieldname',
+        ];
 
         $dbi->expects($this->once())
             ->method('getColumns')
             ->with('database', '')
-            ->will($this->returnValue(array($columns)));
+            ->will($this->returnValue([$columns]));
 
         $dbi->expects($this->any())
             ->method('query')
@@ -829,24 +849,25 @@ class ExportOdtTest extends PmaTestCase
             ->method('fetchAssoc')
             ->will(
                 $this->returnValue(
-                    array(
-                        'comment' => array('field' => 'testComment')
-                    )
+                    [
+                        'comment' => ['field' => 'testComment'],
+                    ]
                 )
             );
 
         $GLOBALS['dbi'] = $dbi;
+        $this->object->relation = new Relation($dbi);
         $GLOBALS['odt_buffer'] = '';
         $GLOBALS['cfgRelation']['relation'] = true;
-        $_SESSION['relation'][0] = array(
+        $_SESSION['relation'][0] = [
             'PMA_VERSION' => PMA_VERSION,
             'relwork' => true,
             'commwork' => true,
             'mimework' => true,
             'db' => 'database',
             'relation' => 'rel',
-            'column_info' => 'col'
-        );
+            'column_info' => 'col',
+        ];
 
         $this->assertTrue(
             $this->object->getTableDef(
@@ -860,13 +881,13 @@ class ExportOdtTest extends PmaTestCase
             )
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '<text:p>ftable (ffield)</text:p>',
             $GLOBALS['odt_buffer']
         );
     }
 
-     /**
+    /**
      * Test for PhpMyAdmin\Plugins\Export\ExportOdt::getTriggers
      *
      * @return void
@@ -877,14 +898,14 @@ class ExportOdtTest extends PmaTestCase
             ->disableOriginalConstructor()
             ->getMock();
 
-        $triggers = array(
-            array(
+        $triggers = [
+            [
                 'name' => 'tna"me',
                 'action_timing' => 'ac>t',
                 'event_manipulation' => 'manip&',
-                'definition' => 'def'
-            )
-        );
+                'definition' => 'def',
+            ],
+        ];
 
         $dbi->expects($this->once())
             ->method('getTriggers')
@@ -901,27 +922,27 @@ class ExportOdtTest extends PmaTestCase
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '<table:table table:name="ta&lt;ble_triggers">',
             $GLOBALS['odt_buffer']
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '<text:p>tna&quot;me</text:p>',
             $GLOBALS['odt_buffer']
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '<text:p>ac&gt;t</text:p>',
             $GLOBALS['odt_buffer']
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '<text:p>manip&amp;</text:p>',
             $GLOBALS['odt_buffer']
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '<text:p>def</text:p>',
             $GLOBALS['odt_buffer']
         );
@@ -945,7 +966,7 @@ class ExportOdtTest extends PmaTestCase
             ->will($this->returnValue(1));
 
         $this->object = $this->getMockBuilder('PhpMyAdmin\Plugins\Export\ExportOdt')
-            ->setMethods(array('getTableDef', 'getTriggers', 'getTableDefStandIn'))
+            ->setMethods(['getTableDef', 'getTriggers', 'getTableDefStandIn'])
             ->getMock();
 
         $this->object->expects($this->at(0))
@@ -961,8 +982,16 @@ class ExportOdtTest extends PmaTestCase
         $this->object->expects($this->at(2))
             ->method('getTableDef')
             ->with(
-                'db', 't&bl', "\n", "example.com",
-                false, false, false, false, true, true
+                'db',
+                't&bl',
+                "\n",
+                "example.com",
+                false,
+                false,
+                false,
+                false,
+                true,
+                true
             )
             ->will($this->returnValue('dumpText3'));
 
@@ -976,11 +1005,16 @@ class ExportOdtTest extends PmaTestCase
         // case 1
         $this->assertTrue(
             $this->object->exportStructure(
-                'db', 't&bl', "\n", "example.com", "create_table", "test"
+                'db',
+                't&bl',
+                "\n",
+                "example.com",
+                "create_table",
+                "test"
             )
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '<text:h text:outline-level="2" text:style-name="Heading_2" ' .
             'text:is-list-header="true">Table structure for table t&amp;bl</text:h>',
             $GLOBALS['odt_buffer']
@@ -991,7 +1025,12 @@ class ExportOdtTest extends PmaTestCase
 
         $this->assertTrue(
             $this->object->exportStructure(
-                'db', 't&bl', "\n", "example.com", "triggers", "test"
+                'db',
+                't&bl',
+                "\n",
+                "example.com",
+                "triggers",
+                "test"
             )
         );
 
@@ -1006,7 +1045,12 @@ class ExportOdtTest extends PmaTestCase
 
         $this->assertTrue(
             $this->object->exportStructure(
-                'db', 't&bl', "\n", "example.com", "create_view", "test"
+                'db',
+                't&bl',
+                "\n",
+                "example.com",
+                "create_view",
+                "test"
             )
         );
 
@@ -1020,7 +1064,12 @@ class ExportOdtTest extends PmaTestCase
         $GLOBALS['odt_buffer'] = '';
         $this->assertTrue(
             $this->object->exportStructure(
-                'db', 't&bl', "\n", "example.com", "stand_in", "test"
+                'db',
+                't&bl',
+                "\n",
+                "example.com",
+                "stand_in",
+                "test"
             )
         );
 
@@ -1039,16 +1088,17 @@ class ExportOdtTest extends PmaTestCase
     public function testFormatOneColumnDefinition()
     {
         $method = new ReflectionMethod(
-            'PhpMyAdmin\Plugins\Export\ExportOdt', 'formatOneColumnDefinition'
+            'PhpMyAdmin\Plugins\Export\ExportOdt',
+            'formatOneColumnDefinition'
         );
         $method->setAccessible(true);
 
-        $cols = array(
+        $cols = [
             'Null' => 'Yes',
             'Field' => 'field',
             'Key' => 'PRI',
-            'Type' => 'set(abc)enum123'
-        );
+            'Type' => 'set(abc)enum123',
+        ];
 
         $col_alias = 'alias';
 
@@ -1062,13 +1112,13 @@ class ExportOdtTest extends PmaTestCase
             $method->invoke($this->object, $cols, $col_alias)
         );
 
-        $cols = array(
+        $cols = [
             'Null' => 'NO',
             'Field' => 'fields',
             'Key' => 'COMP',
             'Type' => '',
-            'Default' => 'def'
-        );
+            'Default' => 'def',
+        ];
 
         $this->assertEquals(
             '<table:table-row><table:table-cell office:value-type="string">' .
