@@ -5,10 +5,13 @@
  *
  * @package PhpMyAdmin-test
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Tests\Plugins\Export;
 
 use PhpMyAdmin\DatabaseInterface;
 use PhpMyAdmin\Plugins\Export\ExportSql;
+use PhpMyAdmin\Relation;
 use PhpMyAdmin\Table;
 use PhpMyAdmin\Tests\PmaTestCase;
 use ReflectionMethod;
@@ -30,7 +33,7 @@ class ExportSqlTest extends PmaTestCase
      *
      * @return void
      */
-    function setUp()
+    protected function setUp(): void
     {
         $GLOBALS['server'] = 0;
         $GLOBALS['db'] = 'db';
@@ -38,7 +41,7 @@ class ExportSqlTest extends PmaTestCase
         $GLOBALS['buffer_needed'] = false;
         $GLOBALS['asfile'] = false;
         $GLOBALS['save_on_server'] = false;
-        $GLOBALS['plugin_param'] = array();
+        $GLOBALS['plugin_param'] = [];
         $GLOBALS['plugin_param']['export_type'] = 'table';
         $GLOBALS['plugin_param']['single_table'] = false;
         $GLOBALS['cfgRelation']['relation'] = true;
@@ -50,7 +53,7 @@ class ExportSqlTest extends PmaTestCase
      *
      * @return void
      */
-    public function tearDown()
+    protected function tearDown(): void
     {
         unset($this->object);
     }
@@ -87,7 +90,7 @@ class ExportSqlTest extends PmaTestCase
 
         $dbi->expects($this->once())
             ->method('getCompatibilities')
-            ->will($this->returnValue(array('v1', 'v2')));
+            ->will($this->returnValue(['v1', 'v2']));
 
         $dbi->expects($this->any())->method('escapeString')
             ->will($this->returnArgument(0));
@@ -198,10 +201,10 @@ class ExportSqlTest extends PmaTestCase
         );
 
         $this->assertEquals(
-            array(
+            [
                 'v1' => 'v1',
-                'v2' => 'v2'
-            ),
+                'v2' => 'v2',
+            ],
             $property->getValues()
         );
 
@@ -275,10 +278,20 @@ class ExportSqlTest extends PmaTestCase
 
         $leaf = array_shift($leaves);
         $this->assertInstanceOf(
-            'PhpMyAdmin\Properties\Options\Items\BoolPropertyItem',
+            'PhpMyAdmin\Properties\Options\Groups\OptionsPropertySubgroup',
             $leaf
         );
 
+        $this->assertCount(
+            2,
+            $leaf->getProperties()
+        );
+
+        $this->assertInstanceOf(
+            'PhpMyAdmin\Properties\Options\Items\BoolPropertyItem',
+            $leaf->getSubgroupHeader()
+        );
+
         $leaf = array_shift($leaves);
         $this->assertInstanceOf(
             'PhpMyAdmin\Properties\Options\Items\BoolPropertyItem',
@@ -333,12 +346,12 @@ class ExportSqlTest extends PmaTestCase
         $dbi->expects($this->at(0))
             ->method('getProceduresOrFunctions')
             ->with('db', 'PROCEDURE')
-            ->will($this->returnValue(array('p1', 'p2')));
+            ->will($this->returnValue(['p1', 'p2']));
 
         $dbi->expects($this->at(1))
             ->method('getProceduresOrFunctions')
             ->with('db', 'FUNCTION')
-            ->will($this->returnValue(array('f1')));
+            ->will($this->returnValue(['f1']));
 
         $dbi->expects($this->at(2))
             ->method('getDefinition')
@@ -523,30 +536,29 @@ class ExportSqlTest extends PmaTestCase
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'h1C',
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'h2C',
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "SET FOREIGN_KEY_CHECKS=0;\n",
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "40101 SET",
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "SET FOREIGN_KEY_CHECKS=0;\n" .
             "SET SQL_MODE = \"NO_AUTO_VALUE_ON_ZERO\";\n" .
-            "SET AUTOCOMMIT = 0;\n" .
             "START TRANSACTION;\n" .
             "SET time_zone = \"+00:00\";\n",
             $result
@@ -587,18 +599,18 @@ class ExportSqlTest extends PmaTestCase
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "DROP DATABASE IF EXISTS `db`;\n",
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'CREATE DATABASE IF NOT EXISTS `db` DEFAULT CHARACTER ' .
             'SET utf8 COLLATE utf8_general_ci;',
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'USE `db`;',
             $result
         );
@@ -627,17 +639,17 @@ class ExportSqlTest extends PmaTestCase
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "DROP DATABASE IF EXISTS db;\n",
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'CREATE DATABASE IF NOT EXISTS db DEFAULT CHARACTER SET testcollation;',
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'USE db;',
             $result
         );
@@ -661,7 +673,7 @@ class ExportSqlTest extends PmaTestCase
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "&quot;testDB&quot;",
             $result
         );
@@ -676,7 +688,7 @@ class ExportSqlTest extends PmaTestCase
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "testDB",
             $result
         );
@@ -704,16 +716,28 @@ class ExportSqlTest extends PmaTestCase
                 'SELECT EVENT_NAME FROM information_schema.EVENTS WHERE'
                 . ' EVENT_SCHEMA= \'db\';'
             )
-            ->will($this->returnValue(array('f1', 'f2')));
+            ->will($this->returnValue(['f1', 'f2']));
 
         $dbi->expects($this->exactly(2))
             ->method('getDefinition')
             ->will(
                 $this->returnValueMap(
-                    array(
-                        array('db', 'EVENT', 'f1', DatabaseInterface::CONNECT_USER, 'f1event'),
-                        array('db', 'EVENT', 'f2', DatabaseInterface::CONNECT_USER, 'f2event')
-                    )
+                    [
+                        [
+                            'db',
+                            'EVENT',
+                            'f1',
+                            DatabaseInterface::CONNECT_USER,
+                            'f1event',
+                        ],
+                        [
+                            'db',
+                            'EVENT',
+                            'f2',
+                            DatabaseInterface::CONNECT_USER,
+                            'f2event',
+                        ],
+                    ]
                 )
             );
         $dbi->expects($this->any())->method('escapeString')
@@ -727,22 +751,22 @@ class ExportSqlTest extends PmaTestCase
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "DELIMITER $$\n",
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "DELIMITER ;\n",
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "f1event$$\n",
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "f2event$$\n",
             $result
         );
@@ -801,7 +825,7 @@ class ExportSqlTest extends PmaTestCase
             ->with('db', 'view')
             ->will(
                 $this->returnValue(
-                    array('cname' => array('Type' => 'int'))
+                    ['cname' => ['Type' => 'int']]
                 )
             );
 
@@ -809,12 +833,12 @@ class ExportSqlTest extends PmaTestCase
 
         $result = $this->object->getTableDefStandIn('db', 'view', "");
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "DROP VIEW IF EXISTS `view`;",
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "CREATE TABLE IF NOT EXISTS `view` (`cname` int);",
             $result
         );
@@ -836,21 +860,21 @@ class ExportSqlTest extends PmaTestCase
         $dbi->expects($this->any())->method('escapeString')
             ->will($this->returnArgument(0));
 
-        $dbi->expects($this->any(0))
+        $dbi->expects($this->any())
             ->method('getColumns')
             ->with('db', 'view')
             ->will(
                 $this->returnValue(
-                    array(
-                        'cname' => array(
+                    [
+                        'cname' => [
                             'Type' => 'char',
                             'Collation' => 'utf-8',
                             'Null' => 'NO',
                             'Default' => 'a',
                             'Comment' => 'cmt',
-                            'Field' => 'fname'
-                        )
-                    )
+                            'Field' => 'fname',
+                        ],
+                    ]
                 )
             );
 
@@ -860,7 +884,10 @@ class ExportSqlTest extends PmaTestCase
         $method = new ReflectionMethod('PhpMyAdmin\Plugins\Export\ExportSql', '_getTableDefForView');
         $method->setAccessible(true);
         $result = $method->invoke(
-            $this->object, 'db', 'view', "\n"
+            $this->object,
+            'db',
+            'view',
+            "\n"
         );
 
         $this->assertEquals(
@@ -884,21 +911,25 @@ class ExportSqlTest extends PmaTestCase
             ->with('db', 'view')
             ->will(
                 $this->returnValue(
-                    array(
-                        'cname' => array(
+                    [
+                        'cname' => [
                             'Type' => 'char',
                             'Collation' => 'utf-8',
                             'Null' => 'YES',
                             'Comment' => 'cmt',
-                            'Field' => 'fname'
-                        )
-                    )
+                            'Field' => 'fname',
+                        ],
+                    ]
                 )
             );
         $GLOBALS['dbi'] = $dbi;
 
         $result = $method->invoke(
-            $this->object, 'db', 'view', "\n", false
+            $this->object,
+            'db',
+            'view',
+            "\n",
+            false
         );
 
         $this->assertEquals(
@@ -953,12 +984,12 @@ class ExportSqlTest extends PmaTestCase
             ->method('fetchValue')
             ->will($this->returnValue(false));
 
-        $tmpres = array(
+        $tmpres = [
             'Auto_increment' => 1,
             'Create_time' => '2000-01-01 10:00:00',
             'Update_time' => '2000-01-02 12:00:00',
             'Check_time' => '2000-01-02 13:00:00',
-        );
+        ];
 
         $dbi->expects($this->once())
             ->method('fetchAssoc')
@@ -968,9 +999,9 @@ class ExportSqlTest extends PmaTestCase
         $dbi->expects($this->exactly(3))
             ->method('tryQuery')
             ->withConsecutive(
-                array("SHOW TABLE STATUS FROM `db` WHERE Name = 'table'"),
-                array('USE `db`'),
-                array('SHOW CREATE TABLE `db`.`table`')
+                ["SHOW TABLE STATUS FROM `db` WHERE Name = 'table'"],
+                ['USE `db`'],
+                ['SHOW CREATE TABLE `db`.`table`']
             )
             ->willReturnOnConsecutiveCalls(
                 'res',
@@ -978,7 +1009,7 @@ class ExportSqlTest extends PmaTestCase
                 'res'
             );
 
-        $row = array(
+        $row = [
             '',
             "CREATE TABLE `table` (\n" .
             "`payment_id` smallint(5) unsigned NOT NULL AUTO_INCREMENT,\n" .
@@ -995,19 +1026,22 @@ class ExportSqlTest extends PmaTestCase
             "CONSTRAINT `fk_payment_customer` FOREIGN KEY (`customer_id`) REFERENCES `customer` (`customer_id`) ON UPDATE CASCADE,\n" .
             "CONSTRAINT `fk_payment_rental` FOREIGN KEY (`rental_id`) REFERENCES `rental` (`rental_id`) ON DELETE SET NULL ON UPDATE CASCADE,\n" .
             "CONSTRAINT `fk_payment_staff` FOREIGN KEY (`staff_id`) REFERENCES `staff` (`staff_id`) ON UPDATE CASCADE\n" .
-            ") ENGINE=InnoDB AUTO_INCREMENT=16050 DEFAULT CHARSET=utf8\n"
-        );
+            ") ENGINE=InnoDB AUTO_INCREMENT=16050 DEFAULT CHARSET=utf8\n",
+        ];
 
         $dbi->expects($this->exactly(1))
             ->method('fetchRow')
             ->will(
                 $this->returnValueMap(
-                    array(
-                        array('res', $row)
-                    )
+                    [
+                        [
+                            'res',
+                            $row,
+                        ],
+                    ]
                 )
             );
-        $dbi->expects($this->once())
+        $dbi->expects($this->exactly(2))
             ->method('getTable')
             ->will($this->returnValue(new Table('table', 'db', $dbi)));
         $dbi->expects($this->any())->method('escapeString')
@@ -1017,70 +1051,76 @@ class ExportSqlTest extends PmaTestCase
         $GLOBALS['cfg']['Server']['DisableIS'] = false;
 
         $result = $this->object->getTableDef(
-            'db', 'table', "\n", "example.com/err", true, true, false
+            'db',
+            'table',
+            "\n",
+            "example.com/err",
+            true,
+            true,
+            false
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '-- Creation: Jan 01, 2000 at 10:00 AM',
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '-- Last update: Jan 02, 2000 at 12:00 PM',
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '-- Last check: Jan 02, 2000 at 01:00 PM',
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'DROP TABLE IF EXISTS `table`;',
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "CREATE TABLE `table`",
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '-- Constraints for dumped tables',
             $GLOBALS['sql_constraints']
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '-- Constraints for table "table"',
             $GLOBALS['sql_constraints']
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'ALTER TABLE "table"',
             $GLOBALS['sql_constraints']
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'ADD CONSTRAINT',
             $GLOBALS['sql_constraints']
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'ALTER TABLE "table"',
             $GLOBALS['sql_constraints_query']
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'ADD CONSTRAINT',
             $GLOBALS['sql_constraints_query']
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'ALTER TABLE "table"',
             $GLOBALS['sql_drop_foreign_keys']
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'DROP FOREIGN KEY',
             $GLOBALS['sql_drop_foreign_keys']
         );
@@ -1129,12 +1169,12 @@ class ExportSqlTest extends PmaTestCase
             ->method('fetchValue')
             ->will($this->returnValue(false));
 
-        $tmpres = array(
+        $tmpres = [
             'Auto_increment' => 1,
             'Create_time' => '2000-01-01 10:00:00',
             'Update_time' => '2000-01-02 12:00:00',
             'Check_time' => '2000-01-02 13:00:00',
-        );
+        ];
 
         $dbi->expects($this->once())
             ->method('fetchAssoc')
@@ -1144,9 +1184,9 @@ class ExportSqlTest extends PmaTestCase
         $dbi->expects($this->exactly(3))
             ->method('tryQuery')
             ->withConsecutive(
-                array("SHOW TABLE STATUS FROM `db` WHERE Name = 'table'"),
-                array('USE `db`'),
-                array('SHOW CREATE TABLE `db`.`table`')
+                ["SHOW TABLE STATUS FROM `db` WHERE Name = 'table'"],
+                ['USE `db`'],
+                ['SHOW CREATE TABLE `db`.`table`']
             )
             ->willReturnOnConsecutiveCalls(
                 'res',
@@ -1158,7 +1198,7 @@ class ExportSqlTest extends PmaTestCase
             ->method('getError')
             ->will($this->returnValue('error occurred'));
 
-        $dbi->expects($this->once())
+        $dbi->expects($this->exactly(2))
             ->method('getTable')
             ->will($this->returnValue(new Table('table', 'db', $dbi)));
         $dbi->expects($this->any())
@@ -1169,10 +1209,16 @@ class ExportSqlTest extends PmaTestCase
         $GLOBALS['cfg']['Server']['DisableIS'] = false;
 
         $result = $this->object->getTableDef(
-            'db', 'table', "\n", "example.com/err", true, true, false
+            'db',
+            'table',
+            "\n",
+            "example.com/err",
+            true,
+            true,
+            false
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '-- Error reading structure for table db.table: error occurred',
             $result
         );
@@ -1185,15 +1231,15 @@ class ExportSqlTest extends PmaTestCase
      */
     public function testGetTableComments()
     {
-        $_SESSION['relation'][0] = array(
+        $_SESSION['relation'][0] = [
             'PMA_VERSION' => PMA_VERSION,
             'relwork' => true,
             'commwork' => true,
             'mimework' => true,
             'db' => 'database',
             'relation' => 'rel',
-            'column_info' => 'col'
-        );
+            'column_info' => 'col',
+        ];
         $GLOBALS['sql_include_comments'] = true;
         $GLOBALS['crlf'] = "\n";
 
@@ -1207,37 +1253,43 @@ class ExportSqlTest extends PmaTestCase
         $dbi->expects($this->exactly(2))
             ->method('fetchResult')
             ->willReturnOnConsecutiveCalls(
-                array(
-                    'foo' => array(
+                [
+                    'foo' => [
                         'foreign_table' => 'ftable',
-                        'foreign_field' => 'ffield'
-                    )
-                ),
-                array(
-                    'fieldname' => array(
+                        'foreign_field' => 'ffield',
+                    ],
+                ],
+                [
+                    'fieldname' => [
                         'values' => 'test-',
                         'transformation' => 'testfoo',
-                        'mimetype' => 'test<'
-                    )
-                )
+                        'mimetype' => 'test<',
+                    ],
+                ]
             );
 
         $GLOBALS['dbi'] = $dbi;
+        $this->object->relation = new Relation($dbi);
 
         $method = new ReflectionMethod('PhpMyAdmin\Plugins\Export\ExportSql', '_getTableComments');
         $method->setAccessible(true);
         $result = $method->invoke(
-            $this->object, 'db', '', "\n", true, true
+            $this->object,
+            'db',
+            '',
+            "\n",
+            true,
+            true
         );
 
-        $this->assertContains(
-            "-- MIME TYPES FOR TABLE :\n" .
+        $this->assertStringContainsString(
+            "-- MEDIA (MIME) TYPES FOR TABLE :\n" .
             "--   fieldname\n" .
             "--       Test<",
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "-- RELATIONSHIPS FOR TABLE :\n" .
             "--   foo\n" .
             "--       ftable -> ffield",
@@ -1265,14 +1317,17 @@ class ExportSqlTest extends PmaTestCase
             ->with('db', 't&bl')
             ->will(
                 $this->returnValue(
-                    array(
-                        array('create' => 'bar', 'drop' => 'foo')
-                    )
+                    [
+                        [
+                            'create' => 'bar',
+                            'drop' => 'foo',
+                        ],
+                    ]
                 )
             );
 
         $this->object = $this->getMockBuilder('PhpMyAdmin\Plugins\Export\ExportSql')
-            ->setMethods(array('getTableDef', 'getTriggers', 'getTableDefStandIn'))
+            ->setMethods(['getTableDef', 'getTriggers', 'getTableDefStandIn'])
             ->getMock();
 
         $this->object->expects($this->at(0))
@@ -1283,7 +1338,11 @@ class ExportSqlTest extends PmaTestCase
         $this->object->expects($this->at(1))
             ->method('getTableDef')
             ->with(
-                'db', 't&bl', "\n", "example.com", false
+                'db',
+                't&bl',
+                "\n",
+                "example.com",
+                false
             )
             ->will($this->returnValue('dumpText3'));
 
@@ -1302,17 +1361,22 @@ class ExportSqlTest extends PmaTestCase
         ob_start();
         $this->assertTrue(
             $this->object->exportStructure(
-                'db', 't&bl', "\n", "example.com", "create_table", "test"
+                'db',
+                't&bl',
+                "\n",
+                "example.com",
+                "create_table",
+                "test"
             )
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '-- Table structure for table &quot;t&amp;bl&quot;',
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'dumpText1',
             $result
         );
@@ -1327,17 +1391,22 @@ class ExportSqlTest extends PmaTestCase
         ob_start();
         $this->assertTrue(
             $this->object->exportStructure(
-                'db', 't&bl', "\n", "example.com", "triggers", "test"
+                'db',
+                't&bl',
+                "\n",
+                "example.com",
+                "triggers",
+                "test"
             )
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "-- Triggers t&amp;bl\n",
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "foo;\nDELIMITER $$\nbarDELIMITER ;\n",
             $result
         );
@@ -1351,17 +1420,22 @@ class ExportSqlTest extends PmaTestCase
         ob_start();
         $this->assertTrue(
             $this->object->exportStructure(
-                'db', 't&bl', "\n", "example.com", "create_view", "test"
+                'db',
+                't&bl',
+                "\n",
+                "example.com",
+                "create_view",
+                "test"
             )
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "-- Structure for view t&amp;bl\n",
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "DROP TABLE IF EXISTS `t&amp;bl`;\n" .
             "dumpText3",
             $result
@@ -1378,7 +1452,7 @@ class ExportSqlTest extends PmaTestCase
             ->method('getColumns')
             ->will(
                 $this->returnValue(
-                    array()
+                    []
                 )
             );
         $GLOBALS['dbi'] = $dbi;
@@ -1387,17 +1461,22 @@ class ExportSqlTest extends PmaTestCase
         ob_start();
         $this->assertTrue(
             $this->object->exportStructure(
-                'db', 't&bl', "\n", "example.com", "create_view", "test"
+                'db',
+                't&bl',
+                "\n",
+                "example.com",
+                "create_view",
+                "test"
             )
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "CREATE TABLE`t&amp;bl`(\n\n);",
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "DROP TABLE IF EXISTS `t&amp;bl`;\n",
             $result
         );
@@ -1407,12 +1486,17 @@ class ExportSqlTest extends PmaTestCase
         ob_start();
         $this->assertTrue(
             $this->object->exportStructure(
-                'db', 't&bl', "\n", "example.com", "stand_in", "test"
+                'db',
+                't&bl',
+                "\n",
+                "example.com",
+                "stand_in",
+                "test"
             )
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "dumpText4",
             $result
         );
@@ -1430,8 +1514,8 @@ class ExportSqlTest extends PmaTestCase
             ->disableOriginalConstructor()
             ->getMock();
 
-        $flags = array();
-        $a = new stdClass;
+        $flags = [];
+        $a = new stdClass();
         $a->blob = false;
         $a->numeric = true;
         $a->type = 'ts';
@@ -1439,7 +1523,7 @@ class ExportSqlTest extends PmaTestCase
         $a->length = 2;
         $flags[] = $a;
 
-        $a = new stdClass;
+        $a = new stdClass();
         $a->blob = false;
         $a->numeric = true;
         $a->type = 'ts';
@@ -1447,7 +1531,7 @@ class ExportSqlTest extends PmaTestCase
         $a->length = 2;
         $flags[] = $a;
 
-        $a = new stdClass;
+        $a = new stdClass();
         $a->blob = true;
         $a->numeric = false;
         $a->type = 'ts';
@@ -1455,7 +1539,7 @@ class ExportSqlTest extends PmaTestCase
         $a->length = 2;
         $flags[] = $a;
 
-        $a = new stdClass;
+        $a = new stdClass();
         $a->type = "bit";
         $a->blob = false;
         $a->numeric = false;
@@ -1463,7 +1547,7 @@ class ExportSqlTest extends PmaTestCase
         $a->length = 2;
         $flags[] = $a;
 
-        $a = new stdClass;
+        $a = new stdClass();
         $a->blob = false;
         $a->numeric = true;
         $a->type = 'timestamp';
@@ -1497,7 +1581,13 @@ class ExportSqlTest extends PmaTestCase
         $dbi->expects($this->exactly(2))
             ->method('fetchRow')
             ->willReturnOnConsecutiveCalls(
-                array(null, 'test', '10', '6', "\x00\x0a\x0d\x1a"),
+                [
+                    null,
+                    'test',
+                    '10',
+                    '6',
+                    "\x00\x0a\x0d\x1a",
+                ],
                 null
             );
         $dbi->expects($this->any())->method('escapeString')
@@ -1532,38 +1622,40 @@ class ExportSqlTest extends PmaTestCase
 
         ob_start();
         $this->object->exportData(
-            'db', 'table', "\n", "example.com/err",
+            'db',
+            'table',
+            "\n",
+            "example.com/err",
             "SELECT a FROM b WHERE 1"
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'TRUNCATE TABLE &quot;table&quot;;',
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'SET IDENTITY_INSERT &quot;table&quot; ON ;',
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'INSERT DELAYED IGNORE INTO &quot;table&quot; (&quot;name&quot;, ' .
             '&quot;name&quot;, &quot;name&quot;, &quot;name&quot;, ' .
             '&quot;name&quot;) VALUES',
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '(NULL, test, 0x3130, 0x36, 0x000a0d1a);',
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "SET IDENTITY_INSERT &quot;table&quot; OFF;",
             $result
         );
-
     }
 
     /**
@@ -1578,8 +1670,8 @@ class ExportSqlTest extends PmaTestCase
             ->disableOriginalConstructor()
             ->getMock();
 
-        $flags = array();
-        $a = new stdClass;
+        $flags = [];
+        $a = new stdClass();
         $a->blob = false;
         $a->numeric = true;
         $a->type = 'real';
@@ -1590,7 +1682,7 @@ class ExportSqlTest extends PmaTestCase
         $a->primary_key = 1;
         $flags[] = $a;
 
-        $a = new stdClass;
+        $a = new stdClass();
         $a->blob = false;
         $a->numeric = true;
         $a->type = '';
@@ -1628,7 +1720,10 @@ class ExportSqlTest extends PmaTestCase
         $dbi->expects($this->exactly(2))
             ->method('fetchRow')
             ->willReturnOnConsecutiveCalls(
-                array(null, null),
+                [
+                    null,
+                    null,
+                ],
                 null
             );
 
@@ -1662,24 +1757,26 @@ class ExportSqlTest extends PmaTestCase
 
         ob_start();
         $this->object->exportData(
-            'db', 'table', "\n", "example.com/err",
+            'db',
+            'table',
+            "\n",
+            "example.com/err",
             "SELECT a FROM b WHERE 1"
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             'UPDATE IGNORE &quot;table&quot; SET &quot;name&quot; = NULL,' .
             '&quot;name&quot; = NULL WHERE CONCAT(`tbl`.`pma`) IS NULL;',
             $result
         );
-
     }
 
     /**
      * Test for PhpMyAdmin\Plugins\Export\ExportSql::exportData
      *
      * @return void
-    */
+     */
     public function testExportDataWithIsView()
     {
         $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
@@ -1707,7 +1804,7 @@ class ExportSqlTest extends PmaTestCase
         $GLOBALS['sql_views_as_tables'] = false;
         $GLOBALS['sql_include_comments'] = true;
         $GLOBALS['crlf'] = "\n";
-        $oldVal = isset($GLOBALS['sql_compatibility']) ? $GLOBALS['sql_compatibility'] : '';
+        $oldVal = $GLOBALS['sql_compatibility'] ?? '';
         $GLOBALS['sql_compatibility'] = 'NONE';
         $GLOBALS['sql_backquotes'] = true;
 
@@ -1717,12 +1814,12 @@ class ExportSqlTest extends PmaTestCase
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
-            "-- VIEW  `tbl`\n",
+        $this->assertStringContainsString(
+            "-- VIEW `tbl`\n",
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "-- Data: None\n",
             $result
         );
@@ -1735,7 +1832,7 @@ class ExportSqlTest extends PmaTestCase
      * Test for PhpMyAdmin\Plugins\Export\ExportSql::exportData
      *
      * @return void
-    */
+     */
     public function testExportDataWithError()
     {
         $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
@@ -1774,7 +1871,7 @@ class ExportSqlTest extends PmaTestCase
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '-- Error reading data for table db.table: err',
             $result
         );
@@ -1806,11 +1903,13 @@ class ExportSqlTest extends PmaTestCase
             " \" double NOT NULL DEFAULT '213'\n";
 
         $method = new ReflectionMethod(
-            'PhpMyAdmin\Plugins\Export\ExportSql', '_makeCreateTableMSSQLCompatible'
+            'PhpMyAdmin\Plugins\Export\ExportSql',
+            '_makeCreateTableMSSQLCompatible'
         );
         $method->setAccessible(true);
         $result = $method->invoke(
-            $this->object, $query
+            $this->object,
+            $query
         );
 
         $this->assertEquals(
@@ -1841,22 +1940,22 @@ class ExportSqlTest extends PmaTestCase
      * Test for PhpMyAdmin\Plugins\Export\ExportSql::initAlias
      *
      * @return void
-    */
+     */
     public function testInitAlias()
     {
-        $aliases = array(
-            'a' => array(
+        $aliases = [
+            'a' => [
                 'alias' => 'aliastest',
-                'tables' => array(
-                    'foo' => array(
-                        'alias' => 'qwerty'
-                    ),
-                    'bar' => array(
-                        'alias' => 'f'
-                    )
-                )
-            )
-        );
+                'tables' => [
+                    'foo' => [
+                        'alias' => 'qwerty',
+                    ],
+                    'bar' => [
+                        'alias' => 'f',
+                    ],
+                ],
+            ],
+        ];
         $db = 'a';
         $table = null;
 
@@ -1883,44 +1982,48 @@ class ExportSqlTest extends PmaTestCase
      * Test for PhpMyAdmin\Plugins\Export\ExportSql::getAlias
      *
      * @return void
-    */
+     */
     public function testGetAlias()
     {
-        $aliases = array(
-            'a' => array(
+        $aliases = [
+            'a' => [
                 'alias' => 'aliastest',
-                'tables' => array(
-                    'foo' => array(
+                'tables' => [
+                    'foo' => [
                         'alias' => 'qwerty',
-                        'columns' => array(
+                        'columns' => [
                             'baz' => 'p',
-                            'pqr' => 'pphymdain'
-                        )
-                    ),
-                    'bar' => array(
+                            'pqr' => 'pphymdain',
+                        ],
+                    ],
+                    'bar' => [
                         'alias' => 'f',
-                        'columns' => array(
-                            'xy' => 'n'
-                        )
-                    )
-                )
-            )
+                        'columns' => [
+                            'xy' => 'n',
+                        ],
+                    ],
+                ],
+            ],
+        ];
+
+        $this->assertEquals(
+            'f',
+            $this->object->getAlias($aliases, 'bar')
         );
 
         $this->assertEquals(
-            'f', $this->object->getAlias($aliases, 'bar')
+            'aliastest',
+            $this->object->getAlias($aliases, 'a')
         );
 
         $this->assertEquals(
-            'aliastest', $this->object->getAlias($aliases, 'a')
+            'pphymdain',
+            $this->object->getAlias($aliases, 'pqr')
         );
 
         $this->assertEquals(
-            'pphymdain', $this->object->getAlias($aliases, 'pqr')
-        );
-
-        $this->assertEquals(
-            '', $this->object->getAlias($aliases, 'abc')
+            '',
+            $this->object->getAlias($aliases, 'abc')
         );
     }
 
@@ -1928,29 +2031,29 @@ class ExportSqlTest extends PmaTestCase
      * Test for PhpMyAdmin\Plugins\Export\ExportSql::replaceWithAlias
      *
      * @return void
-    */
+     */
     public function testReplaceWithAlias()
     {
-        $aliases = array(
-            'a' => array(
+        $aliases = [
+            'a' => [
                 'alias' => 'aliastest',
-                'tables' => array(
-                    'foo' => array(
+                'tables' => [
+                    'foo' => [
                         'alias' => 'bartest',
-                        'columns' => array(
+                        'columns' => [
                             'baz' => 'p',
-                            'pqr' => 'pphymdain'
-                        )
-                    ),
-                    'bar' => array(
+                            'pqr' => 'pphymdain',
+                        ],
+                    ],
+                    'bar' => [
                         'alias' => 'f',
-                        'columns' => array(
-                            'xy' => 'n'
-                        )
-                    )
-                )
-            )
-        );
+                        'columns' => [
+                            'xy' => 'n',
+                        ],
+                    ],
+                ],
+            ],
+        ];
 
         $db = 'a';
         $table = 'foo';
@@ -1965,7 +2068,10 @@ class ExportSqlTest extends PmaTestCase
             . ") ENGINE=InnoDB  DEFAULT CHARSET=latin1 COLLATE="
             . "latin1_general_ci COMMENT='List' AUTO_INCREMENT=5";
         $result = $this->object->replaceWithAliases(
-            $sql_query, $aliases, $db, $table
+            $sql_query,
+            $aliases,
+            $db,
+            $table
         );
 
         $this->assertEquals(
@@ -1978,7 +2084,7 @@ class ExportSqlTest extends PmaTestCase
             $result
         );
 
-        $result = $this->object->replaceWithAliases($sql_query, array(), '', '');
+        $result = $this->object->replaceWithAliases($sql_query, [], '', '');
 
         $this->assertEquals(
             "CREATE TABLE IF NOT EXISTS foo (\n" .
@@ -2001,7 +2107,10 @@ class ExportSqlTest extends PmaTestCase
             . "SET NEW.xy=1; "
             . "END IF; END";
         $result = $this->object->replaceWithAliases(
-            $sql_query, $aliases, $db, $table
+            $sql_query,
+            $aliases,
+            $db,
+            $table
         );
 
         $this->assertEquals(
