@@ -5,10 +5,13 @@
  *
  * @package PhpMyAdmin-test
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Tests\Plugins\Export;
 
 use PhpMyAdmin\DatabaseInterface;
 use PhpMyAdmin\Plugins\Export\ExportTexytext;
+use PhpMyAdmin\Relation;
 use PhpMyAdmin\Tests\PmaTestCase;
 use ReflectionMethod;
 use ReflectionProperty;
@@ -28,14 +31,14 @@ class ExportTexytextTest extends PmaTestCase
      *
      * @return void
      */
-    function setUp()
+    protected function setUp(): void
     {
         $GLOBALS['server'] = 0;
         $GLOBALS['output_kanji_conversion'] = false;
         $GLOBALS['buffer_needed'] = false;
         $GLOBALS['asfile'] = false;
         $GLOBALS['save_on_server'] = false;
-        $GLOBALS['plugin_param'] = array();
+        $GLOBALS['plugin_param'] = [];
         $GLOBALS['plugin_param']['export_type'] = 'table';
         $GLOBALS['plugin_param']['single_table'] = false;
         $GLOBALS['cfgRelation']['relation'] = true;
@@ -47,7 +50,7 @@ class ExportTexytextTest extends PmaTestCase
      *
      * @return void
      */
-    public function tearDown()
+    protected function tearDown(): void
     {
         unset($this->object);
     }
@@ -265,7 +268,7 @@ class ExportTexytextTest extends PmaTestCase
         $dbi->expects($this->at(5))
             ->method('fetchRow')
             ->with(true)
-            ->will($this->returnValue(array(null, '0', 'test')));
+            ->will($this->returnValue([null, '0', 'test']));
 
         $GLOBALS['dbi'] = $dbi;
         $GLOBALS['what'] = 'foo';
@@ -275,21 +278,24 @@ class ExportTexytextTest extends PmaTestCase
         ob_start();
         $this->assertTrue(
             $this->object->exportData(
-                'db', 'ta<ble', "\n", "example.com", "SELECT"
+                'db',
+                'ta<ble',
+                "\n",
+                "example.com",
+                "SELECT"
             )
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "|fName1|fNa&amp;quot;me2|fName3",
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "|&amp;gt;|0|test",
             $result
         );
-
     }
 
     /**
@@ -306,18 +312,18 @@ class ExportTexytextTest extends PmaTestCase
         $dbi->expects($this->once())
             ->method('getColumns')
             ->with('db', 'view')
-            ->will($this->returnValue(array(1, 2)));
+            ->will($this->returnValue([1, 2]));
 
-        $keys = array(
-            array(
+        $keys = [
+            [
                 'Non_unique' => 0,
-                'Column_name' => 'cname'
-            ),
-            array(
+                'Column_name' => 'cname',
+            ],
+            [
                 'Non_unique' => 1,
-                'Column_name' => 'cname2'
-            )
-        );
+                'Column_name' => 'cname2',
+            ],
+        ];
 
         $dbi->expects($this->once())
             ->method('getTableIndexes')
@@ -332,22 +338,22 @@ class ExportTexytextTest extends PmaTestCase
 
         $this->object = $this->getMockBuilder('PhpMyAdmin\Plugins\Export\ExportTexytext')
             ->disableOriginalConstructor()
-            ->setMethods(array('formatOneColumnDefinition'))
+            ->setMethods(['formatOneColumnDefinition'])
             ->getMock();
 
         $this->object->expects($this->at(0))
             ->method('formatOneColumnDefinition')
-            ->with(1, array('cname'))
+            ->with(1, ['cname'])
             ->will($this->returnValue('c1'));
 
         $this->object->expects($this->at(1))
             ->method('formatOneColumnDefinition')
-            ->with(2, array('cname'))
+            ->with(2, ['cname'])
             ->will($this->returnValue('c2'));
 
         $result = $this->object->getTableDefStandIn('db', 'view', '#');
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             "c1\nc2",
             $result
         );
@@ -361,7 +367,7 @@ class ExportTexytextTest extends PmaTestCase
     public function testGetTableDef()
     {
         $this->object = $this->getMockBuilder('PhpMyAdmin\Plugins\Export\ExportTexytext')
-            ->setMethods(array('formatOneColumnDefinition'))
+            ->setMethods(['formatOneColumnDefinition'])
             ->getMock();
 
         // case 1
@@ -370,16 +376,16 @@ class ExportTexytextTest extends PmaTestCase
             ->disableOriginalConstructor()
             ->getMock();
 
-        $keys = array(
-            array(
+        $keys = [
+            [
                 'Non_unique' => 0,
-                'Column_name' => 'cname'
-            ),
-            array(
+                'Column_name' => 'cname',
+            ],
+            [
                 'Non_unique' => 1,
-                'Column_name' => 'cname2'
-            )
-        );
+                'Column_name' => 'cname2',
+            ],
+        ];
 
         $dbi->expects($this->once())
             ->method('getTableIndexes')
@@ -389,19 +395,19 @@ class ExportTexytextTest extends PmaTestCase
         $dbi->expects($this->exactly(2))
             ->method('fetchResult')
             ->willReturnOnConsecutiveCalls(
-                array(
-                    'fname' => array(
+                [
+                    'fname' => [
                         'foreign_table' => '<ftable',
-                        'foreign_field' => 'ffield>'
-                    )
-                ),
-                array(
-                    'fname' => array(
+                        'foreign_field' => 'ffield>',
+                    ],
+                ],
+                [
+                    'fname' => [
                         'values' => 'test-',
                         'transformation' => 'testfoo',
-                        'mimetype' => 'test<'
-                    )
-                )
+                        'mimetype' => 'test<',
+                    ],
+                ]
             );
 
         $dbi->expects($this->once())
@@ -412,33 +418,34 @@ class ExportTexytextTest extends PmaTestCase
                 )
             );
 
-        $columns = array(
+        $columns = [
             'Field' => 'fname',
-            'Comment' => 'comm'
-        );
+            'Comment' => 'comm',
+        ];
 
         $dbi->expects($this->exactly(2))
             ->method('getColumns')
             ->with('db', 'table')
-            ->will($this->returnValue(array($columns)));
+            ->will($this->returnValue([$columns]));
 
         $GLOBALS['dbi'] = $dbi;
+        $this->object->relation = new Relation($dbi);
 
         $this->object->expects($this->exactly(1))
             ->method('formatOneColumnDefinition')
-            ->with(array('Field' => 'fname', 'Comment' => 'comm'), array('cname'))
+            ->with(['Field' => 'fname', 'Comment' => 'comm'], ['cname'])
             ->will($this->returnValue(1));
 
         $GLOBALS['cfgRelation']['relation'] = true;
-        $_SESSION['relation'][0] = array(
+        $_SESSION['relation'][0] = [
             'PMA_VERSION' => PMA_VERSION,
             'relwork' => true,
             'commwork' => true,
             'mimework' => true,
             'db' => 'db',
             'relation' => 'rel',
-            'column_info' => 'col'
-        );
+            'column_info' => 'col',
+        ];
 
         $result = $this->object->getTableDef(
             'db',
@@ -450,13 +457,13 @@ class ExportTexytextTest extends PmaTestCase
             true
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '1|&lt;ftable (ffield&gt;)|comm|Test&lt;',
             $result
         );
     }
 
-     /**
+    /**
      * Test for PhpMyAdmin\Plugins\Export\ExportTexytext::getTriggers
      *
      * @return void
@@ -467,14 +474,14 @@ class ExportTexytextTest extends PmaTestCase
             ->disableOriginalConstructor()
             ->getMock();
 
-        $triggers = array(
-            array(
+        $triggers = [
+            [
                 'name' => 'tna"me',
                 'action_timing' => 'ac>t',
                 'event_manipulation' => 'manip&',
-                'definition' => 'def'
-            )
-        );
+                'definition' => 'def',
+            ],
+        ];
 
         $dbi->expects($this->once())
             ->method('getTriggers')
@@ -485,16 +492,15 @@ class ExportTexytextTest extends PmaTestCase
 
         $result = $this->object->getTriggers('database', 'ta<ble');
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '|tna"me|ac>t|manip&|def',
             $result
         );
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '|Name|Time|Event|Definition',
             $result
         );
-
     }
 
     /**
@@ -515,7 +521,7 @@ class ExportTexytextTest extends PmaTestCase
             ->will($this->returnValue(1));
 
         $this->object = $this->getMockBuilder('PhpMyAdmin\Plugins\Export\ExportTexytext')
-            ->setMethods(array('getTableDef', 'getTriggers', 'getTableDefStandIn'))
+            ->setMethods(['getTableDef', 'getTriggers', 'getTableDefStandIn'])
             ->getMock();
 
         $this->object->expects($this->at(0))
@@ -531,8 +537,16 @@ class ExportTexytextTest extends PmaTestCase
         $this->object->expects($this->at(2))
             ->method('getTableDef')
             ->with(
-                'db', 't&bl', "\n", "example.com",
-                false, false, false, false, true, true
+                'db',
+                't&bl',
+                "\n",
+                "example.com",
+                false,
+                false,
+                false,
+                false,
+                true,
+                true
             )
             ->will($this->returnValue('dumpText3'));
 
@@ -547,12 +561,17 @@ class ExportTexytextTest extends PmaTestCase
         ob_start();
         $this->assertTrue(
             $this->object->exportStructure(
-                'db', 't&bl', "\n", "example.com", "create_table", "test"
+                'db',
+                't&bl',
+                "\n",
+                "example.com",
+                "create_table",
+                "test"
             )
         );
         $result = ob_get_clean();
 
-        $this->assertContains(
+        $this->assertStringContainsString(
             '== Table structure for table t&amp;bl' . "\n\ndumpText1",
             $result
         );
@@ -561,7 +580,12 @@ class ExportTexytextTest extends PmaTestCase
         ob_start();
         $this->assertTrue(
             $this->object->exportStructure(
-                'db', 't&bl', "\n", "example.com", "triggers", "test"
+                'db',
+                't&bl',
+                "\n",
+                "example.com",
+                "triggers",
+                "test"
             )
         );
         $result = ob_get_clean();
@@ -575,7 +599,12 @@ class ExportTexytextTest extends PmaTestCase
         ob_start();
         $this->assertTrue(
             $this->object->exportStructure(
-                'db', 't&bl', "\n", "example.com", "create_view", "test"
+                'db',
+                't&bl',
+                "\n",
+                "example.com",
+                "create_view",
+                "test"
             )
         );
         $result = ob_get_clean();
@@ -589,7 +618,12 @@ class ExportTexytextTest extends PmaTestCase
         ob_start();
         $this->assertTrue(
             $this->object->exportStructure(
-                'db', 't&bl', "\n", "example.com", "stand_in", "test"
+                'db',
+                't&bl',
+                "\n",
+                "example.com",
+                "stand_in",
+                "test"
             )
         );
         $result = ob_get_clean();
@@ -607,33 +641,33 @@ class ExportTexytextTest extends PmaTestCase
      */
     public function testFormatOneColumnDefinition()
     {
-        $cols = array(
+        $cols = [
             'Null' => 'Yes',
             'Field' => 'field',
             'Key' => 'PRI',
-            'Type' => 'set(abc)enum123'
-        );
+            'Type' => 'set(abc)enum123',
+        ];
 
-        $unique_keys = array(
-            'field'
-        );
+        $unique_keys = [
+            'field',
+        ];
 
         $this->assertEquals(
             '|//**field**//|set(abc)|Yes|NULL',
             $this->object->formatOneColumnDefinition($cols, $unique_keys)
         );
 
-        $cols = array(
+        $cols = [
             'Null' => 'NO',
             'Field' => 'fields',
             'Key' => 'COMP',
             'Type' => '',
-            'Default' => 'def'
-        );
+            'Default' => 'def',
+        ];
 
-        $unique_keys = array(
-            'field'
-        );
+        $unique_keys = [
+            'field',
+        ];
 
         $this->assertEquals(
             '|fields|&amp;nbsp;|No|def',
