@@ -5,8 +5,11 @@
  *
  * @package PhpMyAdmin-test
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Tests\Rte;
 
+use PhpMyAdmin\Config;
 use PhpMyAdmin\Response;
 use PhpMyAdmin\Rte\Events;
 use PHPUnit\Framework\TestCase;
@@ -18,29 +21,28 @@ use PHPUnit\Framework\TestCase;
  */
 class EventsTest extends TestCase
 {
+    /**
+     * @var Events
+     */
+    private $events;
+
     /**
      * Set up
      *
      * @return void
      */
-    protected function setUp()
+    protected function setUp(): void
     {
+        $GLOBALS['PMA_Config'] = new Config();
+        $GLOBALS['PMA_Config']->enableBc();
         $GLOBALS['server'] = 0;
         $GLOBALS['db'] = 'db';
         $GLOBALS['table'] = 'table';
         $GLOBALS['PMA_PHP_SELF'] = 'index.php';
-        $GLOBALS['cfg']['AllowThirdPartyFraming'] = false;
-        $GLOBALS['cfg']['SendErrorReports'] = 'ask';
-        $GLOBALS['cfg']['DefaultTabDatabase'] = 'structure';
-        $GLOBALS['cfg']['ShowDatabasesNavigationAsTree'] = true;
-        $GLOBALS['cfg']['DefaultTabTable'] = 'browse';
-        $GLOBALS['cfg']['NavigationTreeDefaultTabTable'] = 'structure';
-        $GLOBALS['cfg']['NavigationTreeDefaultTabTable2'] = '';
-        $GLOBALS['cfg']['LimitChars'] = 50;
-        $GLOBALS['cfg']['Confirm'] = true;
-        $GLOBALS['cfg']['LoginCookieValidity'] = 1440;
-        $GLOBALS['cfg']['ServerDefault'] = '';
+        $GLOBALS['cfg']['Server']['DisableIS'] = false;
         $GLOBALS['tear_down']['server'] = true;
+
+        $this->events = new Events($GLOBALS['dbi']);
     }
 
     /**
@@ -48,7 +50,7 @@ class EventsTest extends TestCase
      *
      * @return void
      */
-    public function tearDown()
+    protected function tearDown(): void
     {
         if ($GLOBALS['tear_down']['server']) {
             unset($GLOBALS['cfg']['ServerDefault']);
@@ -57,7 +59,7 @@ class EventsTest extends TestCase
     }
 
     /**
-     * Test for Events::getDataFromRequest
+     * Test for getDataFromRequest
      *
      * @param array $in  Input
      * @param array $out Expected output
@@ -66,17 +68,15 @@ class EventsTest extends TestCase
      *
      * @dataProvider providerGetDataFromRequest
      */
-    public function testGetDataFromRequestEmpty($in, $out)
+    public function testGetDataFromRequestEmpty($in, $out): void
     {
-        global $_POST;
-
         unset($_POST);
         foreach ($in as $key => $value) {
             if ($value !== '') {
                 $_POST[$key] = $value;
             }
         }
-        $this->assertEquals($out, Events::getDataFromRequest());
+        $this->assertEquals($out, $this->events->getDataFromRequest());
     }
 
     /**
@@ -86,9 +86,9 @@ class EventsTest extends TestCase
      */
     public function providerGetDataFromRequest()
     {
-        return array(
-            array(
-                array(
+        return [
+            [
+                [
                     'item_name'           => '',
                     'item_type'           => '',
                     'item_original_name'  => '',
@@ -101,9 +101,9 @@ class EventsTest extends TestCase
                     'item_definition'     => '',
                     'item_preserve'       => '',
                     'item_comment'        => '',
-                    'item_definer'        => ''
-                ),
-                array(
+                    'item_definer'        => '',
+                ],
+                [
                     'item_name'           => '',
                     'item_type'           => 'ONE TIME',
                     'item_type_toggle'    => 'RECURRING',
@@ -117,11 +117,11 @@ class EventsTest extends TestCase
                     'item_definition'     => '',
                     'item_preserve'       => '',
                     'item_comment'        => '',
-                    'item_definer'        => ''
-                )
-            ),
-            array(
-                array(
+                    'item_definer'        => '',
+                ],
+            ],
+            [
+                [
                     'item_name'           => 'foo',
                     'item_type'           => 'RECURRING',
                     'item_original_name'  => 'foo',
@@ -134,9 +134,9 @@ class EventsTest extends TestCase
                     'item_definition'     => 'foo',
                     'item_preserve'       => 'foo',
                     'item_comment'        => 'foo',
-                    'item_definer'        => 'foo'
-                ),
-                array(
+                    'item_definer'        => 'foo',
+                ],
+                [
                     'item_name'           => 'foo',
                     'item_type'           => 'RECURRING',
                     'item_type_toggle'    => 'ONE TIME',
@@ -150,14 +150,14 @@ class EventsTest extends TestCase
                     'item_definition'     => 'foo',
                     'item_preserve'       => 'foo',
                     'item_comment'        => 'foo',
-                    'item_definer'        => 'foo'
-                )
-            ),
-        );
+                    'item_definer'        => 'foo',
+                ],
+            ],
+        ];
     }
 
     /**
-     * Test for Events::getEditorForm
+     * Test for getEditorForm
      *
      * @param array $data    Data for routine
      * @param array $matcher Matcher
@@ -166,12 +166,12 @@ class EventsTest extends TestCase
      *
      * @dataProvider providerGetEditorFormAdd
      */
-    public function testGetEditorFormAdd($data, $matcher)
+    public function testGetEditorFormAdd($data, $matcher): void
     {
-        Events::setGlobals();
-        $this->assertContains(
+        $this->events->setGlobals();
+        $this->assertStringContainsString(
             $matcher,
-            Events::getEditorForm('add', 'change', $data)
+            $this->events->getEditorForm('add', 'change', $data)
         );
     }
 
@@ -182,7 +182,7 @@ class EventsTest extends TestCase
      */
     public function providerGetEditorFormAdd()
     {
-        $data = array(
+        $data = [
             'item_name'           => '',
             'item_type'           => 'ONE TIME',
             'item_type_toggle'    => 'RECURRING',
@@ -196,55 +196,55 @@ class EventsTest extends TestCase
             'item_definition'     => '',
             'item_preserve'       => '',
             'item_comment'        => '',
-            'item_definer'        => ''
-        );
+            'item_definer'        => '',
+        ];
 
-        return array(
-            array(
+        return [
+            [
                 $data,
-                "<input name='add_item'"
-            ),
-            array(
+                "<input name='add_item'",
+            ],
+            [
                 $data,
-                "<input type='text' name='item_name'"
-            ),
-            array(
+                "<input type='text' name='item_name'",
+            ],
+            [
                 $data,
-                "<select name='item_status'"
-            ),
-            array(
+                "<select name='item_status'",
+            ],
+            [
                 $data,
-                "<input name='item_type'"
-            ),
-            array(
+                "<input name='item_type'",
+            ],
+            [
                 $data,
-                "<input type='text' name='item_execute_at'"
-            ),
-            array(
+                "<input type='text' name='item_execute_at'",
+            ],
+            [
                 $data,
-                "<input type='text' name='item_ends'"
-            ),
-            array(
+                "<input type='text' name='item_ends'",
+            ],
+            [
                 $data,
-                "<textarea name='item_definition'"
-            ),
-            array(
+                "<textarea name='item_definition'",
+            ],
+            [
                 $data,
-                "<input type='text' name='item_definer'"
-            ),
-            array(
+                "<input type='text' name='item_definer'",
+            ],
+            [
                 $data,
-                "<input type='text' name='item_comment'"
-            ),
-            array(
+                "<input type='text' name='item_comment'",
+            ],
+            [
                 $data,
-                "<input type='submit' name='editor_process_add'"
-            )
-        );
+                "<input type='submit' name='editor_process_add'",
+            ],
+        ];
     }
 
     /**
-     * Test for Events::getEditorForm
+     * Test for getEditorForm
      *
      * @param array $data    Data for routine
      * @param array $matcher Matcher
@@ -253,12 +253,12 @@ class EventsTest extends TestCase
      *
      * @dataProvider providerGetEditorFormEdit
      */
-    public function testGetEditorFormEdit($data, $matcher)
+    public function testGetEditorFormEdit($data, $matcher): void
     {
-        Events::setGlobals();
-        $this->assertContains(
+        $this->events->setGlobals();
+        $this->assertStringContainsString(
             $matcher,
-            Events::getEditorForm('edit', 'change', $data)
+            $this->events->getEditorForm('edit', 'change', $data)
         );
     }
 
@@ -269,7 +269,7 @@ class EventsTest extends TestCase
      */
     public function providerGetEditorFormEdit()
     {
-        $data = array(
+        $data = [
             'item_name'           => 'foo',
             'item_type'           => 'RECURRING',
             'item_type_toggle'    => 'ONE TIME',
@@ -283,55 +283,55 @@ class EventsTest extends TestCase
             'item_definition'     => 'SET @A=1;',
             'item_preserve'       => '',
             'item_comment'        => '',
-            'item_definer'        => ''
-        );
+            'item_definer'        => '',
+        ];
 
-        return array(
-            array(
+        return [
+            [
                 $data,
-                "<input name='edit_item'"
-            ),
-            array(
+                "<input name='edit_item'",
+            ],
+            [
                 $data,
-                "<input type='text' name='item_name'"
-            ),
-            array(
+                "<input type='text' name='item_name'",
+            ],
+            [
                 $data,
-                "<select name='item_status'"
-            ),
-            array(
+                "<select name='item_status'",
+            ],
+            [
                 $data,
-                "<input name='item_type'"
-            ),
-            array(
+                "<input name='item_type'",
+            ],
+            [
                 $data,
-                "<input type='text' name='item_execute_at'"
-            ),
-            array(
+                "<input type='text' name='item_execute_at'",
+            ],
+            [
                 $data,
-                "<input type='text' name='item_ends'"
-            ),
-            array(
+                "<input type='text' name='item_ends'",
+            ],
+            [
                 $data,
-                "<textarea name='item_definition'"
-            ),
-            array(
+                "<textarea name='item_definition'",
+            ],
+            [
                 $data,
-                "<input type='text' name='item_definer'"
-            ),
-            array(
+                "<input type='text' name='item_definer'",
+            ],
+            [
                 $data,
-                "<input type='text' name='item_comment'"
-            ),
-            array(
+                "<input type='text' name='item_comment'",
+            ],
+            [
                 $data,
-                "<input type='submit' name='editor_process_edit'"
-            )
-        );
+                "<input type='submit' name='editor_process_edit'",
+            ],
+        ];
     }
 
     /**
-     * Test for Events::getEditorForm
+     * Test for getEditorForm
      *
      * @param array $data    Data for routine
      * @param array $matcher Matcher
@@ -340,13 +340,13 @@ class EventsTest extends TestCase
      *
      * @dataProvider providerGetEditorFormAjax
      */
-    public function testGetEditorFormAjax($data, $matcher)
+    public function testGetEditorFormAjax($data, $matcher): void
     {
         Response::getInstance()->setAjax(true);
-        Events::setGlobals();
-        $this->assertContains(
+        $this->events->setGlobals();
+        $this->assertStringContainsString(
             $matcher,
-            Events::getEditorForm('edit', 'change', $data)
+            $this->events->getEditorForm('edit', 'change', $data)
         );
         Response::getInstance()->setAjax(false);
     }
@@ -358,7 +358,7 @@ class EventsTest extends TestCase
      */
     public function providerGetEditorFormAjax()
     {
-        $data = array(
+        $data = [
             'item_name'           => '',
             'item_type'           => 'RECURRING',
             'item_type_toggle'    => 'ONE TIME',
@@ -372,27 +372,27 @@ class EventsTest extends TestCase
             'item_definition'     => '',
             'item_preserve'       => '',
             'item_comment'        => '',
-            'item_definer'        => ''
-        );
+            'item_definer'        => '',
+        ];
 
-        return array(
-            array(
+        return [
+            [
                 $data,
-                "<select name='item_type'"
-            ),
-            array(
+                "<select name='item_type'",
+            ],
+            [
                 $data,
-                "<input type='hidden' name='editor_process_edit'"
-            ),
-            array(
+                "<input type='hidden' name='editor_process_edit'",
+            ],
+            [
                 $data,
-                "<input type='hidden' name='ajax_request'"
-            )
-        );
+                "<input type='hidden' name='ajax_request'",
+            ],
+        ];
     }
 
     /**
-     * Test for Events::getQueryFromRequest
+     * Test for getQueryFromRequest
      *
      * @param array  $request Request
      * @param string $query   Query
@@ -402,12 +402,12 @@ class EventsTest extends TestCase
      *
      * @dataProvider providerGetQueryFromRequest
      */
-    public function testGetQueryFromRequest($request, $query, $num_err)
+    public function testGetQueryFromRequest($request, $query, $num_err): void
     {
-        global $_POST, $errors;
+        global $errors;
 
-        $errors = array();
-        Events::setGlobals();
+        $errors = [];
+        $this->events->setGlobals();
 
         unset($_POST);
         $_POST = $request;
@@ -420,7 +420,7 @@ class EventsTest extends TestCase
             ->will($this->returnArgument(0));
         $GLOBALS['dbi'] = $dbi;
 
-        $this->assertEquals($query, Events::getQueryFromRequest());
+        $this->assertEquals($query, $this->events->getQueryFromRequest());
         $this->assertCount($num_err, $errors);
     }
 
@@ -431,48 +431,48 @@ class EventsTest extends TestCase
      */
     public function providerGetQueryFromRequest()
     {
-        return array(
+        return [
             // Testing success
-            array(
-                array( // simple once-off event
+            [
+                [ // simple once-off event
                     'item_name'       => 's o m e e v e n t\\',
                     'item_type'       => 'ONE TIME',
                     'item_execute_at' => '2050-01-01 00:00:00',
-                    'item_definition' => 'SET @A=0;'
-                ),
+                    'item_definition' => 'SET @A=0;',
+                ],
                 'CREATE EVENT `s o m e e v e n t\` ON SCHEDULE AT \'2050-01-01 ' .
                 '00:00:00\' ON COMPLETION NOT PRESERVE DO SET @A=0;',
-                0
-            ),
-            array(
-                array( // full once-off event
+                0,
+            ],
+            [
+                [ // full once-off event
                     'item_name'       => 'evn',
                     'item_definer'    => 'me@home',
                     'item_type'       => 'ONE TIME',
                     'item_execute_at' => '2050-01-01 00:00:00',
                     'item_preserve'   => 'ON',
                     'item_status'     => 'ENABLED',
-                    'item_definition' => 'SET @A=0;'
-                ),
+                    'item_definition' => 'SET @A=0;',
+                ],
                 'CREATE DEFINER=`me`@`home` EVENT `evn` ON SCHEDULE AT ' .
                 '\'2050-01-01 00:00:00\' ON COMPLETION PRESERVE ENABLE DO SET @A=0;',
-                0
-            ),
-            array(
-                array( // simple recurring event
+                0,
+            ],
+            [
+                [ // simple recurring event
                     'item_name'           => 'rec_``evn',
                     'item_type'           => 'RECURRING',
                     'item_interval_value' => '365',
                     'item_interval_field' => 'DAY',
                     'item_status'         => 'DISABLED',
-                    'item_definition'     => 'SET @A=0;'
-                ),
+                    'item_definition'     => 'SET @A=0;',
+                ],
                 'CREATE EVENT `rec_````evn` ON SCHEDULE EVERY 365 DAY ON ' .
                 'COMPLETION NOT PRESERVE DISABLE DO SET @A=0;',
-                0
-            ),
-            array(
-                array( // full recurring event
+                0,
+            ],
+            [
+                [ // full recurring event
                     'item_name'           => 'rec_evn2',
                     'item_definer'        => 'evil``user><\\@work\\',
                     'item_type'           => 'RECURRING',
@@ -482,58 +482,58 @@ class EventsTest extends TestCase
                     'item_ends'           => '2050-01-01',
                     'item_preserve'       => 'ON',
                     'item_status'         => 'SLAVESIDE_DISABLED',
-                    'item_definition'     => 'SET @A=0;'
-                ),
+                    'item_definition'     => 'SET @A=0;',
+                ],
                 'CREATE DEFINER=`evil````user><\`@`work\` EVENT `rec_evn2` ON ' .
                 'SCHEDULE EVERY 365 DAY STARTS \'1900-01-01\' ENDS \'2050-01-01\' ' .
                 'ON COMPLETION PRESERVE DISABLE ON SLAVE DO SET @A=0;',
-                0
-            ),
+                0,
+            ],
             // Testing failures
-            array(
-                array( // empty request
-                ),
+            [
+                [ // empty request
+                ],
                 'CREATE EVENT ON SCHEDULE ON COMPLETION NOT PRESERVE DO ',
-                3
-            ),
-            array(
-                array(
+                3,
+            ],
+            [
+                [
                     'item_name'       => 's o m e e v e n t\\',
                     'item_definer'    => 'someuser', // invalid definer format
                     'item_type'       => 'ONE TIME',
                     'item_execute_at' => '', // no execution time
-                    'item_definition' => 'SET @A=0;'
-                ),
+                    'item_definition' => 'SET @A=0;',
+                ],
                 'CREATE EVENT `s o m e e v e n t\` ON SCHEDULE ON COMPLETION NOT ' .
                 'PRESERVE DO SET @A=0;',
-                2
-            ),
-            array(
-                array(
+                2,
+            ],
+            [
+                [
                     'item_name'           => 'rec_``evn',
                     'item_type'           => 'RECURRING',
                     'item_interval_value' => '', // no interval value
                     'item_interval_field' => 'DAY',
                     'item_status'         => 'DISABLED',
-                    'item_definition'     => 'SET @A=0;'
-                ),
+                    'item_definition'     => 'SET @A=0;',
+                ],
                 'CREATE EVENT `rec_````evn` ON SCHEDULE ON COMPLETION NOT ' .
                 'PRESERVE DISABLE DO SET @A=0;',
-                1
-            ),
-            array(
-                array( // simple recurring event
+                1,
+            ],
+            [
+                [ // simple recurring event
                     'item_name'           => 'rec_``evn',
                     'item_type'           => 'RECURRING',
                     'item_interval_value' => '365',
                     'item_interval_field' => 'CENTURIES', // invalid interval field
                     'item_status'         => 'DISABLED',
-                    'item_definition'     => 'SET @A=0;'
-                ),
+                    'item_definition'     => 'SET @A=0;',
+                ],
                 'CREATE EVENT `rec_````evn` ON SCHEDULE ON COMPLETION NOT ' .
                 'PRESERVE DISABLE DO SET @A=0;',
-                1
-            ),
-        );
+                1,
+            ],
+        ];
     }
 }
