@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin-test
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Tests;
 
 use PhpMyAdmin\SysInfo;
@@ -27,7 +29,7 @@ class SysInfoTest extends TestCase
      *
      * @dataProvider sysInfoOsProvider
      */
-    public function testGetSysInfoOs($os, $expected)
+    public function testGetSysInfoOs($os, $expected): void
     {
         $this->assertEquals(
             $expected,
@@ -42,12 +44,24 @@ class SysInfoTest extends TestCase
      */
     public function sysInfoOsProvider()
     {
-        return array(
-            array('FreeBSD', 'Linux'),
-            array('Linux', 'Linux'),
-            array('Winnt', 'Winnt'),
-            array('SunOS', 'SunOS'),
-        );
+        return [
+            [
+                'FreeBSD',
+                'Linux',
+            ],
+            [
+                'Linux',
+                'Linux',
+            ],
+            [
+                'Winnt',
+                'Winnt',
+            ],
+            [
+                'SunOS',
+                'SunOS',
+            ],
+        ];
     }
 
     /**
