@@ -5,14 +5,17 @@
  *
  * @package PhpMyAdmin-test
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Tests;
 
 use PhpMyAdmin\DatabaseInterface;
 use PhpMyAdmin\Tests\PmaTestCase;
 use PhpMyAdmin\Tracker;
 use PhpMyAdmin\Util;
-use PHPUnit\Framework\Assert;
 use ReflectionClass;
+use ReflectionMethod;
+use ReflectionProperty;
 
 /**
  * Tests for PhpMyAdmin\Tracker
@@ -27,7 +30,7 @@ class TrackerTest extends PmaTestCase
      * @access protected
      * @return void
      */
-    protected function setUp()
+    protected function setUp(): void
     {
         /**
          * SET these to avoid undefined index error
@@ -40,11 +43,11 @@ class TrackerTest extends PmaTestCase
         $GLOBALS['cfg']['Server']['tracking_version_auto_create'] = '';
         $GLOBALS['cfg']['Server']['DisableIS'] = false;
 
-        $_SESSION['relation'][$GLOBALS['server']] = array(
+        $_SESSION['relation'][$GLOBALS['server']] = [
             'PMA_VERSION' => PMA_VERSION,
             'db' => 'pmadb',
-            'tracking' => 'tracking'
-        );
+            'tracking' => 'tracking',
+        ];
 
         $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
             ->disableOriginalConstructor()
@@ -62,9 +65,12 @@ class TrackerTest extends PmaTestCase
      */
     public function testEnabled()
     {
+        $reflection = new ReflectionProperty(Tracker::class, 'enabled');
+        $reflection->setAccessible(true);
+
         Tracker::enable();
         $this->assertTrue(
-            Assert::readAttribute('PhpMyAdmin\Tracker', 'enabled')
+            $reflection->getValue()
         );
     }
 
@@ -76,7 +82,7 @@ class TrackerTest extends PmaTestCase
      */
     public function testIsActive()
     {
-        $attr = new \ReflectionProperty('PhpMyAdmin\Tracker', 'enabled');
+        $attr = new ReflectionProperty('PhpMyAdmin\Tracker', 'enabled');
         $attr->setAccessible(true);
         $attr->setValue(false);
 
@@ -86,21 +92,21 @@ class TrackerTest extends PmaTestCase
 
         Tracker::enable();
 
-        $_SESSION['relation'][$GLOBALS['server']] = array(
+        $_SESSION['relation'][$GLOBALS['server']] = [
             'PMA_VERSION' => PMA_VERSION,
-            'trackingwork' => false
-        );
+            'trackingwork' => false,
+        ];
 
         $this->assertFalse(
             Tracker::isActive()
         );
 
-        $_SESSION['relation'][$GLOBALS['server']] = array(
+        $_SESSION['relation'][$GLOBALS['server']] = [
             'PMA_VERSION' => PMA_VERSION,
             'trackingwork' => true,
             'db' => 'pmadb',
-            'tracking' => 'tracking'
-        );
+            'tracking' => 'tracking',
+        ];
 
         $this->assertTrue(
             Tracker::isActive()
@@ -117,7 +123,7 @@ class TrackerTest extends PmaTestCase
      * @test
      * @dataProvider getTableNameData
      */
-    public function testGetTableName($string, $expected)
+    public function testGetTableName($string, $expected): void
     {
         $reflection = new ReflectionClass('PhpMyAdmin\Tracker');
         $method = $reflection->getMethod("getTableName");
@@ -125,7 +131,7 @@ class TrackerTest extends PmaTestCase
 
         $this->assertEquals(
             $expected,
-            $method->invokeArgs(null, array($string))
+            $method->invokeArgs(null, [$string])
         );
     }
 
@@ -137,11 +143,20 @@ class TrackerTest extends PmaTestCase
      */
     public function getTableNameData()
     {
-        return array(
-            array("`tbl`;", "tbl"),
-            array(" `pma.table` ", "table"),
-            array(" `pma.table\nfoobar` ", "table")
-        );
+        return [
+            [
+                "`tbl`;",
+                "tbl",
+            ],
+            [
+                " `pma.table` ",
+                "table",
+            ],
+            [
+                " `pma.table\nfoobar` ",
+                "table",
+            ],
+        ];
     }
 
     /**
@@ -152,7 +167,7 @@ class TrackerTest extends PmaTestCase
      */
     public function testIsTracked()
     {
-        $attr = new \ReflectionProperty('PhpMyAdmin\Tracker', 'enabled');
+        $attr = new ReflectionProperty('PhpMyAdmin\Tracker', 'enabled');
         $attr->setAccessible(true);
         $attr->setValue(false);
 
@@ -219,47 +234,39 @@ class TrackerTest extends PmaTestCase
          * to passing $this->anything()
          */
 
-        $getColumnsResult = array(
-            array(
+        $getColumnsResult = [
+            [
                 'Field' => 'field1',
                 'Type' => 'int(11)',
-                'Key' => 'PRI'
-            ),
-            array(
+                'Key' => 'PRI',
+            ],
+            [
                 'Field' => 'field2',
                 'Type' => 'text',
-                'Key' => ''
-            )
-        );
+                'Key' => '',
+            ],
+        ];
         $dbi->expects($this->once())->method('getColumns')
             ->with('pma_test', 'pma_tbl')
             ->will($this->returnValue($getColumnsResult));
 
-        $getIndexesResult = array(
-            array(
+        $getIndexesResult = [
+            [
                 'Table' => 'pma_tbl',
                 'Field' => 'field1',
-                'Key' => 'PRIMARY'
-            )
-        );
+                'Key' => 'PRIMARY',
+            ],
+        ];
         $dbi->expects($this->once())->method('getTableIndexes')
             ->with('pma_test', 'pma_tbl')
             ->will($this->returnValue($getIndexesResult));
 
-        $tableStatusArray = array(
-            array(
-                'Name' => 'pma_tbl',
-                'Rows' => '1',
-                'Create_time' => '2013-02-22 02:04:04',
-                'Update_time' => '2013-02-22 21:46:48'
-            )
-        );
         $dbi->expects($this->exactly(3))
             ->method('tryQuery')
             ->withConsecutive(
-                array("SHOW TABLE STATUS FROM `pma_test` WHERE Name = 'pma_tbl'"),
-                array('USE `pma_test`'),
-                array('SHOW CREATE TABLE `pma_test`.`pma_tbl`')
+                ["SHOW TABLE STATUS FROM `pma_test` WHERE Name = 'pma_tbl'"],
+                ['USE `pma_test`'],
+                ['SHOW CREATE TABLE `pma_test`.`pma_tbl`']
             )
             ->willReturnOnConsecutiveCalls(
                 'res',
@@ -294,15 +301,15 @@ class TrackerTest extends PmaTestCase
         "\n',
         '11' )";
 
-        $queryResults = array(
-            array(
+        $queryResults = [
+            [
                 $expectedMainQuery,
                 DatabaseInterface::CONNECT_CONTROL,
                 0,
                 false,
-                'executed'
-            )
-        );
+                'executed',
+            ],
+        ];
 
         $dbi->expects($this->any())->method('query')
             ->will($this->returnValueMap($queryResults));
@@ -310,7 +317,7 @@ class TrackerTest extends PmaTestCase
         $dbi->expects($this->any())->method('escapeString')
             ->will($this->returnArgument(0));
         $dbi->expects($this->any())->method('getCompatibilities')
-            ->will($this->returnValue(array()));
+            ->will($this->returnValue([]));
 
         $GLOBALS['dbi'] = $dbi;
         $this->assertEquals(
@@ -413,8 +420,12 @@ class TrackerTest extends PmaTestCase
      * @test
      *
      */
-    public function testChangeTracking($dbname = 'pma_db', $tablename = 'pma_tbl',
-        $version = '0.1', $new_state = '1', $type = null
+    public function testChangeTracking(
+        $dbname = 'pma_db',
+        $tablename = 'pma_tbl',
+        $version = '0.1',
+        $new_state = '1',
+        $type = null
     ) {
         $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
             ->disableOriginalConstructor()
@@ -436,8 +447,10 @@ class TrackerTest extends PmaTestCase
 
         $GLOBALS['dbi'] = $dbi;
 
-        if ($type == null) {
-            $method = new \ReflectionMethod('PhpMyAdmin\Tracker', '_changeTracking');
+        $result = null;
+
+        if ($type === null) {
+            $method = new ReflectionMethod('PhpMyAdmin\Tracker', '_changeTracking');
             $method->setAccessible(true);
             $result = $method->invoke(
                 null,
@@ -482,16 +495,16 @@ class TrackerTest extends PmaTestCase
 
         $date  = Util::date('Y-m-d H:i:s');
 
-        $new_data = array(
-            array(
+        $new_data = [
+            [
                 'username' => 'user1',
-                'statement' => 'test_statement1'
-            ),
-            array(
+                'statement' => 'test_statement1',
+            ],
+            [
                 'username' => 'user2',
-                'statement' => 'test_statement2'
-            )
-        );
+                'statement' => 'test_statement2',
+            ],
+        ];
 
         $sql_query_2 = " UPDATE `pmadb`.`tracking`" .
         " SET `data_sql` = '# log $date user1test_statement1\n" .
@@ -503,10 +516,22 @@ class TrackerTest extends PmaTestCase
         $dbi->method('query')
             ->will(
                 $this->returnValueMap(
-                    array(
-                        array($sql_query_1, DatabaseInterface::CONNECT_CONTROL, 0, false, "executed_1"),
-                        array($sql_query_2, DatabaseInterface::CONNECT_CONTROL, 0, false, "executed_2")
-                    )
+                    [
+                        [
+                            $sql_query_1,
+                            DatabaseInterface::CONNECT_CONTROL,
+                            0,
+                            false,
+                            "executed_1",
+                        ],
+                        [
+                            $sql_query_2,
+                            DatabaseInterface::CONNECT_CONTROL,
+                            0,
+                            false,
+                            "executed_2",
+                        ],
+                    ]
                 )
             );
 
@@ -570,7 +595,7 @@ class TrackerTest extends PmaTestCase
      * @test
      * @dataProvider getTrackedDataProvider
      */
-    public function testGetTrackedData($fetchArrayReturn, $expectedArray)
+    public function testGetTrackedData($fetchArrayReturn, $expectedArray): void
     {
         $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
             ->disableOriginalConstructor()
@@ -589,11 +614,20 @@ class TrackerTest extends PmaTestCase
             ->method('escapeString')
             ->will(
                 $this->returnValueMap(
-                    array(
-                        array("pma'db", "pma\'db"),
-                        array("pma'table", "pma\'table"),
-                        array("1.0", "1.0"),
-                    )
+                    [
+                        [
+                            "pma'db",
+                            "pma\'db",
+                        ],
+                        [
+                            "pma'table",
+                            "pma\'table",
+                        ],
+                        [
+                            "1.0",
+                            "1.0",
+                        ],
+                    ]
                 )
             );
 
@@ -613,81 +647,87 @@ class TrackerTest extends PmaTestCase
      */
     public function getTrackedDataProvider()
     {
-        $fetchArrayReturn = array(
-            array(
+        $fetchArrayReturn = [
+            [
                 "schema_sql" => "# log 20-03-2013 23:33:58 user1\nstat1" .
                 "# log 20-03-2013 23:39:58 user2\n",
                 "data_sql" => "# log ",
                 "schema_snapshot" => "dataschema",
-                "tracking" => "SELECT, DELETE"
-            )
-        );
+                "tracking" => "SELECT, DELETE",
+            ],
+        ];
 
-        $data = array(
-            array(
+        $data = [
+            [
                 'date_from' => '20-03-2013 23:33:58',
                 'date_to' => '20-03-2013 23:39:58',
-                'ddlog' => array(
-                                array(
-                                    'date' => '20-03-2013 23:33:58',
-                                    'username' => 'user1',
-                                    'statement' => "\nstat1"
-                                ),
-                                array(
-                                    'date' => '20-03-2013 23:39:58',
-                                    'username' => 'user2',
-                                    'statement' => ""
-                                )
-                            ),
-                'dmlog' => array(),
+                'ddlog' => [
+                    [
+                        'date' => '20-03-2013 23:33:58',
+                        'username' => 'user1',
+                        'statement' => "\nstat1",
+                    ],
+                    [
+                        'date' => '20-03-2013 23:39:58',
+                        'username' => 'user2',
+                        'statement' => "",
+                    ],
+                ],
+                'dmlog' => [],
                 "schema_snapshot" => "dataschema",
-                "tracking" => "SELECT, DELETE"
-            )
-        );
+                "tracking" => "SELECT, DELETE",
+            ],
+        ];
 
-        $fetchArrayReturn[1] = array(
+        $fetchArrayReturn[1] = [
             "schema_sql" => "# log 20-03-2012 23:33:58 user1\n" .
             "# log 20-03-2012 23:39:58 user2\n",
             "data_sql" => "# log 20-03-2013 23:33:58 user3\n" .
             "# log 20-03-2013 23:39:58 user4\n",
             "schema_snapshot" => "dataschema",
-            "tracking" => "SELECT, DELETE"
-        );
+            "tracking" => "SELECT, DELETE",
+        ];
 
-        $data[1] = array(
+        $data[1] = [
             'date_from' => '20-03-2012 23:33:58',
             'date_to' => '20-03-2013 23:39:58',
-            'ddlog' => array(
-                            array(
-                                'date' => '20-03-2012 23:33:58',
-                                'username' => 'user1',
-                                'statement' => ""
-                            ),
-                            array(
-                                'date' => '20-03-2012 23:39:58',
-                                'username' => 'user2',
-                                'statement' => ""
-                            )
-                        ),
-            'dmlog' => array(
-                            array(
-                                'date' => '20-03-2013 23:33:58',
-                                'username' => 'user3',
-                                'statement' => ""
-                            ),
-                            array(
-                                'date' => '20-03-2013 23:39:58',
-                                'username' => 'user4',
-                                'statement' => ""
-                            )
-                        ),
+            'ddlog' => [
+                [
+                    'date' => '20-03-2012 23:33:58',
+                    'username' => 'user1',
+                    'statement' => "",
+                ],
+                [
+                    'date' => '20-03-2012 23:39:58',
+                    'username' => 'user2',
+                    'statement' => "",
+                ],
+            ],
+            'dmlog' => [
+                [
+                    'date' => '20-03-2013 23:33:58',
+                    'username' => 'user3',
+                    'statement' => "",
+                ],
+                [
+                    'date' => '20-03-2013 23:39:58',
+                    'username' => 'user4',
+                    'statement' => "",
+                ],
+            ],
             "schema_snapshot" => "dataschema",
-            "tracking" => "SELECT, DELETE"
-        );
-        return array(
-            array($fetchArrayReturn[0], $data[0]),
-            array($fetchArrayReturn[1], $data[1])
-        );
+            "tracking" => "SELECT, DELETE",
+        ];
+        return [
+            [
+                $fetchArrayReturn[0],
+                $data[0],
+            ],
+            [
+                $fetchArrayReturn[1],
+                $data[1],
+            ],
+        ];
     }
 
     /**
@@ -705,8 +745,13 @@ class TrackerTest extends PmaTestCase
      * @test
      * @dataProvider parseQueryData
      */
-    public function testParseQuery($query, $type, $identifier, $tablename,
-        $db = null, $tablename_after_rename = null
+    public function testParseQuery(
+        $query,
+        $type,
+        $identifier,
+        $tablename,
+        $db = null,
+        $tablename_after_rename = null
     ) {
         $result = Tracker::parseQuery($query);
 
@@ -747,7 +792,7 @@ class TrackerTest extends PmaTestCase
      */
     public function parseQueryData()
     {
-        $query = array();
+        $query = [];
         /** TODO: Should test fail when USE is in conjunction with * identifiers?
         $query[] = array(
             " - USE db1;\n- CREATE VIEW db1.v AS SELECT * FROM t;",
@@ -757,130 +802,130 @@ class TrackerTest extends PmaTestCase
             "db1"
         );
         */
-        $query[] = array(
+        $query[] = [
             "CREATE VIEW v AS SELECT * FROM t;",
             "DDL",
             "CREATE VIEW",
             "v",
-        );
-        $query[] = array(
+        ];
+        $query[] = [
             "ALTER VIEW db1.v AS SELECT col1, col2, col3, col4 FROM t",
             "DDL",
             "ALTER VIEW",
-            "v"
-        );
-        $query[] = array(
+            "v",
+        ];
+        $query[] = [
             "DROP VIEW db1.v;",
             "DDL",
             "DROP VIEW",
-            "v"
-        );
-        $query[] = array(
+            "v",
+        ];
+        $query[] = [
             "DROP VIEW IF EXISTS db1.v;",
             "DDL",
             "DROP VIEW",
-            "v"
-        );
-        $query[] = array(
+            "v",
+        ];
+        $query[] = [
             "CREATE DATABASE db1;",
             "DDL",
             "CREATE DATABASE",
             "",
-            "db1"
-        );
-        $query[] = array(
+            "db1",
+        ];
+        $query[] = [
             "ALTER DATABASE db1;",
             "DDL",
             "ALTER DATABASE",
-            ""
-        );
-        $query[] = array(
+            "",
+        ];
+        $query[] = [
             "DROP DATABASE db1;",
             "DDL",
             "DROP DATABASE",
             "",
-            "db1"
-        );
-        $query[] = array(
+            "db1",
+        ];
+        $query[] = [
             "CREATE TABLE db1.t1 (c1 INT);",
             "DDL",
             "CREATE TABLE",
-            "t1"
-        );
-        $query[] =  array(
+            "t1",
+        ];
+        $query[] =  [
             "ALTER TABLE db1.t1 ADD c2 TEXT;",
             "DDL",
             "ALTER TABLE",
-            "t1"
-        );
-        $query[] =  array(
+            "t1",
+        ];
+        $query[] =  [
             "DROP TABLE db1.t1",
             "DDL",
             "DROP TABLE",
-            "t1"
-        );
-        $query[] =  array(
+            "t1",
+        ];
+        $query[] =  [
             "DROP TABLE IF EXISTS db1.t1",
             "DDL",
             "DROP TABLE",
-            "t1"
-        );
-        $query[] =  array(
+            "t1",
+        ];
+        $query[] =  [
             "CREATE INDEX ind ON db1.t1 (c2(10));",
             "DDL",
             "CREATE INDEX",
-            "t1"
-        );
-        $query[] =  array(
+            "t1",
+        ];
+        $query[] =  [
             "CREATE UNIQUE INDEX ind ON db1.t1 (c2(10));",
             "DDL",
             "CREATE INDEX",
-            "t1"
-        );
-        $query[] =  array(
+            "t1",
+        ];
+        $query[] =  [
             "CREATE SPATIAL INDEX ind ON db1.t1 (c2(10));",
             "DDL",
             "CREATE INDEX",
-            "t1"
-        );
-        $query[] =  array(
+            "t1",
+        ];
+        $query[] =  [
             "DROP INDEX ind ON db1.t1;",
             "DDL",
             "DROP INDEX",
-            "t1"
-        );
-        $query[] =  array(
+            "t1",
+        ];
+        $query[] =  [
             "RENAME TABLE db1.t1 TO db1.t2",
             "DDL",
             "RENAME TABLE",
             "t1",
             "",
-            "t2"
-        );
-        $query[] =  array(
+            "t2",
+        ];
+        $query[] =  [
             "UPDATE db1.t1 SET a = 2",
             "DML",
             "UPDATE",
-            "t1"
-        );
-        $query[] =  array(
+            "t1",
+        ];
+        $query[] =  [
             "INSERT INTO db1.t1 (a, b, c) VALUES(1, 2, 3)",
             "DML",
             "INSERT",
-            "t1"
-        );
-        $query[] =  array(
+            "t1",
+        ];
+        $query[] =  [
             "DELETE FROM db1.t1",
             "DML",
             "DELETE",
-            "t1"
-        );
-        $query[] =  array(
+            "t1",
+        ];
+        $query[] =  [
             "TRUNCATE db1.t1",
             "DML",
             "TRUNCATE",
-            "t1"
-        );
+            "t1",
+        ];
 
         return $query;
     }
