@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin-test
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Tests;
 
 use PhpMyAdmin\Url;
@@ -24,7 +26,7 @@ class UrlTest extends TestCase
      * @access protected
      * @return void
      */
-    public function setUp()
+    protected function setUp(): void
     {
         unset($_COOKIE['pma_lang']);
     }
@@ -45,7 +47,7 @@ class UrlTest extends TestCase
         $expected = '?db=db'
             . htmlentities($separator) . $expected;
 
-        $this->assertEquals($expected, Url::getCommon(array('db' => 'db')));
+        $this->assertEquals($expected, Url::getCommon(['db' => 'db']));
     }
 
     /**
@@ -64,7 +66,10 @@ class UrlTest extends TestCase
         $expected = '?db=db'
             . htmlentities($separator) . 'table=table'
             . htmlentities($separator) . $expected;
-        $params = array('db' => 'db', 'table' => 'table');
+        $params = [
+            'db' => 'db',
+            'table' => 'table',
+        ];
         $this->assertEquals($expected, Url::getCommon($params));
     }
 
@@ -86,7 +91,11 @@ class UrlTest extends TestCase
         $this->assertEquals(
             $expected,
             Url::getCommonRaw(
-                array('db' => 'db', 'table' => 'table'), '#ABC#'
+                [
+                    'db' => 'db',
+                    'table' => 'table',
+                ],
+                '#ABC#'
             )
         );
     }
